/******************************************************************************
 * @file     startup_AKD1000.c
 * @brief    CMSIS Device Startup Source File for AKD1000 Device
 ******************************************************************************/
/*
 * Copyright (c) 2009-2020 Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "AKD1000.h"

/*----------------------------------------------------------------------------
  External References
 *----------------------------------------------------------------------------*/
extern uint32_t __INITIAL_SP;

extern __NO_RETURN void __PROGRAM_START(void);

/*----------------------------------------------------------------------------
  Internal References
 *----------------------------------------------------------------------------*/
__NO_RETURN void Reset_Handler(void);
void Default_Handler(void);

/*----------------------------------------------------------------------------
  Exception / Interrupt Handler
 *----------------------------------------------------------------------------*/
/* Exceptions */
void NMI_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HardFault_Handler(void) __attribute__((weak));
void MemManage_Handler(void) __attribute__((weak, alias("Default_Handler")));
void BusFault_Handler(void) __attribute__((weak, alias("Default_Handler")));
void UsageFault_Handler(void) __attribute__((weak, alias("Default_Handler")));
void SVC_Handler(void) __attribute__((weak, alias("Default_Handler")));
void DebugMon_Handler(void) __attribute__((weak, alias("Default_Handler")));
void PendSV_Handler(void) __attribute__((weak, alias("Default_Handler")));
void SysTick_Handler(void) __attribute__((weak, alias("Default_Handler")));

#ifndef CONFIG_NO_INTERRUPTS
void Timer_0_Handler(void) __attribute__((weak, alias("Default_Handler")));
void Timer_1_Handler(void) __attribute__((weak, alias("Default_Handler")));
void Wdog_Handler(void) __attribute__((weak, alias("Default_Handler")));
void Uart_0_Handler(void) __attribute__((weak, alias("Default_Handler")));
void Uart_1_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_0_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_1_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_2_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_3_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_4_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_5_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_6_Handler(void) __attribute__((weak, alias("Default_Handler")));
void HDMAC_7_Handler(void) __attribute__((weak, alias("Default_Handler")));
void Akida_Core_Handler(void) __attribute__((weak, alias("Default_Handler")));
void RTC_Handler(void) __attribute__((weak, alias("Default_Handler")));
void I2C_Handler(void) __attribute__((weak, alias("Default_Handler")));
void I3C_Handler(void) __attribute__((weak, alias("Default_Handler")));
void I2S_Handler(void) __attribute__((weak, alias("Default_Handler")));
void SPI_RX_Handler(void) __attribute__((weak, alias("Default_Handler")));
void SPI_TX_Handler(void) __attribute__((weak, alias("Default_Handler")));
void SPI_ERR_Handler(void) __attribute__((weak, alias("Default_Handler")));
void TRNG_Handler(void) __attribute__((weak, alias("Default_Handler")));
void LPDDR_Handler(void) __attribute__((weak, alias("Default_Handler")));
void PCI_EP_OR_USB_Handler(void) __attribute__((weak, alias("Default_Handler")));
void PCI_RC_Handler(void) __attribute__((weak, alias("Default_Handler")));
void SYS_REG_Handler(void) __attribute__((weak, alias("Default_Handler")));
void LPDDR_FRQ_CHNG_Handler(void) __attribute__((weak, alias("Default_Handler")));
void GPIO_Handler(void) __attribute__((weak, alias("Default_Handler")));
#endif

/*----------------------------------------------------------------------------
  Exception / Interrupt Vector table
 *----------------------------------------------------------------------------*/

#if defined(__GNUC__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wpedantic"
#endif
#ifdef CONFIG_NO_INTERRUPTS
extern const VECTOR_TABLE_Type __VECTOR_TABLE[16];
const VECTOR_TABLE_Type __VECTOR_TABLE[16] __VECTOR_TABLE_ATTRIBUTE = {
#else
extern const VECTOR_TABLE_Type __VECTOR_TABLE[240];
const VECTOR_TABLE_Type __VECTOR_TABLE[240] __VECTOR_TABLE_ATTRIBUTE = {
#endif
    (VECTOR_TABLE_Type)(&__INITIAL_SP), /*     Initial Stack Pointer */
    Reset_Handler,                      /*     Reset Handler */
    NMI_Handler,                        /* -14 NMI Handler */
    HardFault_Handler,                  /* -13 Hard Fault Handler */
    MemManage_Handler,                  /* -12 MPU Fault Handler */
    BusFault_Handler,                   /* -11 Bus Fault Handler */
    UsageFault_Handler,                 /* -10 Usage Fault Handler */
    0,                                  /*     Reserved */
    0,                                  /*     Reserved */
    0,                                  /*     Reserved */
    0,                                  /*     Reserved */
    SVC_Handler,                        /*  -5 SVCall Handler */
    DebugMon_Handler,                   /*  -4 Debug Monitor Handler */
    0,                                  /*     Reserved */
    PendSV_Handler,                     /*  -2 PendSV Handler */
    SysTick_Handler,                    /*  -1 SysTick Handler */
#ifndef CONFIG_NO_INTERRUPTS
    /* Interrupts */
    Timer_0_Handler,        /*  0 Timer0 Handler */
    Timer_1_Handler,        /*  1 Timer1 Handler */
    Wdog_Handler,           /*  2 WDOG Handler */
    Uart_0_Handler,         /*  3 Uart0 Handler */
    Uart_1_Handler,         /*  4 Uart1 Handler */
    HDMAC_0_Handler,        /*  5 HDMAC0 Handler */
    HDMAC_1_Handler,        /*  6 HDMAC1 Handler */
    HDMAC_2_Handler,        /*  7 HDMAC2 Handler */
    HDMAC_3_Handler,        /*  8 HDMAC3 Handler */
    HDMAC_4_Handler,        /*  9 HDMAC4 Handler */
    HDMAC_5_Handler,        /*  10 HDMAC5 Handler */
    HDMAC_6_Handler,        /*  11 HDMAC6 Handler */
    HDMAC_7_Handler,        /*  12 HDMAC7 Handler */
    Akida_Core_Handler,     /*  13 External Akida Core Handler */
    RTC_Handler,            /*  14 External RTC Handler */
    I2C_Handler,            /*  15 External I2C Handler */
    I3C_Handler,            /*  16 External I3C Handler */
    I2S_Handler,            /*  17 External I2S Handler */
    SPI_RX_Handler,         /*  18 External SPI RX Handler */
    SPI_TX_Handler,         /*  19 External SPI TX Handler */
    SPI_ERR_Handler,        /*  20 External SPI ERR Handler */
    TRNG_Handler,           /*  21 External TRNG Handler */
    LPDDR_Handler,          /*  22 External LPDDR Handler */
    PCI_EP_OR_USB_Handler,  /*  23 External PCI EP or USB Handler */
    PCI_RC_Handler,         /*  24 External PCI RC Handler */
    Default_Handler,        /*     Reserved */
    SYS_REG_Handler,        /*  26 External System Register Handler */
    LPDDR_FRQ_CHNG_Handler, /*  27 External LPDDR Frequency Change Handler */
    GPIO_Handler,           /*  28 External GPIO Handler */
/* Interrupts 29 .. 223 are left out */
#endif
};

#if defined(__GNUC__)
#pragma GCC diagnostic pop
#endif

/*----------------------------------------------------------------------------
  Reset Handler called on controller reset
 *----------------------------------------------------------------------------*/
__NO_RETURN void Reset_Handler(void) {
    SystemInit();      /* CMSIS System Initialization */
    __PROGRAM_START(); /* Enter PreMain (C library entry point) */
}

#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wmissing-noreturn"
#endif

#ifdef CONFIG_DEBUG
#define HARDFAULT_HANDLING_ASM(_x) \
    __asm volatile(                \
        "tst lr, #4 \n"            \
        "ite eq \n"                \
        "mrseq r0, msp \n"         \
        "mrsne r0, psp \n"         \
        "b fault_handler_c \n")
#else
#define HARDFAULT_HANDLING_ASM(_x) \
    do {                           \
        while (1)                  \
            ;                      \
    } while (0)
#endif

/*----------------------------------------------------------------------------
  Hard Fault Handler
 *----------------------------------------------------------------------------*/
void HardFault_Handler(void) {
    HARDFAULT_HANDLING_ASM(0);
}

/*----------------------------------------------------------------------------
  Default Handler for Exceptions / Interrupts
 *----------------------------------------------------------------------------*/
void Default_Handler(void) {
    HARDFAULT_HANDLING_ASM(0);
}

#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
#pragma clang diagnostic pop
#endif
