#include <stddef.h>

#include "driver.h"
#include "i2c/ina233.h"
#include "i2c_bus.h"
#include "mini_pcie.h"
#include "soc.h"
#include "spi_flash.h"

#ifdef CONFIG_DRIVER_I2C
#ifdef CONFIG_INA233
DECLARE_I2C_DEVICE(ina1, CONFIG_INA233_ADDRESS, NULL, 2);
#endif
#ifdef CONFIG_INA231
DECLARE_I2C_DEVICE(ina1, CONFIG_INA231_ADDRESS, NULL, 2);
#endif
#endif

void board_init() {
    /* initialize the soc internal drivers */
    soc_init();

    driver_init();

#ifdef CONFIG_DRIVER_I2C
    /* attach i2c device drivers to their respective busses */
    struct i2c_bus_driver* bus = (struct i2c_bus_driver*)driver_lookup("akida_i3c");
#ifdef CONFIG_INA233
    /* ina233 is a slave to I3c master */
    void* interface = interface_lookup("ina233");
    i2c_attach(bus, &ina1, interface);
#endif

#ifdef CONFIG_INA231
    /* ina231 is a slave to I3c master */
    void* interface = interface_lookup("ina231");
    i2c_attach(bus, &ina1, interface);
#endif

#endif
}
