#ifndef __CRG11_H_
#define __CRG11_H_

#include <stdint.h>
#include "AKD1000.h"

typedef volatile struct {
    uint32_t CRPLC;       // 0x000
    uint32_t CRRDY;       // 0x004
    uint32_t CRSTP;       // 0x008
    uint32_t reserved00;  // 0x00C

    uint32_t CRIMA;  // 0x010
    uint32_t CRPIC;  // 0x014

    uint32_t reserved01;  // 0x018
    uint32_t reserved02;  // 0x01C

    uint32_t CRRSC;          // 0x020
    uint32_t CRSWR;          // 0x024
    uint32_t CRRRS;          // 0x028
    uint32_t CRRSM;          // 0x02C
    uint32_t CRCDC;          // 0x030
    uint32_t reserved03[3];  // 0x034 - 0x03C
    uint32_t PLLICP;         // 0x040

    uint32_t reserved04[(0x100 - 0x44) / 4];  // 0x034 - 0x0FC
    // 0x100 -0x1FC
    struct {
        uint32_t CRDM;
        uint32_t CRLP;
        uint32_t reserved00;
        uint32_t reserved01;
    } CLK[16];

    uint32_t AKCRGC;    // 0x200
    uint32_t DDRGC;     // 0x204
    uint32_t DDRFC;     // 0x208
    uint32_t M4SSC;     // 0x20c
    uint32_t AKIPCRC;   // 0x210
    uint32_t AKIPCIEC;  // 0x214
    uint32_t AKRTCC;    // 0x218
} CRG11_Type;

// CRG11 access definition
#define CRG11 ((CRG11_Type*)CRG11_BASE)  // CRG11_BASE

/*************** Bit definition of CRPLC register  ***************/
#define CRG11_CRPLC_PLLBYPASS ((uint32_t)((uint32_t)0x1 << 24)) /* PLL bypass mode */

#define CRG11_CRPLC_LUWMODE ((uint32_t)((uint32_t)0xF << 16)) /* PLL lock-up wait time  */
/* configuration for LUWMODE */
#define CRG11_CRPLC_LUWMODE_64 \
    ((uint32_t)((uint32_t)0x0 << 16)) /* PLL lock-up wait time 64 * TXCLK */
#define CRG11_CRPLC_LUWMODE_128 \
    ((uint32_t)((uint32_t)0x1 << 16)) /* PLL lock-up wait time 128 * TXCLK */
#define CRG11_CRPLC_LUWMODE_512 \
    ((uint32_t)((uint32_t)0x2 << 16)) /* PLL lock-up wait time 512 * TXCLK */
#define CRG11_CRPLC_LUWMODE_768 \
    ((uint32_t)((uint32_t)0x3 << 16)) /* PLL lock-up wait time 768 * TXCLK */
#define CRG11_CRPLC_LUWMODE_1024 \
    ((uint32_t)((uint32_t)0x4 << 16)) /* PLL lock-up wait time 1024 * TXCLK */
#define CRG11_CRPLC_LUWMODE_1536 \
    ((uint32_t)((uint32_t)0x5 << 16)) /* PLL lock-up wait time 1536 * TXCLK */
#define CRG11_CRPLC_LUWMODE_2048 \
    ((uint32_t)((uint32_t)0x6 << 16)) /* PLL lock-up wait time 2048 * TXCLK */
#define CRG11_CRPLC_LUWMODE_3072 \
    ((uint32_t)((uint32_t)0x7 << 16)) /* PLL lock-up wait time 3072 * TXCLK */
#define CRG11_CRPLC_LUWMODE_4096 \
    ((uint32_t)((uint32_t)0x8 << 16)) /* PLL lock-up wait time 4096 * TXCLK */
#define CRG11_CRPLC_LUWMODE_6144 \
    ((uint32_t)((uint32_t)0x9 << 16)) /* PLL lock-up wait time 6144 * TXCLK */
#define CRG11_CRPLC_LUWMODE_8192 \
    ((uint32_t)((uint32_t)0xA << 16)) /* PLL lock-up wait time 8192 * TXCLK */
#define CRG11_CRPLC_LUWMODE_12288 \
    ((uint32_t)((uint32_t)0xB << 16)) /* PLL lock-up wait time 12288 * TXCLK */
#define CRG11_CRPLC_LUWMODE_16384 \
    ((uint32_t)((uint32_t)0xC << 16)) /* PLL lock-up wait time 16384 * TXCLK */
#define CRG11_CRPLC_LUWMODE_24576 \
    ((uint32_t)((uint32_t)0xD << 16)) /* PLL lock-up wait time 24576 * TXCLK */
#define CRG11_CRPLC_LUWMODE_32768 \
    ((uint32_t)((uint32_t)0xE << 16)) /* PLL lock-up wait time 32768 * TXCLK */
#define CRG11_CRPLC_LUWMODE_49152 \
    ((uint32_t)((uint32_t)0xF << 16)) /* PLL lock-up wait time 49152 * TXCLK */

#define CRG11_CRPLC_PSMODE \
    ((uint32_t)((uint32_t)0xF << 8)) /* Dividing ratio of PLL clock frequency */
/* configuration for PSMODE */
#define CRG11_CRPLC_PSMODE_1 ((uint32_t)((uint32_t)0x0 << 8))    /* n = 1 */
#define CRG11_CRPLC_PSMODE_1_2 ((uint32_t)((uint32_t)0x1 << 8))  /* n = 1/(1*2) */
#define CRG11_CRPLC_PSMODE_2_2 ((uint32_t)((uint32_t)0x2 << 8))  /* n = 1/(2*2) */
#define CRG11_CRPLC_PSMODE_3_2 ((uint32_t)((uint32_t)0x3 << 8))  /* n = 1/(3*2) */
#define CRG11_CRPLC_PSMODE_4_2 ((uint32_t)((uint32_t)0x4 << 8))  /* n = 1/(4*2) */
#define CRG11_CRPLC_PSMODE_5_2 ((uint32_t)((uint32_t)0x5 << 8))  /* n = 1/(5*2) */
#define CRG11_CRPLC_PSMODE_6_2 ((uint32_t)((uint32_t)0x6 << 8))  /* n = 1/(6*2) */
#define CRG11_CRPLC_PSMODE_7_2 ((uint32_t)((uint32_t)0x7 << 8))  /* n = 1/(7*2) */
#define CRG11_CRPLC_PSMODE_8_2 ((uint32_t)((uint32_t)0x8 << 8))  /* n = 1/(8*2) */
#define CRG11_CRPLC_PSMODE_9_2 ((uint32_t)((uint32_t)0x9 << 8))  /* n = 1/(9*2) */
#define CRG11_CRPLC_PSMODE_10_2 ((uint32_t)((uint32_t)0xA << 8)) /* n = 1/(10*2) */
#define CRG11_CRPLC_PSMODE_11_2 ((uint32_t)((uint32_t)0xB << 8)) /* n = 1/(11*2) */
#define CRG11_CRPLC_PSMODE_12_2 ((uint32_t)((uint32_t)0xC << 8)) /* n = 1/(12*2) */
#define CRG11_CRPLC_PSMODE_13_2 ((uint32_t)((uint32_t)0xD << 8)) /* n = 1/(13*2) */
#define CRG11_CRPLC_PSMODE_14_2 ((uint32_t)((uint32_t)0xE << 8)) /* n = 1/(14*2) */
#define CRG11_CRPLC_PSMODE_15_2 ((uint32_t)((uint32_t)0xF << 8)) /* n = 1/(15*2) */

#define CRG11_CRPLC_FBMODE \
    ((uint32_t)((uint32_t)0x3F << 0)) /* Multiplying ratio of PLL clock frequency */
/* configuration for FBMODE */
#define CRG11_CRPLC_FBMODE_STOP ((uint32_t)((uint32_t)0x00 << 0)) /* STOP the PLL*/
#define CRG11_CRPLC_FBMODE_1_2 ((uint32_t)((uint32_t)0x01 << 0))  /* m = 1*2 */
#define CRG11_CRPLC_FBMODE_2_2 ((uint32_t)((uint32_t)0x02 << 0))  /* m = 2*2 */
#define CRG11_CRPLC_FBMODE_3_2 ((uint32_t)((uint32_t)0x03 << 0))  /* m = 3*2 */
#define CRG11_CRPLC_FBMODE_4_2 ((uint32_t)((uint32_t)0x04 << 0))  /* m = 4*2 */
#define CRG11_CRPLC_FBMODE_5_2 ((uint32_t)((uint32_t)0x05 << 0))  /* m = 5*2 */
#define CRG11_CRPLC_FBMODE_6_2 ((uint32_t)((uint32_t)0x06 << 0))  /* m = 6*2 */
#define CRG11_CRPLC_FBMODE_7_2 ((uint32_t)((uint32_t)0x07 << 0))  /* m = 7*2 */
#define CRG11_CRPLC_FBMODE_8_2 ((uint32_t)((uint32_t)0x08 << 0))  /* m = 8*2 */
#define CRG11_CRPLC_FBMODE_9_2 ((uint32_t)((uint32_t)0x09 << 0))  /* m = 9*2 */
#define CRG11_CRPLC_FBMODE_10_2 ((uint32_t)((uint32_t)0x0A << 0)) /* m = 10*2 */
#define CRG11_CRPLC_FBMODE_11_2 ((uint32_t)((uint32_t)0x0B << 0)) /* m = 11*2 */
#define CRG11_CRPLC_FBMODE_12_2 ((uint32_t)((uint32_t)0x0C << 0)) /* m = 12*2 */
#define CRG11_CRPLC_FBMODE_13_2 ((uint32_t)((uint32_t)0x0D << 0)) /* m = 13*2 */
#define CRG11_CRPLC_FBMODE_14_2 ((uint32_t)((uint32_t)0x0E << 0)) /* m = 14*2 */
#define CRG11_CRPLC_FBMODE_15_2 ((uint32_t)((uint32_t)0x0F << 0)) /* m = 15*2 */
#define CRG11_CRPLC_FBMODE_16_2 ((uint32_t)((uint32_t)0x10 << 0)) /* m = 16*2 */
#define CRG11_CRPLC_FBMODE_17_2 ((uint32_t)((uint32_t)0x11 << 0)) /* m = 17*2 */
#define CRG11_CRPLC_FBMODE_18_2 ((uint32_t)((uint32_t)0x12 << 0)) /* m = 18*2 */
#define CRG11_CRPLC_FBMODE_19_2 ((uint32_t)((uint32_t)0x13 << 0)) /* m = 19*2 */
#define CRG11_CRPLC_FBMODE_20_2 ((uint32_t)((uint32_t)0x14 << 0)) /* m = 20*2 */
#define CRG11_CRPLC_FBMODE_21_2 ((uint32_t)((uint32_t)0x15 << 0)) /* m = 21*2 */
#define CRG11_CRPLC_FBMODE_22_2 ((uint32_t)((uint32_t)0x16 << 0)) /* m = 22*2 */
#define CRG11_CRPLC_FBMODE_23_2 ((uint32_t)((uint32_t)0x17 << 0)) /* m = 23*2 */
#define CRG11_CRPLC_FBMODE_24_2 ((uint32_t)((uint32_t)0x18 << 0)) /* m = 24*2 */
#define CRG11_CRPLC_FBMODE_25_2 ((uint32_t)((uint32_t)0x19 << 0)) /* m = 25*2 */
#define CRG11_CRPLC_FBMODE_26_2 ((uint32_t)((uint32_t)0x1A << 0)) /* m = 26*2 */
#define CRG11_CRPLC_FBMODE_27_2 ((uint32_t)((uint32_t)0x1B << 0)) /* m = 27*2 */
#define CRG11_CRPLC_FBMODE_28_2 ((uint32_t)((uint32_t)0x1C << 0)) /* m = 28*2 */
#define CRG11_CRPLC_FBMODE_29_2 ((uint32_t)((uint32_t)0x1D << 0)) /* m = 29*2 */
#define CRG11_CRPLC_FBMODE_30_2 ((uint32_t)((uint32_t)0x1E << 0)) /* m = 30*2 */
#define CRG11_CRPLC_FBMODE_31_2 ((uint32_t)((uint32_t)0x1F << 0)) /* m = 31*2 */
#define CRG11_CRPLC_FBMODE_32_2 ((uint32_t)((uint32_t)0x20 << 0)) /* m = 32*2 */
#define CRG11_CRPLC_FBMODE_33_2 ((uint32_t)((uint32_t)0x21 << 0)) /* m = 33*2 */
#define CRG11_CRPLC_FBMODE_34_2 ((uint32_t)((uint32_t)0x22 << 0)) /* m = 34*2 */
#define CRG11_CRPLC_FBMODE_35_2 ((uint32_t)((uint32_t)0x23 << 0)) /* m = 35*2 */
#define CRG11_CRPLC_FBMODE_36_2 ((uint32_t)((uint32_t)0x24 << 0)) /* m = 36*2 */
#define CRG11_CRPLC_FBMODE_37_2 ((uint32_t)((uint32_t)0x25 << 0)) /* m = 37*2 */
#define CRG11_CRPLC_FBMODE_38_2 ((uint32_t)((uint32_t)0x26 << 0)) /* m = 38*2 */
#define CRG11_CRPLC_FBMODE_39_2 ((uint32_t)((uint32_t)0x27 << 0)) /* m = 39*2 */
#define CRG11_CRPLC_FBMODE_40_2 ((uint32_t)((uint32_t)0x28 << 0)) /* m = 40*2 */
#define CRG11_CRPLC_FBMODE_41_2 ((uint32_t)((uint32_t)0x29 << 0)) /* m = 41*2 */
#define CRG11_CRPLC_FBMODE_42_2 ((uint32_t)((uint32_t)0x2A << 0)) /* m = 42*2 */
#define CRG11_CRPLC_FBMODE_43_2 ((uint32_t)((uint32_t)0x2B << 0)) /* m = 43*2 */
#define CRG11_CRPLC_FBMODE_44_2 ((uint32_t)((uint32_t)0x2C << 0)) /* m = 44*2 */
#define CRG11_CRPLC_FBMODE_45_2 ((uint32_t)((uint32_t)0x2D << 0)) /* m = 45*2 */
#define CRG11_CRPLC_FBMODE_46_2 ((uint32_t)((uint32_t)0x2E << 0)) /* m = 46*2 */
#define CRG11_CRPLC_FBMODE_47_2 ((uint32_t)((uint32_t)0x2F << 0)) /* m = 47*2 */
#define CRG11_CRPLC_FBMODE_48_2 ((uint32_t)((uint32_t)0x30 << 0)) /* m = 48*2 */
#define CRG11_CRPLC_FBMODE_49_2 ((uint32_t)((uint32_t)0x31 << 0)) /* m = 49*2 */
#define CRG11_CRPLC_FBMODE_50_2 ((uint32_t)((uint32_t)0x32 << 0)) /* m = 50*2 */
#define CRG11_CRPLC_FBMODE_51_2 ((uint32_t)((uint32_t)0x33 << 0)) /* m = 51*2 */
#define CRG11_CRPLC_FBMODE_52_2 ((uint32_t)((uint32_t)0x34 << 0)) /* m = 52*2 */
#define CRG11_CRPLC_FBMODE_53_2 ((uint32_t)((uint32_t)0x35 << 0)) /* m = 53*2 */
#define CRG11_CRPLC_FBMODE_54_2 ((uint32_t)((uint32_t)0x36 << 0)) /* m = 54*2 */
#define CRG11_CRPLC_FBMODE_55_2 ((uint32_t)((uint32_t)0x37 << 0)) /* m = 55*2 */
#define CRG11_CRPLC_FBMODE_56_2 ((uint32_t)((uint32_t)0x38 << 0)) /* m = 56*2 */
#define CRG11_CRPLC_FBMODE_57_2 ((uint32_t)((uint32_t)0x39 << 0)) /* m = 57*2 */
#define CRG11_CRPLC_FBMODE_58_2 ((uint32_t)((uint32_t)0x3A << 0)) /* m = 58*2 */
#define CRG11_CRPLC_FBMODE_59_2 ((uint32_t)((uint32_t)0x3B << 0)) /* m = 59*2 */
#define CRG11_CRPLC_FBMODE_60_2 ((uint32_t)((uint32_t)0x3C << 0)) /* m = 60*2 */
#define CRG11_CRPLC_FBMODE_61_2 ((uint32_t)((uint32_t)0x3D << 0)) /* m = 61*2 */
#define CRG11_CRPLC_FBMODE_62_2 ((uint32_t)((uint32_t)0x3E << 0)) /* m = 62*2 */
#define CRG11_CRPLC_FBMODE_63_2 ((uint32_t)((uint32_t)0x3F << 0)) /* m = 63*2 */

/*************** Bit definition of CRRDY register  ***************/
#define CRG11_CRRDY_PSRMNT ((uint32_t)((uint32_t)0x1 << 4)) /* PSMODE reflection monitor */
#define CRG11_CRRDY_PLLRDY ((uint32_t)((uint32_t)0x1 << 0)) /* PLLREADY monitor */

/*************** Bit definition of CRSTP register  ***************/
#define CRG11_CRSTP_STOPMNT ((uint32_t)((uint32_t)0x1 << 1)) /* Stop mode monitor */
#define CRG11_CRSTP_STOPEN ((uint32_t)((uint32_t)0x1 << 0))  /* Stop mode enable */

/*************** Bit definition of CRIMA register  ***************/
#define CRG11_CRIMA_RDYINTM ((uint32_t)((uint32_t)0x1 << 0)) /* Mask signal of PLLRDY interrupt */

/*************** Bit definition of CRPIC register  ***************/
#define CRG11_CRPIC_PLLRDYINT ((uint32_t)((uint32_t)0x1 << 0)) /* PLLRDY interrupt clear */

/*************** Bit definition of CRRSC register  ***************/
#define CRG11_CRRSC_SRSTMODE ((uint32_t)((uint32_t)0xF << 16)) /* SRST reset pulse width */
/* configuration for SRSTMODE */
#define CRG11_CRRSC_SRSTMODE_8 \
    ((uint32_t)((uint32_t)0x0 << 16)) /* SRST reset pulse width 8 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_12 \
    ((uint32_t)((uint32_t)0x1 << 16)) /* SRST reset pulse width 12 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_16 \
    ((uint32_t)((uint32_t)0x2 << 16)) /* SRST reset pulse width 16 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_24 \
    ((uint32_t)((uint32_t)0x3 << 16)) /* SRST reset pulse width 24 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_32 \
    ((uint32_t)((uint32_t)0x4 << 16)) /* SRST reset pulse width 32 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_48 \
    ((uint32_t)((uint32_t)0x5 << 16)) /* SRST reset pulse width 48 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_64 \
    ((uint32_t)((uint32_t)0x6 << 16)) /* SRST reset pulse width 64 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_96 \
    ((uint32_t)((uint32_t)0x7 << 16)) /* SRST reset pulse width 96 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_128 \
    ((uint32_t)((uint32_t)0x8 << 16)) /* SRST reset pulse width 128 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_192 \
    ((uint32_t)((uint32_t)0x9 << 16)) /* SRST reset pulse width 192 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_256 \
    ((uint32_t)((uint32_t)0xA << 16)) /* SRST reset pulse width 256 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_384 \
    ((uint32_t)((uint32_t)0xB << 16)) /* SRST reset pulse width 384 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_512 \
    ((uint32_t)((uint32_t)0xC << 16)) /* SRST reset pulse width 512 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_768 \
    ((uint32_t)((uint32_t)0xD << 16)) /* SRST reset pulse width 768 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_1024 \
    ((uint32_t)((uint32_t)0xE << 16)) /* SRST reset pulse width 1024 * TCCLK */
#define CRG11_CRRSC_SRSTMODE_1536 \
    ((uint32_t)((uint32_t)0xF << 16)) /* SRST reset pulse width 1536 * TCCLK */

#define CRG11_CRRSC_WDRSTM ((uint32_t)((uint32_t)0x1 << 9)) /* Watchdog reset mode */
#define CRG11_CRRSC_SWRSTM ((uint32_t)((uint32_t)0x1 << 8)) /* Software reset mode */

#define CRG11_CRRSC_ARSTMODE ((uint32_t)((uint32_t)0xF << 0)) /* Software reset pulse width */
/* configuration for ARSTMODE */
#define CRG11_CRRSC_ARSTMODE_8 \
    ((uint32_t)((uint32_t)0x0 << 0)) /* Software reset pulse width 8 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_12 \
    ((uint32_t)((uint32_t)0x1 << 0)) /* Software reset pulse width 12 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_16 \
    ((uint32_t)((uint32_t)0x2 << 0)) /* Software reset pulse width 16 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_24 \
    ((uint32_t)((uint32_t)0x3 << 0)) /* Software reset pulse width 24 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_32 \
    ((uint32_t)((uint32_t)0x4 << 0)) /* Software reset pulse width 32 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_48 \
    ((uint32_t)((uint32_t)0x5 << 0)) /* Software reset pulse width 48 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_64 \
    ((uint32_t)((uint32_t)0x6 << 0)) /* Software reset pulse width 64 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_96 \
    ((uint32_t)((uint32_t)0x7 << 0)) /* Software reset pulse width 96 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_128 \
    ((uint32_t)((uint32_t)0x8 << 0)) /* Software reset pulse width 128 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_192 \
    ((uint32_t)((uint32_t)0x9 << 0)) /* Software reset pulse width 192 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_256 \
    ((uint32_t)((uint32_t)0xA << 0)) /* Software reset pulse width 256 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_384 \
    ((uint32_t)((uint32_t)0xB << 0)) /* Software reset pulse width 384 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_512 \
    ((uint32_t)((uint32_t)0xC << 0)) /* Software reset pulse width 512 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_768 \
    ((uint32_t)((uint32_t)0xD << 0)) /* Software reset pulse width 768 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_1024 \
    ((uint32_t)((uint32_t)0xE << 0)) /* Software reset pulse width 1024 * TCCLK */
#define CRG11_CRRSC_ARSTMODE_1536 \
    ((uint32_t)((uint32_t)0xF << 0)) /* Software reset pulse width 1536 * TCCLK */

/*************** Bit definition of CRSWR register  ***************/
#define CRG11_CRSWR_SWRSTREQ ((uint32_t)((uint32_t)0x1 << 0)) /* Software reset request */

/*************** Bit definition of CRRRS register  ***************/
#define CRG11_CRRRS_RRSTREQ \
    ((uint32_t)((uint32_t)0xFF << 0)) /* register-controlled reset request */
/* configuration for RRSTREQ */
#define CRG11_CRRRS_RRSTREQ0 \
    ((uint32_t)((uint32_t)0x1 << 0)) /* register-controlled reset request RRESET[0] */
#define CRG11_CRRRS_RRSTREQ1 \
    ((uint32_t)((uint32_t)0x1 << 1)) /* register-controlled reset request RRESET[1] */
#define CRG11_CRRRS_RRSTREQ2 \
    ((uint32_t)((uint32_t)0x1 << 2)) /* register-controlled reset request RRESET[2] */
#define CRG11_CRRRS_RRSTREQ3 \
    ((uint32_t)((uint32_t)0x1 << 3)) /* register-controlled reset request RRESET[3] */
#define CRG11_CRRRS_RRSTREQ4 \
    ((uint32_t)((uint32_t)0x1 << 4)) /* register-controlled reset request RRESET[4] */
#define CRG11_CRRRS_RRSTREQ5 \
    ((uint32_t)((uint32_t)0x1 << 5)) /* register-controlled reset request RRESET[5] */
#define CRG11_CRRRS_RRSTREQ6 \
    ((uint32_t)((uint32_t)0x1 << 6)) /* register-controlled reset request RRESET[6] */
#define CRG11_CRRRS_RRSTREQ7 \
    ((uint32_t)((uint32_t)0x1 << 7)) /* register-controlled reset request RRESET[7] */

/*************** Bit definition of CRRSM register  ***************/
#define CRG11_CRRSM_PORESET ((uint32_t)((uint32_t)0x1 << 3)) /* PORESETn monitor */
#define CRG11_CRRSM_SRST ((uint32_t)((uint32_t)0x1 << 2))    /* SRST reset monitor */
#define CRG11_CRRSM_SWRST ((uint32_t)((uint32_t)0x1 << 1))   /* Software reset monitor */
#define CRG11_CRRSM_WDRST ((uint32_t)((uint32_t)0x1 << 0))   /* Watchdog reset monitor */

/*************** Bit definition of CRCDC register   ***************/
#define CRG11_CRCDC_DCHREQ                                                \
    ((uint32_t)((uint32_t)0x1 << 0)) /* Clock divider mode update request \
                                      */

/*************** Bit definition of CRDMx register  ***************/
#define CRG11_CRDM_DIVMODE ((uint32_t)((uint32_t)0xFF << 0)) /* CLKx domain divider mode */
/* configuration for DIVMODE */
#define CRG11_CRDM_DIVMODE_1 ((uint32_t)((uint32_t)0x00 << 0))   /* FCLKx = FCCLK *(1/1) */
#define CRG11_CRDM_DIVMODE_2 ((uint32_t)((uint32_t)0x01 << 0))   /* FCLKx = FCCLK *(1/2) */
#define CRG11_CRDM_DIVMODE_4 ((uint32_t)((uint32_t)0x03 << 0))   /* FCLKx = FCCLK *(1/4) */
#define CRG11_CRDM_DIVMODE_8 ((uint32_t)((uint32_t)0x07 << 0))   /* FCLKx = FCCLK *(1/8) */
#define CRG11_CRDM_DIVMODE_3 ((uint32_t)((uint32_t)0x02 << 0))   /* FCLKx = FCCLK *(1/3) */
#define CRG11_CRDM_DIVMODE_6 ((uint32_t)((uint32_t)0x05 << 0))   /* FCLKx = FCCLK *(1/6) */
#define CRG11_CRDM_DIVMODE_12 ((uint32_t)((uint32_t)0x0B << 0))  /* FCLKx = FCCLK *(1/12) */
#define CRG11_CRDM_DIVMODE_24 ((uint32_t)((uint32_t)0x17 << 0))  /* FCLKx = FCCLK *(1/24) */
#define CRG11_CRDM_DIVMODE_9 ((uint32_t)((uint32_t)0x08 << 0))   /* FCLKx = FCCLK *(1/9) */
#define CRG11_CRDM_DIVMODE_18 ((uint32_t)((uint32_t)0x11 << 0))  /* FCLKx = FCCLK *(1/18) */
#define CRG11_CRDM_DIVMODE_36 ((uint32_t)((uint32_t)0x23 << 0))  /* FCLKx = FCCLK *(1/36) */
#define CRG11_CRDM_DIVMODE_72 ((uint32_t)((uint32_t)0x47 << 0))  /* FCLKx = FCCLK *(1/72) */
#define CRG11_CRDM_DIVMODE_27 ((uint32_t)((uint32_t)0x1A << 0))  /* FCLKx = FCCLK *(1/27) */
#define CRG11_CRDM_DIVMODE_54 ((uint32_t)((uint32_t)0x35 << 0))  /* FCLKx = FCCLK *(1/54) */
#define CRG11_CRDM_DIVMODE_108 ((uint32_t)((uint32_t)0x6B << 0)) /* FCLKx = FCCLK *(1/108) */
#define CRG11_CRDM_DIVMODE_216 ((uint32_t)((uint32_t)0xD7 << 0)) /* FCLKx = FCCLK *(1/216) */

/*************** Bit definition of CRLPx register  ***************/
#define CRG11_CRLP_CEN ((uint32_t)((uint32_t)0xFF << 24)) /* CLKx[7:0] low power state monitor */
/* configuration for CEN */
#define CRG11_CRLP_CEN_0 ((uint32_t)((uint32_t)0x01 << 24)) /* CLKx[0] low power state monitor */
#define CRG11_CRLP_CEN_1 ((uint32_t)((uint32_t)0x02 << 24)) /* CLKx[1] low power state monitor */
#define CRG11_CRLP_CEN_2 ((uint32_t)((uint32_t)0x04 << 24)) /* CLKx[2] low power state monitor */
#define CRG11_CRLP_CEN_3 ((uint32_t)((uint32_t)0x08 << 24)) /* CLKx[3] low power state monitor */
#define CRG11_CRLP_CEN_4 ((uint32_t)((uint32_t)0x10 << 24)) /* CLKx[4] low power state monitor */
#define CRG11_CRLP_CEN_5 ((uint32_t)((uint32_t)0x20 << 24)) /* CLKx[5] low power state monitor */
#define CRG11_CRLP_CEN_6 ((uint32_t)((uint32_t)0x40 << 24)) /* CLKx[6] low power state monitor */
#define CRG11_CRLP_CEN_7 ((uint32_t)((uint32_t)0x80 << 24)) /* CLKx[7] low power state monitor */

#define CRG11_CRLP_CACTIVE \
    ((uint32_t)((uint32_t)0xFF << 16)) /* CACTIVE_Cx[7:0] low power active monitor */
/* configuration for CACTIVE */
#define CRG11_CRLP_CACTIVE_0 \
    ((uint32_t)((uint32_t)0x01 << 16)) /* CACTIVE_Cx[0] low power active monitor */
#define CRG11_CRLP_CACTIVE_1 \
    ((uint32_t)((uint32_t)0x02 << 16)) /* CACTIVE_Cx[1] low power active monitor */
#define CRG11_CRLP_CACTIVE_2 \
    ((uint32_t)((uint32_t)0x04 << 16)) /* CACTIVE_Cx[2] low power active monitor */
#define CRG11_CRLP_CACTIVE_3 \
    ((uint32_t)((uint32_t)0x08 << 16)) /* CACTIVE_Cx[3] low power active monitor */
#define CRG11_CRLP_CACTIVE_4 \
    ((uint32_t)((uint32_t)0x10 << 16)) /* CACTIVE_Cx[4] low power active monitor */
#define CRG11_CRLP_CACTIVE_5 \
    ((uint32_t)((uint32_t)0x20 << 16)) /* CACTIVE_Cx[5] low power active monitor */
#define CRG11_CRLP_CACTIVE_6 \
    ((uint32_t)((uint32_t)0x40 << 16)) /* CACTIVE_Cx[6] low power active monitor */
#define CRG11_CRLP_CACTIVE_7 \
    ((uint32_t)((uint32_t)0x80 << 16)) /* CACTIVE_Cx[7] low power active monitor */

#define CRG11_CRLP_LPOWERHS \
    ((uint32_t)((uint32_t)0xFF << 8)) /* CLKx[7:0] Low power handchake monitor */
/* configuration for LPOWERHS */
#define CRG11_CRLP_LPOWERHS_0 \
    ((uint32_t)((uint32_t)0x01 << 8)) /* CLKx[0] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_1 \
    ((uint32_t)((uint32_t)0x02 << 8)) /* CLKx[1] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_2 \
    ((uint32_t)((uint32_t)0x04 << 8)) /* CLKx[2] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_3 \
    ((uint32_t)((uint32_t)0x08 << 8)) /* CLKx[3] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_4 \
    ((uint32_t)((uint32_t)0x10 << 8)) /* CLKx[4] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_5 \
    ((uint32_t)((uint32_t)0x20 << 8)) /* CLKx[5] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_6 \
    ((uint32_t)((uint32_t)0x40 << 8)) /* CLKx[6] Low power handchake monitor */
#define CRG11_CRLP_LPOWERHS_7 \
    ((uint32_t)((uint32_t)0x80 << 8)) /* CLKx[7] Low power handchake monitor */

#define CRG11_CRLP_CSYSREQ ((uint32_t)((uint32_t)0xFF << 0)) /* CLKx[7:0] low power request*/
/* configuration for CSYSREQ */
#define CRG11_CRLP_CSYSREQ_0 ((uint32_t)((uint32_t)0x01 << 0)) /* CLKx[0] low power request*/
#define CRG11_CRLP_CSYSREQ_1 ((uint32_t)((uint32_t)0x02 << 0)) /* CLKx[1] low power request*/
#define CRG11_CRLP_CSYSREQ_2 ((uint32_t)((uint32_t)0x04 << 0)) /* CLKx[2] low power request*/
#define CRG11_CRLP_CSYSREQ_3 ((uint32_t)((uint32_t)0x08 << 0)) /* CLKx[3] low power request*/
#define CRG11_CRLP_CSYSREQ_4 ((uint32_t)((uint32_t)0x10 << 0)) /* CLKx[4] low power request*/
#define CRG11_CRLP_CSYSREQ_5 ((uint32_t)((uint32_t)0x20 << 0)) /* CLKx[5] low power request*/
#define CRG11_CRLP_CSYSREQ_6 ((uint32_t)((uint32_t)0x40 << 0)) /* CLKx[6] low power request*/
#define CRG11_CRLP_CSYSREQ_7 ((uint32_t)((uint32_t)0x80 << 0)) /* CLKx[7] low power request*/

/* Definition of the modules to clock id
 * 6.4	AKIDA INTERNAL CLOCK DOMAINS of Akida_clkrst_specs_v0p1
 */
#define CRG11_CLK_ID_NONE -1
#define CRG11_CLK_ID_M4_AHB 0
#define CRG11_CLK_ID_M4_TRACE 1
#define CRG11_CLK_ID_M4_SYSTICK 2
#define CRG11_CLK_ID_M4_APB 4
#define CRG11_CLK_ID_M4_TIMER 5
#define CRG11_CLK_ID_M4_UART 5
#define CRG11_CLK_ID_SYSAPB 7
#define CRG11_CLK_ID_AXI 8
#define CRG11_CLK_ID_AK 9
#define CRG11_CLK_ID_AK_APB 10
#define CRG11_CLK_ID_SCC 11
#define CRG11_CLK_ID_LPDDR 12
#define CRG11_CLK_ID_I2S 13
#define CRG11_CLK_ID_RTC 14
#define CRG11_CLK_ID_SPI 7
#define CRG11_CLK_ID_I2C 7
#define CRG11_CLK_ID_WDOG 7
#define CRG11_CLK_ID_I3C 10
#define CRG11_CLK_ID_PCIE 14

int crg11_init(uint8_t speed);

#endif  // CRG11_H_
