#ifndef __POWER_MONITOR_H_
#define __POWER_MONITOR_H_

/**
 * @file power_monitor.h
 * This is public header file of power monitor.
 */

/** @addtogroup sensors
 * @{
 * @addtogroup power_sensors power sensor class
 * Documentation details of power monitor Abstraction layer.
 * @{
 **/

#include <stdint.h>

#include "driver.h"

struct power_monitor_driver;

struct power_monitor_ops {
    int (*read_voltage)(struct power_monitor_driver* drv, int* volt);
    int (*read_current)(struct power_monitor_driver* drv, int* current);
    int (*read_power)(struct power_monitor_driver* drv, int* power);
};

/**
 * power_monitor driver handle.
 */
struct power_monitor_driver {
    /** Common driver interface */
    struct driver_common driver;
    /** power_monitor driver interface implementation*/
    struct power_monitor_ops* ops;
    /** Private pointer */
    void* priv;
};

#define DECLARE_POWER_MONITOR(_name_, _ops_, _init_, _priv_)                            \
    struct power_monitor_driver __power_monitor_data_##_name_ = {.driver.init = _init_, \
                                                                 .ops = _ops_};         \
    DECLARE_DRIVER(_name_, power_monitor, &__power_monitor_data_##_name_.driver, _priv_)

/**
 * Get the voltage in uV from power monitor device
 * @param drv the power_monitor driver in use
 * @param volt the pointer to variable to return read voltage
 *
 * @return return error code in case of failure or return success
 */
int get_voltage(struct power_monitor_driver* drv, int* volt);

/**
 * Gets the current value in uA from power monitor device
 * @param drv the power_monitor driver in use
 * @param current the pointer to variable to return read current
 *
 * @return return error code in case of failure or return success
 */
int get_current(struct power_monitor_driver* drv, int* current);

/**
 * Get the power (uW) from power monitor device
 * @param drv the power_monitor driver in use
 * @param power the pointer to variable to return read power
 *
 * @return return error code in case of failure or return success
 */
int get_power(struct power_monitor_driver* drv, int* power);

/** @} */
/** @} */
#endif /* __POWER_MONITOR_H_ */
