#ifndef __I2C_REG_H_
#define __I2C_REG_H_
#include <stdint.h>

/*All register are of 1 bytes, remaining 3 bytes are unused*/
typedef volatile struct {
    __IO uint32_t BSR;  /*Bus Status Register                         */
    __IO uint32_t BCR;  /*Bus Control Register                        */
    __IO uint32_t CCR;  /*Clock Control Register                      */
    __IO uint32_t ADR;  /*Address Regsiter                            */
    __IO uint32_t DAR;  /*Data Register                               */
    __IO uint32_t CSR;  /*Expand Clock Period Select Register         */
    __IO uint32_t FSR;  /*Macro System Clock Frequency Select Register*/
    __IO uint32_t BCR2; /*Bus Control Register 2                      */
} I2C_t;

#define I2C ((I2C_t*)I2C_BASE)

/****************************************************
  ::BSR:: BitField descriptions
****************************************************/
/*! BUS BUSY */
#define I2C_BSR_BB_POS 7
#define I2C_BSR_BB_LEN 1
#define I2C_BSR_BB_MASK 0x80
#define I2C_BSR_BB_SET(x) (x << 7)
#define I2C_BSR_BB_GET(x) ((x >> 7) & 0x01)

/*! Repeat Start Condition */
#define I2C_BSR_RSC_POS 6
#define I2C_BSR_RSC_LEN 1
#define I2C_BSR_RSC_MASK 0x40
#define I2C_BSR_RSC_SET(x) (x << 6)
#define I2C_BSR_RSC_GET(x) ((x >> 6) & 0x01)

/*! Arbitration Lost */
#define I2C_BSR_AL_POS 5
#define I2C_BSR_AL_LEN 1
#define I2C_BSR_AL_MASK 0x20
#define I2C_BSR_AL_SET(x) (x << 5)
#define I2C_BSR_AL_GET(x) ((x >> 5) & 0x01)

/*! Last Received Bit */
#define I2C_BSR_LRB_POS 4
#define I2C_BSR_LRB_LEN 1
#define I2C_BSR_LRB_MASK 0x10
#define I2C_BSR_LRB_SET(x) (x << 4)
#define I2C_BSR_LRB_GET(x) ((x >> 4) & 0x01)

/*! Transfer/Receive */
#define I2C_BSR_TRX_POS 3
#define I2C_BSR_TRX_LEN 1
#define I2C_BSR_TRX_MASK 0x08
#define I2C_BSR_TRX_SET(x) (x << 3)
#define I2C_BSR_TRX_GET(x) ((x >> 3) & 0x01)

/*! Address As Slave */
#define I2C_BSR_AAS_POS 2
#define I2C_BSR_AAS_LEN 1
#define I2C_BSR_AAS_MASK 0x04
#define I2C_BSR_AAS_SET(x) (x << 2)
#define I2C_BSR_AAS_GET(x) ((x >> 2) & 0x01)

/*! General Call Address */
#define I2C_BSR_GCA_POS 1
#define I2C_BSR_GCA_LEN 1
#define I2C_BSR_GCA_MASK 0x02
#define I2C_BSR_GCA_SET(x) (x << 1)
#define I2C_BSR_GCA_GET(x) ((x >> 1) & 0x01)

/*! First Byte Transfer */
#define I2C_BSR_FBT_POS 0
#define I2C_BSR_FBT_LEN 1
#define I2C_BSR_FBT_MASK 0x01
#define I2C_BSR_FBT_SET(x) (x)
#define I2C_BSR_FBT_GET(x) (x & 0x01)

/****************************************************
  ::BCR:: BitField descriptions
****************************************************/
/*! BUS Error */
#define I2C_BCR_BER_POS 7
#define I2C_BCR_BER_LEN 1
#define I2C_BCR_BER_MASK 0x80
#define I2C_BCR_BER_SET(x) (x << 7)
#define I2C_BCR_BER_GET(x) ((x >> 7) & 0x01)

/*! BUS Error Interrupt Enable */
#define I2C_BCR_BEIE_POS 6
#define I2C_BCR_BEIE_LEN 1
#define I2C_BCR_BEIE_MASK 0x40
#define I2C_BCR_BEIE_SET(x) (x << 6)
#define I2C_BCR_BEIE_GET(x) ((x >> 6) & 0x01)

/*! Start Condition Continue */
#define I2C_BCR_SCC_POS 5
#define I2C_BCR_SCC_LEN 1
#define I2C_BCR_SCC_MASK 0x20
#define I2C_BCR_SCC_SET(x) (x << 5)
#define I2C_BCR_SCC_GET(x) ((x >> 5) & 0x01)

/*! Master Slave Select */
#define I2C_BCR_MSS_POS 4
#define I2C_BCR_MSS_LEN 1
#define I2C_BCR_MSS_MASK 0x10
#define I2C_BCR_MSS_SET(x) (x << 4)
#define I2C_BCR_MSS_GET(x) ((x >> 4) & 0x01)

/*! Acknowledge */
#define I2C_BCR_ACK_POS 3
#define I2C_BCR_ACK_LEN 1
#define I2C_BCR_ACK_MASK 0x08
#define I2C_BCR_ACK_SET(x) (x << 3)
#define I2C_BCR_ACK_GET(x) ((x >> 3) & 0x01)

/*! General Call Address Acknowledge */
#define I2C_BCR_GCAA_POS 2
#define I2C_BCR_GCAA_LEN 1
#define I2C_BCR_GCAA_MASK 0x04
#define I2C_BCR_GCAA_SET(x) (x << 2)
#define I2C_BCR_GCAA_GET(x) ((x >> 2) & 0x01)

/*! Interrupt Enable */
#define I2C_BCR_INTE_POS 1
#define I2C_BCR_INTE_LEN 1
#define I2C_BCR_INTE_MASK 0x02
#define I2C_BCR_INTE_SET(x) (x << 1)
#define I2C_BCR_INTE_GET(x) ((x >> 1) & 0x01)

/*! Interrupt */
#define I2C_BCR_INT_POS 0
#define I2C_BCR_INT_LEN 1
#define I2C_BCR_INT_MASK 0x01
#define I2C_BCR_INT_SET(x) (x)
#define I2C_BCR_INT_GET(x) (x & 0x01)

/****************************************************
  ::CCR:: BitField descriptions
****************************************************/
/*! Fast Mode Select */
#define I2C_CCR_FM_POS 6
#define I2C_CCR_FM_LEN 1
#define I2C_CCR_FM_MASK 0x40
#define I2C_CCR_FM_SET(x) (x << 6)
#define I2C_CCR_FM_GET(x) ((x >> 6) & 0x01)

#define I2C_CCR_FM_STANd_0 0x00
#define I2C_CCR_FM_FAST_1 0x01
/*! Enable */
#define I2C_CCR_EN_POS 5
#define I2C_CCR_EN_LEN 1
#define I2C_CCR_EN_MASK 0x20
#define I2C_CCR_EN_SET(x) (x << 5)
#define I2C_CCR_EN_GET(x) ((x >> 5) & 0x01)

/*! Clock Period select */
#define I2C_CCR_CS_POS 0
#define I2C_CCR_CS_LEN 5
#define I2C_CCR_CS_MASK 0x1f
#define I2C_CCR_CS_SET(x) (x)
#define I2C_CCR_CS_GET(x) (x & 0x1f)

/****************************************************
  ::ADR:: BitField descriptions
****************************************************/
/*! Address */
#define I2C_ADR_ADRESS_POS 0
#define I2C_ADR_ADRESS_LEN 7
#define I2C_ADR_ADRESS_MASK 0x7f
#define I2C_ADR_ADRESS_SET(x) (x)
#define I2C_ADR_ADRESS_GET(x) (x & 0x7f)

/****************************************************
  ::DAR:: BitField descriptions
****************************************************/
/*! DATA */
#define I2C_DAR_DATA_POS 0
#define I2C_DAR_DATA_LEN 8
#define I2C_DAR_DATA_MASK 0xff
#define I2C_DAR_DATA_SET(x) (x)
#define I2C_DAR_DATA_GET(x) (x & 0xff)

/****************************************************
  ::BCR2:: BitField descriptions
****************************************************/
/*! SDA Status */
#define I2C_BCR2_SDAS_POS 5
#define I2C_BCR2_SDAS_LEN 1
#define I2C_BCR2_SDAS_MASK 0x20
#define I2C_BCR2_SDAS_SET(x) (x << 5)
#define I2C_BCR2_SDAS_GET(x) ((x >> 5) & 0x01)

/*! SCL Status */
#define I2C_BCR2_SCLS_POS 4
#define I2C_BCR2_SCLS_LEN 1
#define I2C_BCR2_SCLS_MASK 0x10
#define I2C_BCR2_SCLS_SET(x) (x << 4)
#define I2C_BCR2_SCLS_GET(x) ((x >> 4) & 0x01)

/*! SDA Low Drive */
#define I2C_BCR2_SDAL_POS 1
#define I2C_BCR2_SDAL_LEN 1
#define I2C_BCR2_SDAL_MASK 0x02
#define I2C_BCR2_SDAL_SET(x) (x << 1)
#define I2C_BCR2_SDAL_GET(x) ((x >> 1) & 0x01)

/*! SCL Low Drive */
#define I2C_BCR2_SCLL_POS 0
#define I2C_BCR2_SCLL_LEN 1
#define I2C_BCR2_SCLL_MASK 0x01
#define I2C_BCR2_SCLL_SET(x) (x)
#define I2C_BCR2_SCLL_GET(x) (x & 0x01)

/****************************************************
  ::CSR:: BitField descriptions
****************************************************/
/*! Test Mode Select */
#define I2C_CSR_TST_POS 6
#define I2C_CSR_TST_LEN 2
#define I2C_CSR_TST_MASK 0xc0
#define I2C_CSR_TST_SET(x) (x << 6)
#define I2C_CSR_TST_GET(x) ((x >> 6) & 0x03)

#define I2C_CSR_TST_TST_0 0x00
#define I2C_CSR_TST_TST_1 0x01
/*! Clock Period Select */
#define I2C_CSR_CS_POS 0
#define I2C_CSR_CS_LEN 6
#define I2C_CSR_CS_MASK 0x3f
#define I2C_CSR_CS_SET(x) (x)
#define I2C_CSR_CS_GET(x) (x & 0x3f)

/****************************************************
  ::FSR:: BitField descriptions
****************************************************/
/*! Bus Clock Frequency Select */
#define I2C_FSR_FS_POS 0
#define I2C_FSR_FS_LEN 4
#define I2C_FSR_FS_MASK 0x0f
#define I2C_FSR_FS_SET(x) (x)
#define I2C_FSR_FS_GET(x) (x & 0x0f)

#define I2C_FSR_FS_FS_0 0x00
#define I2C_FSR_FS_FS_1 0x01
#define I2C_FSR_FS_FS_2 0x02
#define I2C_FSR_FS_FS_3 0x03
#define I2C_FSR_FS_FS_4 0x04
#define I2C_FSR_FS_FS_5 0x05
#define I2C_FSR_FS_FS_6 0x06
#define I2C_FSR_FS_FS_7 0x07
#define I2C_FSR_FS_FS_8 0x08
#define I2C_FSR_FS_FS_9 0x09
#define I2C_FSR_FS_FS_A 0x0a
#define I2C_FSR_FS_FS_B 0x0b

#endif /* __I2C_REG_H_*/
