#ifndef __I3C_REG_H_
#define __I3C_REG_H_

#include "common.h"

typedef struct {
    __IO uint32_t rr0;
    __IO uint32_t rr1;
    __IO uint32_t rr2;
    uint32_t reserved;
} device_reg_t;

typedef struct {
    __O uint32_t ier;
    __O uint32_t idr;
    __I uint32_t imr;
    __O uint32_t icr;
    __I uint32_t isr;
} device_intr_reg_t;

typedef struct {
    __I uint32_t dev_id;
    __I uint32_t conf_status0;
    __I uint32_t conf_status1;
    __I uint32_t rev_id;
    __IO uint32_t ctrl;
    __IO uint32_t prescl_ctrl0;
    __IO uint32_t prescl_ctrl1;
    uint32_t reserved0;
    device_intr_reg_t mst_intr;
    __IO uint32_t mst_status0;
    __I uint32_t cmdr;
    __I uint32_t ibir;
    device_intr_reg_t slv_intr;
    __I uint32_t slv_status0;
    __I uint32_t slv_status1;
    uint32_t reserved1;
    __O uint32_t cmd0_fifo;
    __O uint32_t cmd1_fifo;
    __O uint32_t tx_fifo;
    uint32_t reserved2;
    __O uint32_t imd_cmd0;
    __O uint32_t imd_cmd1;
    __IO uint32_t imd_data;
    uint32_t reserved3;
    __I uint32_t rx_fifo;
    __I uint32_t ibi_data_fifo;
    __O uint32_t slv_ddr_tx_fifo;
    __I uint32_t slv_ddr_rx_fifo;
    __IO uint32_t cmd_ibi_thr_ctrl;
    __IO uint32_t tx_rx_thr_ctrl;
    __IO uint32_t slv_ddr_tx_rx_thr_ctrl;
    __O uint32_t flush_ctrl;
    uint32_t reserved4[4];
    __IO uint32_t tto_prescl_ctrl0;
    __IO uint32_t tto_prescl_ctrl1;
    __IO uint32_t devs_ctrl;
    uint32_t reserved5;
    device_reg_t device_id[8];
    uint32_t reserved6[17];
    __IO uint32_t sir_map0;
    __IO uint32_t sir_map1;
    uint32_t reserved7[6];
    __I uint32_t gpir_word0;
    __I uint32_t gpir_word1;
    uint32_t reserved8[30];
    __I uint32_t gpor_word0;
    __I uint32_t gpor_word1;
} i3c_reg_t;

typedef struct {
    __IO uint32_t asf_int_status;
    __IO uint32_t asf_int_raw_status;
    __IO uint32_t asf_int_mask;
    __IO uint32_t asf_int_test;
    __IO uint32_t asf_fatal_nonfatal_select;
    uint32_t reserved0[4];
    __I uint32_t asf_sram_corr_fault_status;
    __I uint32_t asf_sram_uncorr_fault_status;
    __IO uint32_t asf_sram_fault_stats;
    uint32_t reserved1;
    __IO uint32_t asf_trans_to_ctrl;
    __IO uint32_t asf_trans_to_fault_mask;
    __IO uint32_t asf_trans_to_fault_status;
    uint32_t reserved2;
    __IO uint32_t asf_protocol_fault_mask;
    __IO uint32_t asf_protocol_fault_status;
} i3c_status_reg_t;

#define I3C_STATUS_REG_OFFSET 0x300

#define I3C ((i3c_reg_t*)I3C_BASE)
#define I3C_STATUS ((i3c_status_reg_t*)(I3C_BASE + I3C_STATUS_REG_OFFSET))

/****************************************************
  ::DEV_ID:: BitField descriptions
****************************************************/
/*! Cadence IP Device ID */
#define I3C_DEV_ID_ID_POS 0
#define I3C_DEV_ID_ID_LEN 15
#define I3C_DEV_ID_ID_MASK 0x00007fff
#define I3C_DEV_ID_ID_SET(x) (x << 0)
#define I3C_DEV_ID_ID_GET(x) ((x >> 0) & 0x00007fff)

/****************************************************
  ::CONF_STATUS0:: BitField descriptions
****************************************************/
/*! depth of Commands Response Queue */
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_POS 29
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_LEN 3
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_MASK 0xe0000000
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_SET(x) (x << 29)
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_GET(x) ((x >> 29) & 0x00000007)

#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_CMDR_DEPTH_4 0x00000
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_CMDR_DEPTH_8 0x00001
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_CMDR_DEPTH_16 0x00002
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_CMDR_DEPTH_32 0x00003
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_CMDR_DEPTH_64 0x00004
#define I3C_CONF_STATUS0_CMDR_MEM_DEPTH_CMDR_DEPTH_NA 0x00006
/*! supported ASF checks */
#define I3C_CONF_STATUS0_ASF_POS 24
#define I3C_CONF_STATUS0_ASF_LEN 5
#define I3C_CONF_STATUS0_ASF_MASK 0x1f000000
#define I3C_CONF_STATUS0_ASF_SET(x) (x << 24)
#define I3C_CONF_STATUS0_ASF_GET(x) ((x >> 24) & 0x0000001f)

#define I3C_CONF_STATUS0_ASF_ASF_ECC 0x00004
#define I3C_CONF_STATUS0_ASF_ASF_INTEDRITY 0x00003
#define I3C_CONF_STATUS0_ASF_ASF_CSR_DAP 0x00002
#define I3C_CONF_STATUS0_ASF_ASF_TRANS_TIMEOUT 0x00001
#define I3C_CONF_STATUS0_ASF_ASF_PROTOCOL_FAULTS 0x00000
/*! Returns the value of User GPO (1-126) */
#define I3C_CONF_STATUS0_GPO_POS 16
#define I3C_CONF_STATUS0_GPO_LEN 8
#define I3C_CONF_STATUS0_GPO_MASK 0x00ff0000
#define I3C_CONF_STATUS0_GPO_SET(x) (x << 16)
#define I3C_CONF_STATUS0_GPO_GET(x) ((x >> 16) & 0x000000ff)

/*! Returns the value of User GPI (1-126) */
#define I3C_CONF_STATUS0_GPI_POS 8
#define I3C_CONF_STATUS0_GPI_LEN 8
#define I3C_CONF_STATUS0_GPI_MASK 0x0000ff00
#define I3C_CONF_STATUS0_GPI_SET(x) (x << 8)
#define I3C_CONF_STATUS0_GPI_GET(x) ((x >> 8) & 0x000000ff)

/*! depth of IBI Response Queue */
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_POS 6
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_LEN 2
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_MASK 0x000000c0
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_SET(x) (x << 6)
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_GET(x) ((x >> 6) & 0x00000003)

#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_IBIR_DEPTH_4 0x00000
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_IBIR_DEPTH_8 0x00001
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_IBIR_DEPTH_16 0x00002
#define I3C_CONF_STATUS0_IBIR_MEM_DEPTH_IBIR_DEPTH_32 0x00003
/*!  DDR is supported */
#define I3C_CONF_STATUS0_DDR_POS 5
#define I3C_CONF_STATUS0_DDR_LEN 1
#define I3C_CONF_STATUS0_DDR_MASK 0x00000020
#define I3C_CONF_STATUS0_DDR_SET(x) (x << 5)
#define I3C_CONF_STATUS0_DDR_GET(x) ((x >> 5) & 0x00000001)

/*!  Device Role (MM/SM) */
#define I3C_CONF_STATUS0_DEV_ROLE_POS 4
#define I3C_CONF_STATUS0_DEV_ROLE_LEN 1
#define I3C_CONF_STATUS0_DEV_ROLE_MASK 0x00000010
#define I3C_CONF_STATUS0_DEV_ROLE_SET(x) (x << 4)
#define I3C_CONF_STATUS0_DEV_ROLE_GET(x) ((x >> 4) & 0x00000001)

#define I3C_CONF_STATUS0_DEV_ROLE_DEV_ROLE_MM 0x00000
#define I3C_CONF_STATUS0_DEV_ROLE_DEV_ROLE_SM 0x00001
/*!  number of retaining registers for I3C Slave devices */
#define I3C_CONF_STATUS0_DEVS_NUM_POS 0
#define I3C_CONF_STATUS0_DEVS_NUM_LEN 4
#define I3C_CONF_STATUS0_DEVS_NUM_MASK 0x0000000f
#define I3C_CONF_STATUS0_DEVS_NUM_SET(x) (x << 0)
#define I3C_CONF_STATUS0_DEVS_NUM_GET(x) ((x >> 0) & 0x0000000f)

/****************************************************
  ::CONF_STATUS1:: BitField descriptions
****************************************************/
/*! HW resources for IBI capable devices */
#define I3C_CONF_STATUS1_IBI_HW_RES_POS 28
#define I3C_CONF_STATUS1_IBI_HW_RES_LEN 4
#define I3C_CONF_STATUS1_IBI_HW_RES_MASK 0xf0000000
#define I3C_CONF_STATUS1_IBI_HW_RES_SET(x) (x << 28)
#define I3C_CONF_STATUS1_IBI_HW_RES_GET(x) ((x >> 28) & 0x0000000f)

#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP1 0x00000
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP2 0x00002
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP3 0x00003
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP4 0x00004
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP5 0x00005
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP6 0x00006
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP7 0x00007
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP8 0x00008
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP9 0x00009
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP10 0x0000a
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP11 0x0000b
#define I3C_CONF_STATUS1_IBI_HW_RES_SIR_MAP_NA 0x0000c
/*!  depth of Command Memory */
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_POS 26
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_LEN 2
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_MASK 0x0c000000
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_SET(x) (x << 26)
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_GET(x) ((x >> 26) & 0x00000003)

#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_CMD_DEPTH_4 0x00000
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_CMD_DEPTH_8 0x00001
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_CMD_DEPTH_16 0x00002
#define I3C_CONF_STATUS1_CMD_MEM_DEPTH_CMD_DEPTH_32 0x00003
/*!  depth of Slave DDR Rx Memory */
#define I3C_CONF_STATUS1_SLV_DDR_RX_MEM_DEPTH_POS 21
#define I3C_CONF_STATUS1_SLV_DDR_RX_MEM_DEPTH_LEN 5
#define I3C_CONF_STATUS1_SLV_DDR_RX_MEM_DEPTH_MASK 0x03e00000
#define I3C_CONF_STATUS1_SLV_DDR_RX_MEM_DEPTH_SET(x) (x << 21)
#define I3C_CONF_STATUS1_SLV_DDR_RX_MEM_DEPTH_GET(x) ((x >> 21) & 0x0000001f)

/*!  depth of Slave DDR Tx Memory */
#define I3C_CONF_STATUS1_SLV_DDR_TX_MEM_DEPTH_POS 16
#define I3C_CONF_STATUS1_SLV_DDR_TX_MEM_DEPTH_LEN 5
#define I3C_CONF_STATUS1_SLV_DDR_TX_MEM_DEPTH_MASK 0x001f0000
#define I3C_CONF_STATUS1_SLV_DDR_TX_MEM_DEPTH_SET(x) (x << 16)
#define I3C_CONF_STATUS1_SLV_DDR_TX_MEM_DEPTH_GET(x) ((x >> 16) & 0x0000001f)

/*!  depth of In-Band Interrupt Memory */
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_POS 10
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_LEN 3
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_MASK 0x00001c00
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_SET(x) (x << 10)
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_GET(x) ((x >> 10) & 0x00000007)

#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_2 0x00000
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_4 0x00001
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_8 0x00002
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_16 0x00003
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_32 0x00004
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_64 0x00005
#define I3C_CONF_STATUS1_IBI_MEM_DEPTH_IBI_DEPTH_NA 0x00006
/*!  depth of Rx Memory */
#define I3C_CONF_STATUS1_RX_MEM_DEPTH_POS 5
#define I3C_CONF_STATUS1_RX_MEM_DEPTH_LEN 5
#define I3C_CONF_STATUS1_RX_MEM_DEPTH_MASK 0x000003e0
#define I3C_CONF_STATUS1_RX_MEM_DEPTH_SET(x) (x << 5)
#define I3C_CONF_STATUS1_RX_MEM_DEPTH_GET(x) ((x >> 5) & 0x0000001f)

/*!  depth of Tx Memory */
#define I3C_CONF_STATUS1_TX_MEM_DEPTH_POS 0
#define I3C_CONF_STATUS1_TX_MEM_DEPTH_LEN 5
#define I3C_CONF_STATUS1_TX_MEM_DEPTH_MASK 0x0000001f
#define I3C_CONF_STATUS1_TX_MEM_DEPTH_SET(x) (x << 0)
#define I3C_CONF_STATUS1_TX_MEM_DEPTH_GET(x) ((x >> 0) & 0x0000001f)

/****************************************************
  ::REV_ID:: BitField descriptions
****************************************************/
/*! VENDOR ID */
#define I3C_REV_ID_VENDOR_ID_POS 20
#define I3C_REV_ID_VENDOR_ID_LEN 12
#define I3C_REV_ID_VENDOR_ID_MASK 0xfff00000
#define I3C_REV_ID_VENDOR_ID_SET(x) (x << 20)
#define I3C_REV_ID_VENDOR_ID_GET(x) ((x >> 20) & 0x00000fff)

/*! PRODUCT ID */
#define I3C_REV_ID_PRODUCT_ID_POS 8
#define I3C_REV_ID_PRODUCT_ID_LEN 12
#define I3C_REV_ID_PRODUCT_ID_MASK 0x000fff00
#define I3C_REV_ID_PRODUCT_ID_SET(x) (x << 8)
#define I3C_REV_ID_PRODUCT_ID_GET(x) ((x >> 8) & 0x00000fff)

/*! Major revision value */
#define I3C_REV_ID_REV_MAJOR_POS 5
#define I3C_REV_ID_REV_MAJOR_LEN 3
#define I3C_REV_ID_REV_MAJOR_MASK 0x000000e0
#define I3C_REV_ID_REV_MAJOR_SET(x) (x << 5)
#define I3C_REV_ID_REV_MAJOR_GET(x) ((x >> 5) & 0x00000007)

/*! Minor revision value */
#define I3C_REV_ID_REV_MINOR_POS 0
#define I3C_REV_ID_REV_MINOR_LEN 5
#define I3C_REV_ID_REV_MINOR_MASK 0x0000001f
#define I3C_REV_ID_REV_MINOR_SET(x) (x << 0)
#define I3C_REV_ID_REV_MINOR_GET(x) ((x >> 0) & 0x0000001f)

/****************************************************
  ::CTRL:: BitField descriptions
****************************************************/
/*! When set HIGH the I3C-Master is enabled */
#define I3C_CTRL_DEV_EN_POS 31
#define I3C_CTRL_DEV_EN_LEN 1
#define I3C_CTRL_DEV_EN_MASK 0x80000000
#define I3C_CTRL_DEV_EN_SET(x) (x << 31)
#define I3C_CTRL_DEV_EN_GET(x) ((x >> 31) & 0x00000001)

/*! HALT or Abort */
#define I3C_CTRL_HALT_EN_POS 30
#define I3C_CTRL_HALT_EN_LEN 1
#define I3C_CTRL_HALT_EN_MASK 0x40000000
#define I3C_CTRL_HALT_EN_SET(x) (x << 30)
#define I3C_CTRL_HALT_EN_GET(x) ((x >> 30) & 0x00000001)

/*! starts execution of the commands */
#define I3C_CTRL_MCS_POS 29
#define I3C_CTRL_MCS_LEN 1
#define I3C_CTRL_MCS_MASK 0x20000000
#define I3C_CTRL_MCS_SET(x) (x << 29)
#define I3C_CTRL_MCS_GET(x) ((x >> 29) & 0x00000001)

/*! wait to start command execution until mcs bit set */
#define I3C_CTRL_MCS_EN_POS 28
#define I3C_CTRL_MCS_EN_LEN 1
#define I3C_CTRL_MCS_EN_MASK 0x10000000
#define I3C_CTRL_MCS_EN_SET(x) (x << 28)
#define I3C_CTRL_MCS_EN_GET(x) ((x >> 28) & 0x00000001)

/*! HW response for ACK'ed HJ request */
#define I3C_CTRL_HJ_DISEC_POS 8
#define I3C_CTRL_HJ_DISEC_LEN 1
#define I3C_CTRL_HJ_DISEC_MASK 0x00000100
#define I3C_CTRL_HJ_DISEC_SET(x) (x << 8)
#define I3C_CTRL_HJ_DISEC_GET(x) ((x >> 8) & 0x00000001)

/*! ACK response type for GETACCMST CCC */
#define I3C_CTRL_MST_ACK_POS 7
#define I3C_CTRL_MST_ACK_LEN 1
#define I3C_CTRL_MST_ACK_MASK 0x00000080
#define I3C_CTRL_MST_ACK_SET(x) (x << 7)
#define I3C_CTRL_MST_ACK_GET(x) ((x >> 7) & 0x00000001)

/*! ACK response type for HJ request */
#define I3C_CTRL_HJ_ACK_POS 6
#define I3C_CTRL_HJ_ACK_LEN 1
#define I3C_CTRL_HJ_ACK_MASK 0x00000040
#define I3C_CTRL_HJ_ACK_SET(x) (x << 6)
#define I3C_CTRL_HJ_ACK_GET(x) ((x >> 6) & 0x00000001)

/*! Initiate HJ request */
#define I3C_CTRL_HJ_INIT_POS 5
#define I3C_CTRL_HJ_INIT_LEN 1
#define I3C_CTRL_HJ_INIT_MASK 0x00000020
#define I3C_CTRL_HJ_INIT_SET(x) (x << 5)
#define I3C_CTRL_HJ_INIT_GET(x) ((x >> 5) & 0x00000001)

/*! Initiate Mastership request */
#define I3C_CTRL_MST_INIT_POS 4
#define I3C_CTRL_MST_INIT_LEN 1
#define I3C_CTRL_MST_INIT_MASK 0x00000010
#define I3C_CTRL_MST_INIT_SET(x) (x << 4)
#define I3C_CTRL_MST_INIT_GET(x) ((x >> 4) & 0x00000001)

/*! Address Header optimization */
#define I3C_CTRL_AHDR_OPT_POS 3
#define I3C_CTRL_AHDR_OPT_LEN 1
#define I3C_CTRL_AHDR_OPT_MASK 0x00000008
#define I3C_CTRL_AHDR_OPT_SET(x) (x << 3)
#define I3C_CTRL_AHDR_OPT_GET(x) ((x >> 3) & 0x00000001)

/*! Bus Mode */
#define I3C_CTRL_BUS_MODE_POS 0
#define I3C_CTRL_BUS_MODE_LEN 2
#define I3C_CTRL_BUS_MODE_MASK 0x00000003
#define I3C_CTRL_BUS_MODE_SET(x) (x << 0)
#define I3C_CTRL_BUS_MODE_GET(x) ((x >> 0) & 0x00000003)

#define I3C_CTRL_BUS_MODE_BUS_MODE_PURE 0x00000
#define I3C_CTRL_BUS_MODE_BUS_MODE_INVALID 0x00001
#define I3C_CTRL_BUS_MODE_BUS_MODE_MIXED_FAST 0x00002
#define I3C_CTRL_BUS_MODE_BUS_MODE_MIXED_SLOW 0x00003
/****************************************************
  ::PRESCL_CTRL0:: BitField descriptions
****************************************************/
/*! Prescaler value for I2C SCL clock generation */
#define I3C_PRESCL_CTRL0_I2C_POS 16
#define I3C_PRESCL_CTRL0_I2C_LEN 16
#define I3C_PRESCL_CTRL0_I2C_MASK 0xffff0000
#define I3C_PRESCL_CTRL0_I2C_SET(x) (x << 16)
#define I3C_PRESCL_CTRL0_I2C_GET(x) ((x >> 16) & 0x0000ffff)

/*! Prescaler value for I3C Push-Pull SDR Mode SCL clock generation */
#define I3C_PRESCL_CTRL0_I3C_POS 0
#define I3C_PRESCL_CTRL0_I3C_LEN 10
#define I3C_PRESCL_CTRL0_I3C_MASK 0x000003ff
#define I3C_PRESCL_CTRL0_I3C_SET(x) (x << 0)
#define I3C_PRESCL_CTRL0_I3C_GET(x) ((x >> 0) & 0x000003ff)

/****************************************************
  ::PRESCL_CTRL1:: BitField descriptions
****************************************************/
/*! Counter for low period of SCL clock for Push Pull in I3C */
#define I3C_PRESCL_CTRL1_PP_LOW_POS 8
#define I3C_PRESCL_CTRL1_PP_LOW_LEN 8
#define I3C_PRESCL_CTRL1_PP_LOW_MASK 0x0000ff00
#define I3C_PRESCL_CTRL1_PP_LOW_SET(x) (x << 8)
#define I3C_PRESCL_CTRL1_PP_LOW_GET(x) ((x >> 8) & 0x000000ff)

/*! Counter for low period of SCL clock for Open Drain in I3C */
#define I3C_PRESCL_CTRL1_OD_LOW_POS 0
#define I3C_PRESCL_CTRL1_OD_LOW_LEN 8
#define I3C_PRESCL_CTRL1_OD_LOW_MASK 0x000000ff
#define I3C_PRESCL_CTRL1_OD_LOW_SET(x) (x << 0)
#define I3C_PRESCL_CTRL1_OD_LOW_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::MST_IER:: BitField descriptions
****************************************************/
/*! CORE HALTED interrupt Enable. */
#define I3C_MST_IER_HALTED_POS 18
#define I3C_MST_IER_HALTED_LEN 1
#define I3C_MST_IER_HALTED_MASK 0x00040000
#define I3C_MST_IER_HALTED_SET(x) (x << 18)
#define I3C_MST_IER_HALTED_GET(x) ((x >> 18) & 0x00000001)

/*! MR_DONE */
#define I3C_MST_IER_MR_DONE_POS 17
#define I3C_MST_IER_MR_DONE_LEN 1
#define I3C_MST_IER_MR_DONE_MASK 0x00020000
#define I3C_MST_IER_MR_DONE_SET(x) (x << 17)
#define I3C_MST_IER_MR_DONE_GET(x) ((x >> 17) & 0x00000001)

/*! IMM_COMP */
#define I3C_MST_IER_IMM_COMP_POS 16
#define I3C_MST_IER_IMM_COMP_LEN 1
#define I3C_MST_IER_IMM_COMP_MASK 0x00010000
#define I3C_MST_IER_IMM_COMP_SET(x) (x << 16)
#define I3C_MST_IER_IMM_COMP_GET(x) ((x >> 16) & 0x00000001)

/*! TX_THR */
#define I3C_MST_IER_TX_THR_POS 15
#define I3C_MST_IER_TX_THR_LEN 1
#define I3C_MST_IER_TX_THR_MASK 0x00008000
#define I3C_MST_IER_TX_THR_SET(x) (x << 15)
#define I3C_MST_IER_TX_THR_GET(x) ((x >> 15) & 0x00000001)

/*! TX_OVF */
#define I3C_MST_IER_TX_OVF_POS 14
#define I3C_MST_IER_TX_OVF_LEN 1
#define I3C_MST_IER_TX_OVF_MASK 0x00004000
#define I3C_MST_IER_TX_OVF_SET(x) (x << 14)
#define I3C_MST_IER_TX_OVF_GET(x) ((x >> 14) & 0x00000001)

/*! IBID_THR */
#define I3C_MST_IER_IBID_THR_POS 12
#define I3C_MST_IER_IBID_THR_LEN 1
#define I3C_MST_IER_IBID_THR_MASK 0x00001000
#define I3C_MST_IER_IBID_THR_SET(x) (x << 12)
#define I3C_MST_IER_IBID_THR_GET(x) ((x >> 12) & 0x00000001)

/*! IBID_UNF */
#define I3C_MST_IER_IBID_UNF_POS 11
#define I3C_MST_IER_IBID_UNF_LEN 1
#define I3C_MST_IER_IBID_UNF_MASK 0x00000800
#define I3C_MST_IER_IBID_UNF_SET(x) (x << 11)
#define I3C_MST_IER_IBID_UNF_GET(x) ((x >> 11) & 0x00000001)

/*! IBIR_THR */
#define I3C_MST_IER_IBIR_THR_POS 10
#define I3C_MST_IER_IBIR_THR_LEN 1
#define I3C_MST_IER_IBIR_THR_MASK 0x00000400
#define I3C_MST_IER_IBIR_THR_SET(x) (x << 10)
#define I3C_MST_IER_IBIR_THR_GET(x) ((x >> 10) & 0x00000001)

/*! IBIR_UNF */
#define I3C_MST_IER_IBIR_UNF_POS 9
#define I3C_MST_IER_IBIR_UNF_LEN 1
#define I3C_MST_IER_IBIR_UNF_MASK 0x00000200
#define I3C_MST_IER_IBIR_UNF_SET(x) (x << 9)
#define I3C_MST_IER_IBIR_UNF_GET(x) ((x >> 9) & 0x00000001)

/*! IBIR_OVF */
#define I3C_MST_IER_IBIR_OVF_POS 8
#define I3C_MST_IER_IBIR_OVF_LEN 1
#define I3C_MST_IER_IBIR_OVF_MASK 0x00000100
#define I3C_MST_IER_IBIR_OVF_SET(x) (x << 8)
#define I3C_MST_IER_IBIR_OVF_GET(x) ((x >> 8) & 0x00000001)

/*! RX_THR */
#define I3C_MST_IER_RX_THR_POS 7
#define I3C_MST_IER_RX_THR_LEN 1
#define I3C_MST_IER_RX_THR_MASK 0x00000080
#define I3C_MST_IER_RX_THR_SET(x) (x << 7)
#define I3C_MST_IER_RX_THR_GET(x) ((x >> 7) & 0x00000001)

/*! RX_UNF */
#define I3C_MST_IER_RX_UNF_POS 6
#define I3C_MST_IER_RX_UNF_LEN 1
#define I3C_MST_IER_RX_UNF_MASK 0x00000040
#define I3C_MST_IER_RX_UNF_SET(x) (x << 6)
#define I3C_MST_IER_RX_UNF_GET(x) ((x >> 6) & 0x00000001)

/*! CMDD_EMP */
#define I3C_MST_IER_CMDD_EMP_POS 5
#define I3C_MST_IER_CMDD_EMP_LEN 1
#define I3C_MST_IER_CMDD_EMP_MASK 0x00000020
#define I3C_MST_IER_CMDD_EMP_SET(x) (x << 5)
#define I3C_MST_IER_CMDD_EMP_GET(x) ((x >> 5) & 0x00000001)

/*! CMDD_THR */
#define I3C_MST_IER_CMDD_THR_POS 4
#define I3C_MST_IER_CMDD_THR_LEN 1
#define I3C_MST_IER_CMDD_THR_MASK 0x00000010
#define I3C_MST_IER_CMDD_THR_SET(x) (x << 4)
#define I3C_MST_IER_CMDD_THR_GET(x) ((x >> 4) & 0x00000001)

/*! CMDD_OVF */
#define I3C_MST_IER_CMDD_OVF_POS 3
#define I3C_MST_IER_CMDD_OVF_LEN 1
#define I3C_MST_IER_CMDD_OVF_MASK 0x00000008
#define I3C_MST_IER_CMDD_OVF_SET(x) (x << 3)
#define I3C_MST_IER_CMDD_OVF_GET(x) ((x >> 3) & 0x00000001)

/*! CMDR_THR */
#define I3C_MST_IER_CMDR_THR_POS 2
#define I3C_MST_IER_CMDR_THR_LEN 1
#define I3C_MST_IER_CMDR_THR_MASK 0x00000004
#define I3C_MST_IER_CMDR_THR_SET(x) (x << 2)
#define I3C_MST_IER_CMDR_THR_GET(x) ((x >> 2) & 0x00000001)

/*! CMDR_UNF */
#define I3C_MST_IER_CMDR_UNF_POS 1
#define I3C_MST_IER_CMDR_UNF_LEN 1
#define I3C_MST_IER_CMDR_UNF_MASK 0x00000002
#define I3C_MST_IER_CMDR_UNF_SET(x) (x << 1)
#define I3C_MST_IER_CMDR_UNF_GET(x) ((x >> 1) & 0x00000001)

/*! CMDR_OVF */
#define I3C_MST_IER_CMDR_OVF_POS 0
#define I3C_MST_IER_CMDR_OVF_LEN 1
#define I3C_MST_IER_CMDR_OVF_MASK 0x00000001
#define I3C_MST_IER_CMDR_OVF_SET(x) (x << 0)
#define I3C_MST_IER_CMDR_OVF_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::MST_IDR:: BitField descriptions
****************************************************/
/*! CORE HALTED interrupt Enable. */
#define I3C_MST_IDR_HALTED_POS 18
#define I3C_MST_IDR_HALTED_LEN 1
#define I3C_MST_IDR_HALTED_MASK 0x00040000
#define I3C_MST_IDR_HALTED_SET(x) (x << 18)
#define I3C_MST_IDR_HALTED_GET(x) ((x >> 18) & 0x00000001)

/*! MR_DONE */
#define I3C_MST_IDR_MR_DONE_POS 17
#define I3C_MST_IDR_MR_DONE_LEN 1
#define I3C_MST_IDR_MR_DONE_MASK 0x00020000
#define I3C_MST_IDR_MR_DONE_SET(x) (x << 17)
#define I3C_MST_IDR_MR_DONE_GET(x) ((x >> 17) & 0x00000001)

/*! IMM_COMP */
#define I3C_MST_IDR_IMM_COMP_POS 16
#define I3C_MST_IDR_IMM_COMP_LEN 1
#define I3C_MST_IDR_IMM_COMP_MASK 0x00010000
#define I3C_MST_IDR_IMM_COMP_SET(x) (x << 16)
#define I3C_MST_IDR_IMM_COMP_GET(x) ((x >> 16) & 0x00000001)

/*! TX_THR */
#define I3C_MST_IDR_TX_THR_POS 15
#define I3C_MST_IDR_TX_THR_LEN 1
#define I3C_MST_IDR_TX_THR_MASK 0x00008000
#define I3C_MST_IDR_TX_THR_SET(x) (x << 15)
#define I3C_MST_IDR_TX_THR_GET(x) ((x >> 15) & 0x00000001)

/*! TX_OVF */
#define I3C_MST_IDR_TX_OVF_POS 14
#define I3C_MST_IDR_TX_OVF_LEN 1
#define I3C_MST_IDR_TX_OVF_MASK 0x00004000
#define I3C_MST_IDR_TX_OVF_SET(x) (x << 14)
#define I3C_MST_IDR_TX_OVF_GET(x) ((x >> 14) & 0x00000001)

/*! IBID_THR */
#define I3C_MST_IDR_IBID_THR_POS 12
#define I3C_MST_IDR_IBID_THR_LEN 1
#define I3C_MST_IDR_IBID_THR_MASK 0x00001000
#define I3C_MST_IDR_IBID_THR_SET(x) (x << 12)
#define I3C_MST_IDR_IBID_THR_GET(x) ((x >> 12) & 0x00000001)

/*! IBID_UNF */
#define I3C_MST_IDR_IBID_UNF_POS 11
#define I3C_MST_IDR_IBID_UNF_LEN 1
#define I3C_MST_IDR_IBID_UNF_MASK 0x00000800
#define I3C_MST_IDR_IBID_UNF_SET(x) (x << 11)
#define I3C_MST_IDR_IBID_UNF_GET(x) ((x >> 11) & 0x00000001)

/*! IBIR_THR */
#define I3C_MST_IDR_IBIR_THR_POS 10
#define I3C_MST_IDR_IBIR_THR_LEN 1
#define I3C_MST_IDR_IBIR_THR_MASK 0x00000400
#define I3C_MST_IDR_IBIR_THR_SET(x) (x << 10)
#define I3C_MST_IDR_IBIR_THR_GET(x) ((x >> 10) & 0x00000001)

/*! IBIR_UNF */
#define I3C_MST_IDR_IBIR_UNF_POS 9
#define I3C_MST_IDR_IBIR_UNF_LEN 1
#define I3C_MST_IDR_IBIR_UNF_MASK 0x00000200
#define I3C_MST_IDR_IBIR_UNF_SET(x) (x << 9)
#define I3C_MST_IDR_IBIR_UNF_GET(x) ((x >> 9) & 0x00000001)

/*! IBIR_OVF */
#define I3C_MST_IDR_IBIR_OVF_POS 8
#define I3C_MST_IDR_IBIR_OVF_LEN 1
#define I3C_MST_IDR_IBIR_OVF_MASK 0x00000100
#define I3C_MST_IDR_IBIR_OVF_SET(x) (x << 8)
#define I3C_MST_IDR_IBIR_OVF_GET(x) ((x >> 8) & 0x00000001)

/*! RX_THR */
#define I3C_MST_IDR_RX_THR_POS 7
#define I3C_MST_IDR_RX_THR_LEN 1
#define I3C_MST_IDR_RX_THR_MASK 0x00000080
#define I3C_MST_IDR_RX_THR_SET(x) (x << 7)
#define I3C_MST_IDR_RX_THR_GET(x) ((x >> 7) & 0x00000001)

/*! RX_UNF */
#define I3C_MST_IDR_RX_UNF_POS 6
#define I3C_MST_IDR_RX_UNF_LEN 1
#define I3C_MST_IDR_RX_UNF_MASK 0x00000040
#define I3C_MST_IDR_RX_UNF_SET(x) (x << 6)
#define I3C_MST_IDR_RX_UNF_GET(x) ((x >> 6) & 0x00000001)

/*! CMDD_EMP */
#define I3C_MST_IDR_CMDD_EMP_POS 5
#define I3C_MST_IDR_CMDD_EMP_LEN 1
#define I3C_MST_IDR_CMDD_EMP_MASK 0x00000020
#define I3C_MST_IDR_CMDD_EMP_SET(x) (x << 5)
#define I3C_MST_IDR_CMDD_EMP_GET(x) ((x >> 5) & 0x00000001)

/*! CMDD_THR */
#define I3C_MST_IDR_CMDD_THR_POS 4
#define I3C_MST_IDR_CMDD_THR_LEN 1
#define I3C_MST_IDR_CMDD_THR_MASK 0x00000010
#define I3C_MST_IDR_CMDD_THR_SET(x) (x << 4)
#define I3C_MST_IDR_CMDD_THR_GET(x) ((x >> 4) & 0x00000001)

/*! CMDD_OVF */
#define I3C_MST_IDR_CMDD_OVF_POS 3
#define I3C_MST_IDR_CMDD_OVF_LEN 1
#define I3C_MST_IDR_CMDD_OVF_MASK 0x00000008
#define I3C_MST_IDR_CMDD_OVF_SET(x) (x << 3)
#define I3C_MST_IDR_CMDD_OVF_GET(x) ((x >> 3) & 0x00000001)

/*! CMDR_THR */
#define I3C_MST_IDR_CMDR_THR_POS 2
#define I3C_MST_IDR_CMDR_THR_LEN 1
#define I3C_MST_IDR_CMDR_THR_MASK 0x00000004
#define I3C_MST_IDR_CMDR_THR_SET(x) (x << 2)
#define I3C_MST_IDR_CMDR_THR_GET(x) ((x >> 2) & 0x00000001)

/*! CMDR_UNF */
#define I3C_MST_IDR_CMDR_UNF_POS 1
#define I3C_MST_IDR_CMDR_UNF_LEN 1
#define I3C_MST_IDR_CMDR_UNF_MASK 0x00000002
#define I3C_MST_IDR_CMDR_UNF_SET(x) (x << 1)
#define I3C_MST_IDR_CMDR_UNF_GET(x) ((x >> 1) & 0x00000001)

/*! CMDR_OVF */
#define I3C_MST_IDR_CMDR_OVF_POS 0
#define I3C_MST_IDR_CMDR_OVF_LEN 1
#define I3C_MST_IDR_CMDR_OVF_MASK 0x00000001
#define I3C_MST_IDR_CMDR_OVF_SET(x) (x << 0)
#define I3C_MST_IDR_CMDR_OVF_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::MST_IMR:: BitField descriptions
****************************************************/
/*! CORE HALTED interrupt Enable. */
#define I3C_MST_IMR_HALTED_POS 18
#define I3C_MST_IMR_HALTED_LEN 1
#define I3C_MST_IMR_HALTED_MASK 0x00040000
#define I3C_MST_IMR_HALTED_SET(x) (x << 18)
#define I3C_MST_IMR_HALTED_GET(x) ((x >> 18) & 0x00000001)

/*! MR_DONE */
#define I3C_MST_IMR_MR_DONE_POS 17
#define I3C_MST_IMR_MR_DONE_LEN 1
#define I3C_MST_IMR_MR_DONE_MASK 0x00020000
#define I3C_MST_IMR_MR_DONE_SET(x) (x << 17)
#define I3C_MST_IMR_MR_DONE_GET(x) ((x >> 17) & 0x00000001)

/*! IMM_COMP */
#define I3C_MST_IMR_IMM_COMP_POS 16
#define I3C_MST_IMR_IMM_COMP_LEN 1
#define I3C_MST_IMR_IMM_COMP_MASK 0x00010000
#define I3C_MST_IMR_IMM_COMP_SET(x) (x << 16)
#define I3C_MST_IMR_IMM_COMP_GET(x) ((x >> 16) & 0x00000001)

/*! TX_THR */
#define I3C_MST_IMR_TX_THR_POS 15
#define I3C_MST_IMR_TX_THR_LEN 1
#define I3C_MST_IMR_TX_THR_MASK 0x00008000
#define I3C_MST_IMR_TX_THR_SET(x) (x << 15)
#define I3C_MST_IMR_TX_THR_GET(x) ((x >> 15) & 0x00000001)

/*! TX_OVF */
#define I3C_MST_IMR_TX_OVF_POS 14
#define I3C_MST_IMR_TX_OVF_LEN 1
#define I3C_MST_IMR_TX_OVF_MASK 0x00004000
#define I3C_MST_IMR_TX_OVF_SET(x) (x << 14)
#define I3C_MST_IMR_TX_OVF_GET(x) ((x >> 14) & 0x00000001)

/*! IBID_THR */
#define I3C_MST_IMR_IBID_THR_POS 12
#define I3C_MST_IMR_IBID_THR_LEN 1
#define I3C_MST_IMR_IBID_THR_MASK 0x00001000
#define I3C_MST_IMR_IBID_THR_SET(x) (x << 12)
#define I3C_MST_IMR_IBID_THR_GET(x) ((x >> 12) & 0x00000001)

/*! IBID_UNF */
#define I3C_MST_IMR_IBID_UNF_POS 11
#define I3C_MST_IMR_IBID_UNF_LEN 1
#define I3C_MST_IMR_IBID_UNF_MASK 0x00000800
#define I3C_MST_IMR_IBID_UNF_SET(x) (x << 11)
#define I3C_MST_IMR_IBID_UNF_GET(x) ((x >> 11) & 0x00000001)

/*! IBIR_THR */
#define I3C_MST_IMR_IBIR_THR_POS 10
#define I3C_MST_IMR_IBIR_THR_LEN 1
#define I3C_MST_IMR_IBIR_THR_MASK 0x00000400
#define I3C_MST_IMR_IBIR_THR_SET(x) (x << 10)
#define I3C_MST_IMR_IBIR_THR_GET(x) ((x >> 10) & 0x00000001)

/*! IBIR_UNF */
#define I3C_MST_IMR_IBIR_UNF_POS 9
#define I3C_MST_IMR_IBIR_UNF_LEN 1
#define I3C_MST_IMR_IBIR_UNF_MASK 0x00000200
#define I3C_MST_IMR_IBIR_UNF_SET(x) (x << 9)
#define I3C_MST_IMR_IBIR_UNF_GET(x) ((x >> 9) & 0x00000001)

/*! IBIR_OVF */
#define I3C_MST_IMR_IBIR_OVF_POS 8
#define I3C_MST_IMR_IBIR_OVF_LEN 1
#define I3C_MST_IMR_IBIR_OVF_MASK 0x00000100
#define I3C_MST_IMR_IBIR_OVF_SET(x) (x << 8)
#define I3C_MST_IMR_IBIR_OVF_GET(x) ((x >> 8) & 0x00000001)

/*! RX_THR */
#define I3C_MST_IMR_RX_THR_POS 7
#define I3C_MST_IMR_RX_THR_LEN 1
#define I3C_MST_IMR_RX_THR_MASK 0x00000080
#define I3C_MST_IMR_RX_THR_SET(x) (x << 7)
#define I3C_MST_IMR_RX_THR_GET(x) ((x >> 7) & 0x00000001)

/*! RX_UNF */
#define I3C_MST_IMR_RX_UNF_POS 6
#define I3C_MST_IMR_RX_UNF_LEN 1
#define I3C_MST_IMR_RX_UNF_MASK 0x00000040
#define I3C_MST_IMR_RX_UNF_SET(x) (x << 6)
#define I3C_MST_IMR_RX_UNF_GET(x) ((x >> 6) & 0x00000001)

/*! CMDD_EMP */
#define I3C_MST_IMR_CMDD_EMP_POS 5
#define I3C_MST_IMR_CMDD_EMP_LEN 1
#define I3C_MST_IMR_CMDD_EMP_MASK 0x00000020
#define I3C_MST_IMR_CMDD_EMP_SET(x) (x << 5)
#define I3C_MST_IMR_CMDD_EMP_GET(x) ((x >> 5) & 0x00000001)

/*! CMDD_THR */
#define I3C_MST_IMR_CMDD_THR_POS 4
#define I3C_MST_IMR_CMDD_THR_LEN 1
#define I3C_MST_IMR_CMDD_THR_MASK 0x00000010
#define I3C_MST_IMR_CMDD_THR_SET(x) (x << 4)
#define I3C_MST_IMR_CMDD_THR_GET(x) ((x >> 4) & 0x00000001)

/*! CMDD_OVF */
#define I3C_MST_IMR_CMDD_OVF_POS 3
#define I3C_MST_IMR_CMDD_OVF_LEN 1
#define I3C_MST_IMR_CMDD_OVF_MASK 0x00000008
#define I3C_MST_IMR_CMDD_OVF_SET(x) (x << 3)
#define I3C_MST_IMR_CMDD_OVF_GET(x) ((x >> 3) & 0x00000001)

/*! CMDR_THR */
#define I3C_MST_IMR_CMDR_THR_POS 2
#define I3C_MST_IMR_CMDR_THR_LEN 1
#define I3C_MST_IMR_CMDR_THR_MASK 0x00000004
#define I3C_MST_IMR_CMDR_THR_SET(x) (x << 2)
#define I3C_MST_IMR_CMDR_THR_GET(x) ((x >> 2) & 0x00000001)

/*! CMDR_UNF */
#define I3C_MST_IMR_CMDR_UNF_POS 1
#define I3C_MST_IMR_CMDR_UNF_LEN 1
#define I3C_MST_IMR_CMDR_UNF_MASK 0x00000002
#define I3C_MST_IMR_CMDR_UNF_SET(x) (x << 1)
#define I3C_MST_IMR_CMDR_UNF_GET(x) ((x >> 1) & 0x00000001)

/*! CMDR_OVF */
#define I3C_MST_IMR_CMDR_OVF_POS 0
#define I3C_MST_IMR_CMDR_OVF_LEN 1
#define I3C_MST_IMR_CMDR_OVF_MASK 0x00000001
#define I3C_MST_IMR_CMDR_OVF_SET(x) (x << 0)
#define I3C_MST_IMR_CMDR_OVF_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::MST_ICR:: BitField descriptions
****************************************************/
/*! CORE HALTED interrupt Enable. */
#define I3C_MST_ICR_HALTED_POS 18
#define I3C_MST_ICR_HALTED_LEN 1
#define I3C_MST_ICR_HALTED_MASK 0x00040000
#define I3C_MST_ICR_HALTED_SET(x) (x << 18)
#define I3C_MST_ICR_HALTED_GET(x) ((x >> 18) & 0x00000001)

/*! MR_DONE */
#define I3C_MST_ICR_MR_DONE_POS 17
#define I3C_MST_ICR_MR_DONE_LEN 1
#define I3C_MST_ICR_MR_DONE_MASK 0x00020000
#define I3C_MST_ICR_MR_DONE_SET(x) (x << 17)
#define I3C_MST_ICR_MR_DONE_GET(x) ((x >> 17) & 0x00000001)

/*! IMM_COMP */
#define I3C_MST_ICR_IMM_COMP_POS 16
#define I3C_MST_ICR_IMM_COMP_LEN 1
#define I3C_MST_ICR_IMM_COMP_MASK 0x00010000
#define I3C_MST_ICR_IMM_COMP_SET(x) (x << 16)
#define I3C_MST_ICR_IMM_COMP_GET(x) ((x >> 16) & 0x00000001)

/*! TX_THR */
#define I3C_MST_ICR_TX_THR_POS 15
#define I3C_MST_ICR_TX_THR_LEN 1
#define I3C_MST_ICR_TX_THR_MASK 0x00008000
#define I3C_MST_ICR_TX_THR_SET(x) (x << 15)
#define I3C_MST_ICR_TX_THR_GET(x) ((x >> 15) & 0x00000001)

/*! TX_OVF */
#define I3C_MST_ICR_TX_OVF_POS 14
#define I3C_MST_ICR_TX_OVF_LEN 1
#define I3C_MST_ICR_TX_OVF_MASK 0x00004000
#define I3C_MST_ICR_TX_OVF_SET(x) (x << 14)
#define I3C_MST_ICR_TX_OVF_GET(x) ((x >> 14) & 0x00000001)

/*! IBID_THR */
#define I3C_MST_ICR_IBID_THR_POS 12
#define I3C_MST_ICR_IBID_THR_LEN 1
#define I3C_MST_ICR_IBID_THR_MASK 0x00001000
#define I3C_MST_ICR_IBID_THR_SET(x) (x << 12)
#define I3C_MST_ICR_IBID_THR_GET(x) ((x >> 12) & 0x00000001)

/*! IBID_UNF */
#define I3C_MST_ICR_IBID_UNF_POS 11
#define I3C_MST_ICR_IBID_UNF_LEN 1
#define I3C_MST_ICR_IBID_UNF_MASK 0x00000800
#define I3C_MST_ICR_IBID_UNF_SET(x) (x << 11)
#define I3C_MST_ICR_IBID_UNF_GET(x) ((x >> 11) & 0x00000001)

/*! IBIR_THR */
#define I3C_MST_ICR_IBIR_THR_POS 10
#define I3C_MST_ICR_IBIR_THR_LEN 1
#define I3C_MST_ICR_IBIR_THR_MASK 0x00000400
#define I3C_MST_ICR_IBIR_THR_SET(x) (x << 10)
#define I3C_MST_ICR_IBIR_THR_GET(x) ((x >> 10) & 0x00000001)

/*! IBIR_UNF */
#define I3C_MST_ICR_IBIR_UNF_POS 9
#define I3C_MST_ICR_IBIR_UNF_LEN 1
#define I3C_MST_ICR_IBIR_UNF_MASK 0x00000200
#define I3C_MST_ICR_IBIR_UNF_SET(x) (x << 9)
#define I3C_MST_ICR_IBIR_UNF_GET(x) ((x >> 9) & 0x00000001)

/*! IBIR_OVF */
#define I3C_MST_ICR_IBIR_OVF_POS 8
#define I3C_MST_ICR_IBIR_OVF_LEN 1
#define I3C_MST_ICR_IBIR_OVF_MASK 0x00000100
#define I3C_MST_ICR_IBIR_OVF_SET(x) (x << 8)
#define I3C_MST_ICR_IBIR_OVF_GET(x) ((x >> 8) & 0x00000001)

/*! RX_THR */
#define I3C_MST_ICR_RX_THR_POS 7
#define I3C_MST_ICR_RX_THR_LEN 1
#define I3C_MST_ICR_RX_THR_MASK 0x00000080
#define I3C_MST_ICR_RX_THR_SET(x) (x << 7)
#define I3C_MST_ICR_RX_THR_GET(x) ((x >> 7) & 0x00000001)

/*! RX_UNF */
#define I3C_MST_ICR_RX_UNF_POS 6
#define I3C_MST_ICR_RX_UNF_LEN 1
#define I3C_MST_ICR_RX_UNF_MASK 0x00000040
#define I3C_MST_ICR_RX_UNF_SET(x) (x << 6)
#define I3C_MST_ICR_RX_UNF_GET(x) ((x >> 6) & 0x00000001)

/*! CMDD_EMP */
#define I3C_MST_ICR_CMDD_EMP_POS 5
#define I3C_MST_ICR_CMDD_EMP_LEN 1
#define I3C_MST_ICR_CMDD_EMP_MASK 0x00000020
#define I3C_MST_ICR_CMDD_EMP_SET(x) (x << 5)
#define I3C_MST_ICR_CMDD_EMP_GET(x) ((x >> 5) & 0x00000001)

/*! CMDD_THR */
#define I3C_MST_ICR_CMDD_THR_POS 4
#define I3C_MST_ICR_CMDD_THR_LEN 1
#define I3C_MST_ICR_CMDD_THR_MASK 0x00000010
#define I3C_MST_ICR_CMDD_THR_SET(x) (x << 4)
#define I3C_MST_ICR_CMDD_THR_GET(x) ((x >> 4) & 0x00000001)

/*! CMDD_OVF */
#define I3C_MST_ICR_CMDD_OVF_POS 3
#define I3C_MST_ICR_CMDD_OVF_LEN 1
#define I3C_MST_ICR_CMDD_OVF_MASK 0x00000008
#define I3C_MST_ICR_CMDD_OVF_SET(x) (x << 3)
#define I3C_MST_ICR_CMDD_OVF_GET(x) ((x >> 3) & 0x00000001)

/*! CMDR_THR */
#define I3C_MST_ICR_CMDR_THR_POS 2
#define I3C_MST_ICR_CMDR_THR_LEN 1
#define I3C_MST_ICR_CMDR_THR_MASK 0x00000004
#define I3C_MST_ICR_CMDR_THR_SET(x) (x << 2)
#define I3C_MST_ICR_CMDR_THR_GET(x) ((x >> 2) & 0x00000001)

/*! CMDR_UNF */
#define I3C_MST_ICR_CMDR_UNF_POS 1
#define I3C_MST_ICR_CMDR_UNF_LEN 1
#define I3C_MST_ICR_CMDR_UNF_MASK 0x00000002
#define I3C_MST_ICR_CMDR_UNF_SET(x) (x << 1)
#define I3C_MST_ICR_CMDR_UNF_GET(x) ((x >> 1) & 0x00000001)

/*! CMDR_OVF */
#define I3C_MST_ICR_CMDR_OVF_POS 0
#define I3C_MST_ICR_CMDR_OVF_LEN 1
#define I3C_MST_ICR_CMDR_OVF_MASK 0x00000001
#define I3C_MST_ICR_CMDR_OVF_SET(x) (x << 0)
#define I3C_MST_ICR_CMDR_OVF_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::MST_ISR:: BitField descriptions
****************************************************/
/*! CORE HALTED interrupt Enable. */
#define I3C_MST_ISR_HALTED_POS 18
#define I3C_MST_ISR_HALTED_LEN 1
#define I3C_MST_ISR_HALTED_MASK 0x00040000
#define I3C_MST_ISR_HALTED_SET(x) (x << 18)
#define I3C_MST_ISR_HALTED_GET(x) ((x >> 18) & 0x00000001)

/*! MR_DONE */
#define I3C_MST_ISR_MR_DONE_POS 17
#define I3C_MST_ISR_MR_DONE_LEN 1
#define I3C_MST_ISR_MR_DONE_MASK 0x00020000
#define I3C_MST_ISR_MR_DONE_SET(x) (x << 17)
#define I3C_MST_ISR_MR_DONE_GET(x) ((x >> 17) & 0x00000001)

/*! IMM_COMP */
#define I3C_MST_ISR_IMM_COMP_POS 16
#define I3C_MST_ISR_IMM_COMP_LEN 1
#define I3C_MST_ISR_IMM_COMP_MASK 0x00010000
#define I3C_MST_ISR_IMM_COMP_SET(x) (x << 16)
#define I3C_MST_ISR_IMM_COMP_GET(x) ((x >> 16) & 0x00000001)

/*! TX_THR */
#define I3C_MST_ISR_TX_THR_POS 15
#define I3C_MST_ISR_TX_THR_LEN 1
#define I3C_MST_ISR_TX_THR_MASK 0x00008000
#define I3C_MST_ISR_TX_THR_SET(x) (x << 15)
#define I3C_MST_ISR_TX_THR_GET(x) ((x >> 15) & 0x00000001)

/*! TX_OVF */
#define I3C_MST_ISR_TX_OVF_POS 14
#define I3C_MST_ISR_TX_OVF_LEN 1
#define I3C_MST_ISR_TX_OVF_MASK 0x00004000
#define I3C_MST_ISR_TX_OVF_SET(x) (x << 14)
#define I3C_MST_ISR_TX_OVF_GET(x) ((x >> 14) & 0x00000001)

/*! IBID_THR */
#define I3C_MST_ISR_IBID_THR_POS 12
#define I3C_MST_ISR_IBID_THR_LEN 1
#define I3C_MST_ISR_IBID_THR_MASK 0x00001000
#define I3C_MST_ISR_IBID_THR_SET(x) (x << 12)
#define I3C_MST_ISR_IBID_THR_GET(x) ((x >> 12) & 0x00000001)

/*! IBID_UNF */
#define I3C_MST_ISR_IBID_UNF_POS 11
#define I3C_MST_ISR_IBID_UNF_LEN 1
#define I3C_MST_ISR_IBID_UNF_MASK 0x00000800
#define I3C_MST_ISR_IBID_UNF_SET(x) (x << 11)
#define I3C_MST_ISR_IBID_UNF_GET(x) ((x >> 11) & 0x00000001)

/*! IBIR_THR */
#define I3C_MST_ISR_IBIR_THR_POS 10
#define I3C_MST_ISR_IBIR_THR_LEN 1
#define I3C_MST_ISR_IBIR_THR_MASK 0x00000400
#define I3C_MST_ISR_IBIR_THR_SET(x) (x << 10)
#define I3C_MST_ISR_IBIR_THR_GET(x) ((x >> 10) & 0x00000001)

/*! IBIR_UNF */
#define I3C_MST_ISR_IBIR_UNF_POS 9
#define I3C_MST_ISR_IBIR_UNF_LEN 1
#define I3C_MST_ISR_IBIR_UNF_MASK 0x00000200
#define I3C_MST_ISR_IBIR_UNF_SET(x) (x << 9)
#define I3C_MST_ISR_IBIR_UNF_GET(x) ((x >> 9) & 0x00000001)

/*! IBIR_OVF */
#define I3C_MST_ISR_IBIR_OVF_POS 8
#define I3C_MST_ISR_IBIR_OVF_LEN 1
#define I3C_MST_ISR_IBIR_OVF_MASK 0x00000100
#define I3C_MST_ISR_IBIR_OVF_SET(x) (x << 8)
#define I3C_MST_ISR_IBIR_OVF_GET(x) ((x >> 8) & 0x00000001)

/*! RX_THR */
#define I3C_MST_ISR_RX_THR_POS 7
#define I3C_MST_ISR_RX_THR_LEN 1
#define I3C_MST_ISR_RX_THR_MASK 0x00000080
#define I3C_MST_ISR_RX_THR_SET(x) (x << 7)
#define I3C_MST_ISR_RX_THR_GET(x) ((x >> 7) & 0x00000001)

/*! RX_UNF */
#define I3C_MST_ISR_RX_UNF_POS 6
#define I3C_MST_ISR_RX_UNF_LEN 1
#define I3C_MST_ISR_RX_UNF_MASK 0x00000040
#define I3C_MST_ISR_RX_UNF_SET(x) (x << 6)
#define I3C_MST_ISR_RX_UNF_GET(x) ((x >> 6) & 0x00000001)

/*! CMDD_EMP */
#define I3C_MST_ISR_CMDD_EMP_POS 5
#define I3C_MST_ISR_CMDD_EMP_LEN 1
#define I3C_MST_ISR_CMDD_EMP_MASK 0x00000020
#define I3C_MST_ISR_CMDD_EMP_SET(x) (x << 5)
#define I3C_MST_ISR_CMDD_EMP_GET(x) ((x >> 5) & 0x00000001)

/*! CMDD_THR */
#define I3C_MST_ISR_CMDD_THR_POS 4
#define I3C_MST_ISR_CMDD_THR_LEN 1
#define I3C_MST_ISR_CMDD_THR_MASK 0x00000010
#define I3C_MST_ISR_CMDD_THR_SET(x) (x << 4)
#define I3C_MST_ISR_CMDD_THR_GET(x) ((x >> 4) & 0x00000001)

/*! CMDD_OVF */
#define I3C_MST_ISR_CMDD_OVF_POS 3
#define I3C_MST_ISR_CMDD_OVF_LEN 1
#define I3C_MST_ISR_CMDD_OVF_MASK 0x00000008
#define I3C_MST_ISR_CMDD_OVF_SET(x) (x << 3)
#define I3C_MST_ISR_CMDD_OVF_GET(x) ((x >> 3) & 0x00000001)

/*! CMDR_THR */
#define I3C_MST_ISR_CMDR_THR_POS 2
#define I3C_MST_ISR_CMDR_THR_LEN 1
#define I3C_MST_ISR_CMDR_THR_MASK 0x00000004
#define I3C_MST_ISR_CMDR_THR_SET(x) (x << 2)
#define I3C_MST_ISR_CMDR_THR_GET(x) ((x >> 2) & 0x00000001)

/*! CMDR_UNF */
#define I3C_MST_ISR_CMDR_UNF_POS 1
#define I3C_MST_ISR_CMDR_UNF_LEN 1
#define I3C_MST_ISR_CMDR_UNF_MASK 0x00000002
#define I3C_MST_ISR_CMDR_UNF_SET(x) (x << 1)
#define I3C_MST_ISR_CMDR_UNF_GET(x) ((x >> 1) & 0x00000001)

/*! CMDR_OVF */
#define I3C_MST_ISR_CMDR_OVF_POS 0
#define I3C_MST_ISR_CMDR_OVF_LEN 1
#define I3C_MST_ISR_CMDR_OVF_MASK 0x00000001
#define I3C_MST_ISR_CMDR_OVF_SET(x) (x << 0)
#define I3C_MST_ISR_CMDR_OVF_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::MST_STATUS0:: BitField descriptions
****************************************************/
/*!  core is IDLE */
#define I3C_MST_STATUS0_IDLE_POS 18
#define I3C_MST_STATUS0_IDLE_LEN 1
#define I3C_MST_STATUS0_IDLE_MASK 0x00040000
#define I3C_MST_STATUS0_IDLE_SET(x) (x << 18)
#define I3C_MST_STATUS0_IDLE_GET(x) ((x >> 18) & 0x00000001)

/*!  core is HALTED */
#define I3C_MST_STATUS0_HALTED_POS 17
#define I3C_MST_STATUS0_HALTED_LEN 1
#define I3C_MST_STATUS0_HALTED_MASK 0x00020000
#define I3C_MST_STATUS0_HALTED_SET(x) (x << 17)
#define I3C_MST_STATUS0_HALTED_GET(x) ((x >> 17) & 0x00000001)

/*!  core OP MODE */
#define I3C_MST_STATUS0_OP_MODE_POS 16
#define I3C_MST_STATUS0_OP_MODE_LEN 1
#define I3C_MST_STATUS0_OP_MODE_MASK 0x00010000
#define I3C_MST_STATUS0_OP_MODE_SET(x) (x << 16)
#define I3C_MST_STATUS0_OP_MODE_GET(x) ((x >> 16) & 0x00000001)

#define I3C_MST_STATUS0_OP_MODE_SLAVE_MODE 0x00000
#define I3C_MST_STATUS0_OP_MODE_MASTER_MODE 0x00001
/*!  TX FULL */
#define I3C_MST_STATUS0_TX_FULL_POS 13
#define I3C_MST_STATUS0_TX_FULL_LEN 1
#define I3C_MST_STATUS0_TX_FULL_MASK 0x00002000
#define I3C_MST_STATUS0_TX_FULL_SET(x) (x << 13)
#define I3C_MST_STATUS0_TX_FULL_GET(x) ((x >> 13) & 0x00000001)

/*!  IBID FULL */
#define I3C_MST_STATUS0_IBID_FULL_POS 12
#define I3C_MST_STATUS0_IBID_FULL_LEN 1
#define I3C_MST_STATUS0_IBID_FULL_MASK 0x00001000
#define I3C_MST_STATUS0_IBID_FULL_SET(x) (x << 12)
#define I3C_MST_STATUS0_IBID_FULL_GET(x) ((x >> 12) & 0x00000001)

/*!  IBIR FULL */
#define I3C_MST_STATUS0_IBIR_FULL_POS 11
#define I3C_MST_STATUS0_IBIR_FULL_LEN 1
#define I3C_MST_STATUS0_IBIR_FULL_MASK 0x00000800
#define I3C_MST_STATUS0_IBIR_FULL_SET(x) (x << 11)
#define I3C_MST_STATUS0_IBIR_FULL_GET(x) ((x >> 11) & 0x00000001)

/*!  RX FULL */
#define I3C_MST_STATUS0_RX_FULL_POS 10
#define I3C_MST_STATUS0_RX_FULL_LEN 1
#define I3C_MST_STATUS0_RX_FULL_MASK 0x00000400
#define I3C_MST_STATUS0_RX_FULL_SET(x) (x << 10)
#define I3C_MST_STATUS0_RX_FULL_GET(x) ((x >> 10) & 0x00000001)

/*!  CMDD FULL */
#define I3C_MST_STATUS0_CMDD_FULL_POS 9
#define I3C_MST_STATUS0_CMDD_FULL_LEN 1
#define I3C_MST_STATUS0_CMDD_FULL_MASK 0x00000200
#define I3C_MST_STATUS0_CMDD_FULL_SET(x) (x << 9)
#define I3C_MST_STATUS0_CMDD_FULL_GET(x) ((x >> 9) & 0x00000001)

/*!  CMDR FULL */
#define I3C_MST_STATUS0_CMDR_FULL_POS 8
#define I3C_MST_STATUS0_CMDR_FULL_LEN 1
#define I3C_MST_STATUS0_CMDR_FULL_MASK 0x00000100
#define I3C_MST_STATUS0_CMDR_FULL_SET(x) (x << 8)
#define I3C_MST_STATUS0_CMDR_FULL_GET(x) ((x >> 8) & 0x00000001)

/*!  TX EMP */
#define I3C_MST_STATUS0_TX_EMP_POS 5
#define I3C_MST_STATUS0_TX_EMP_LEN 1
#define I3C_MST_STATUS0_TX_EMP_MASK 0x00000020
#define I3C_MST_STATUS0_TX_EMP_SET(x) (x << 5)
#define I3C_MST_STATUS0_TX_EMP_GET(x) ((x >> 5) & 0x00000001)

/*!  IBID EMP */
#define I3C_MST_STATUS0_IBID_EMP_POS 4
#define I3C_MST_STATUS0_IBID_EMP_LEN 1
#define I3C_MST_STATUS0_IBID_EMP_MASK 0x00000010
#define I3C_MST_STATUS0_IBID_EMP_SET(x) (x << 4)
#define I3C_MST_STATUS0_IBID_EMP_GET(x) ((x >> 4) & 0x00000001)

/*!  IBIR EMP */
#define I3C_MST_STATUS0_IBIR_EMP_POS 3
#define I3C_MST_STATUS0_IBIR_EMP_LEN 1
#define I3C_MST_STATUS0_IBIR_EMP_MASK 0x00000008
#define I3C_MST_STATUS0_IBIR_EMP_SET(x) (x << 3)
#define I3C_MST_STATUS0_IBIR_EMP_GET(x) ((x >> 3) & 0x00000001)

/*!  RX EMP */
#define I3C_MST_STATUS0_RX_EMP_POS 2
#define I3C_MST_STATUS0_RX_EMP_LEN 1
#define I3C_MST_STATUS0_RX_EMP_MASK 0x00000004
#define I3C_MST_STATUS0_RX_EMP_SET(x) (x << 2)
#define I3C_MST_STATUS0_RX_EMP_GET(x) ((x >> 2) & 0x00000001)

/*!  CMDD EMP */
#define I3C_MST_STATUS0_CMDD_EMP_POS 1
#define I3C_MST_STATUS0_CMDD_EMP_LEN 1
#define I3C_MST_STATUS0_CMDD_EMP_MASK 0x00000002
#define I3C_MST_STATUS0_CMDD_EMP_SET(x) (x << 1)
#define I3C_MST_STATUS0_CMDD_EMP_GET(x) ((x >> 1) & 0x00000001)

/*!  CMDR EMP */
#define I3C_MST_STATUS0_CMDR_EMP_POS 0
#define I3C_MST_STATUS0_CMDR_EMP_LEN 1
#define I3C_MST_STATUS0_CMDR_EMP_MASK 0x00000001
#define I3C_MST_STATUS0_CMDR_EMP_SET(x) (x << 0)
#define I3C_MST_STATUS0_CMDR_EMP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::CMDR:: BitField descriptions
****************************************************/
/*!  error that occurred during command execution */
#define I3C_CMDR_ERROR_POS 24
#define I3C_CMDR_ERROR_LEN 4
#define I3C_CMDR_ERROR_MASK 0x0f000000
#define I3C_CMDR_ERROR_SET(x) (x << 24)
#define I3C_CMDR_ERROR_GET(x) ((x >> 24) & 0x0000000f)

#define I3C_CMDR_ERROR_NO_ERROR 0x00000
#define I3C_CMDR_ERROR_DDR_PREAMBLE_ERROR 0x00001
#define I3C_CMDR_ERROR_DDR_PARITY_ERROR 0x00002
#define I3C_CMDR_ERROR_DDR_RX_FIFO_OVERFLOW 0x00003
#define I3C_CMDR_ERROR_DDR_TX_FIFO_UNDERFLOW 0x00004
#define I3C_CMDR_ERROR_M0_ERROR 0x00005
#define I3C_CMDR_ERROR_M1_ERROR 0x00006
#define I3C_CMDR_ERROR_M2_ERROR 0x00007
#define I3C_CMDR_ERROR_MST_ABORT 0x00008
#define I3C_CMDR_ERROR_NACK_RESPONSE 0x00009
#define I3C_CMDR_ERROR_INVALID_DA 0x0000a
#define I3C_CMDR_ERROR_DDR_DROPPED 0x0000b
/*!  XFER BYTES */
#define I3C_CMDR_XFER_BYTES_POS 8
#define I3C_CMDR_XFER_BYTES_LEN 12
#define I3C_CMDR_XFER_BYTES_MASK 0x000fff00
#define I3C_CMDR_XFER_BYTES_SET(x) (x << 8)
#define I3C_CMDR_XFER_BYTES_GET(x) ((x >> 8) & 0x00000fff)

/*!  CMD ID */
#define I3C_CMDR_CMD_ID_POS 0
#define I3C_CMDR_CMD_ID_LEN 8
#define I3C_CMDR_CMD_ID_MASK 0x000000ff
#define I3C_CMDR_CMD_ID_SET(x) (x << 0)
#define I3C_CMDR_CMD_ID_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::IBIR:: BitField descriptions
****************************************************/
/*!  Master response */
#define I3C_IBIR_RESP_POS 12
#define I3C_IBIR_RESP_LEN 1
#define I3C_IBIR_RESP_MASK 0x00001000
#define I3C_IBIR_RESP_SET(x) (x << 12)
#define I3C_IBIR_RESP_GET(x) ((x >> 12) & 0x00000001)

/*!  ID of slave that issued the request */
#define I3C_IBIR_SLAVE_ID_POS 8
#define I3C_IBIR_SLAVE_ID_LEN 4
#define I3C_IBIR_SLAVE_ID_MASK 0x00000f00
#define I3C_IBIR_SLAVE_ID_SET(x) (x << 8)
#define I3C_IBIR_SLAVE_ID_GET(x) ((x >> 8) & 0x0000000f)

/*!  Error */
#define I3C_IBIR_ERROR_POS 7
#define I3C_IBIR_ERROR_LEN 1
#define I3C_IBIR_ERROR_MASK 0x00000080
#define I3C_IBIR_ERROR_SET(x) (x << 7)
#define I3C_IBIR_ERROR_GET(x) ((x >> 7) & 0x00000001)

/*!  Number of bytes transferred */
#define I3C_IBIR_XFER_BYTES_POS 2
#define I3C_IBIR_XFER_BYTES_LEN 5
#define I3C_IBIR_XFER_BYTES_MASK 0x0000007c
#define I3C_IBIR_XFER_BYTES_SET(x) (x << 2)
#define I3C_IBIR_XFER_BYTES_GET(x) ((x >> 2) & 0x0000001f)

/*!  IBI Request */
#define I3C_IBIR_IBI_TYPE_POS 0
#define I3C_IBIR_IBI_TYPE_LEN 2
#define I3C_IBIR_IBI_TYPE_MASK 0x00000003
#define I3C_IBIR_IBI_TYPE_SET(x) (x << 0)
#define I3C_IBIR_IBI_TYPE_GET(x) ((x >> 0) & 0x00000003)

#define I3C_IBIR_IBI_TYPE_INBAND_INTERRUPT 0x00000
#define I3C_IBIR_IBI_TYPE_HOTJOIN_REQUEST 0x00001
#define I3C_IBIR_IBI_TYPE_MASTERSHIP_REQUEST 0x00002
/****************************************************
  ::SLV_IER:: BitField descriptions
****************************************************/
/*!  DEFSLVS interrupt */
#define I3C_SLV_IER_DEFSLVS_POS 21
#define I3C_SLV_IER_DEFSLVS_LEN 1
#define I3C_SLV_IER_DEFSLVS_MASK 0x00200000
#define I3C_SLV_IER_DEFSLVS_SET(x) (x << 21)
#define I3C_SLV_IER_DEFSLVS_GET(x) ((x >> 21) & 0x00000001)

/*!  TM Interrupt */
#define I3C_SLV_IER_TM_POS 20
#define I3C_SLV_IER_TM_LEN 1
#define I3C_SLV_IER_TM_MASK 0x00100000
#define I3C_SLV_IER_TM_SET(x) (x << 20)
#define I3C_SLV_IER_TM_GET(x) ((x >> 20) & 0x00000001)

/*!  ERROR interrupt */
#define I3C_SLV_IER_ERROR_POS 19
#define I3C_SLV_IER_ERROR_LEN 1
#define I3C_SLV_IER_ERROR_MASK 0x00080000
#define I3C_SLV_IER_ERROR_SET(x) (x << 19)
#define I3C_SLV_IER_ERROR_GET(x) ((x >> 19) & 0x00000001)

/*!  EVENT_UP interrupt */
#define I3C_SLV_IER_EVENT_UP_POS 18
#define I3C_SLV_IER_EVENT_UP_LEN 1
#define I3C_SLV_IER_EVENT_UP_MASK 0x00040000
#define I3C_SLV_IER_EVENT_UP_SET(x) (x << 18)
#define I3C_SLV_IER_EVENT_UP_GET(x) ((x >> 18) & 0x00000001)

/*!  HJ_DONE Interrupt */
#define I3C_SLV_IER_HJ_DONE_POS 17
#define I3C_SLV_IER_HJ_DONE_LEN 1
#define I3C_SLV_IER_HJ_DONE_MASK 0x00020000
#define I3C_SLV_IER_HJ_DONE_SET(x) (x << 17)
#define I3C_SLV_IER_HJ_DONE_GET(x) ((x >> 17) & 0x00000001)

/*!  MR_DONE interrupt */
#define I3C_SLV_IER_MR_DONE_POS 16
#define I3C_SLV_IER_MR_DONE_LEN 1
#define I3C_SLV_IER_MR_DONE_MASK 0x00010000
#define I3C_SLV_IER_MR_DONE_SET(x) (x << 16)
#define I3C_SLV_IER_MR_DONE_GET(x) ((x >> 16) & 0x00000001)

/*!  DA_UPDATE Interrupt */
#define I3C_SLV_IER_DA_UPDATE_POS 15
#define I3C_SLV_IER_DA_UPDATE_LEN 1
#define I3C_SLV_IER_DA_UPDATE_MASK 0x00008000
#define I3C_SLV_IER_DA_UPDATE_SET(x) (x << 15)
#define I3C_SLV_IER_DA_UPDATE_GET(x) ((x >> 15) & 0x00000001)

/*!  SDR_FAIL interrupt */
#define I3C_SLV_IER_SDR_FAIL_POS 14
#define I3C_SLV_IER_SDR_FAIL_LEN 1
#define I3C_SLV_IER_SDR_FAIL_MASK 0x00004000
#define I3C_SLV_IER_SDR_FAIL_SET(x) (x << 14)
#define I3C_SLV_IER_SDR_FAIL_GET(x) ((x >> 14) & 0x00000001)

/*!  DDR_FAIL Interrupt */
#define I3C_SLV_IER_DDR_FAIL_POS 13
#define I3C_SLV_IER_DDR_FAIL_LEN 1
#define I3C_SLV_IER_DDR_FAIL_MASK 0x00002000
#define I3C_SLV_IER_DDR_FAIL_SET(x) (x << 13)
#define I3C_SLV_IER_DDR_FAIL_GET(x) ((x >> 13) & 0x00000001)

/*!  M_RD_ABORT interrupt */
#define I3C_SLV_IER_M_RD_ABORT_POS 12
#define I3C_SLV_IER_M_RD_ABORT_LEN 1
#define I3C_SLV_IER_M_RD_ABORT_MASK 0x00001000
#define I3C_SLV_IER_M_RD_ABORT_SET(x) (x << 12)
#define I3C_SLV_IER_M_RD_ABORT_GET(x) ((x >> 12) & 0x00000001)

/*!  DDR_RX_THR Interrupt */
#define I3C_SLV_IER_DDR_RX_THR_POS 11
#define I3C_SLV_IER_DDR_RX_THR_LEN 1
#define I3C_SLV_IER_DDR_RX_THR_MASK 0x00000800
#define I3C_SLV_IER_DDR_RX_THR_SET(x) (x << 11)
#define I3C_SLV_IER_DDR_RX_THR_GET(x) ((x >> 11) & 0x00000001)

/*!  DDR_TX_THR Interrupt */
#define I3C_SLV_IER_DDR_TX_THR_POS 10
#define I3C_SLV_IER_DDR_TX_THR_LEN 1
#define I3C_SLV_IER_DDR_TX_THR_MASK 0x00000400
#define I3C_SLV_IER_DDR_TX_THR_SET(x) (x << 10)
#define I3C_SLV_IER_DDR_TX_THR_GET(x) ((x >> 10) & 0x00000001)

/*!  SDR_RX_THR Interrupt */
#define I3C_SLV_IER_SDR_RX_THR_POS 9
#define I3C_SLV_IER_SDR_RX_THR_LEN 1
#define I3C_SLV_IER_SDR_RX_THR_MASK 0x00000200
#define I3C_SLV_IER_SDR_RX_THR_SET(x) (x << 9)
#define I3C_SLV_IER_SDR_RX_THR_GET(x) ((x >> 9) & 0x00000001)

/*!  SDR_TX_THR Interrupt */
#define I3C_SLV_IER_SDR_TX_THR_POS 8
#define I3C_SLV_IER_SDR_TX_THR_LEN 1
#define I3C_SLV_IER_SDR_TX_THR_MASK 0x00000100
#define I3C_SLV_IER_SDR_TX_THR_SET(x) (x << 8)
#define I3C_SLV_IER_SDR_TX_THR_GET(x) ((x >> 8) & 0x00000001)

/*!  DDR_RX_UNF Interrupt */
#define I3C_SLV_IER_DDR_RX_UNF_POS 7
#define I3C_SLV_IER_DDR_RX_UNF_LEN 1
#define I3C_SLV_IER_DDR_RX_UNF_MASK 0x00000080
#define I3C_SLV_IER_DDR_RX_UNF_SET(x) (x << 7)
#define I3C_SLV_IER_DDR_RX_UNF_GET(x) ((x >> 7) & 0x00000001)

/*!  DDR_TX_OVF Interrupt */
#define I3C_SLV_IER_DDR_TX_OVF_POS 6
#define I3C_SLV_IER_DDR_TX_OVF_LEN 1
#define I3C_SLV_IER_DDR_TX_OVF_MASK 0x00000040
#define I3C_SLV_IER_DDR_TX_OVF_SET(x) (x << 6)
#define I3C_SLV_IER_DDR_TX_OVF_GET(x) ((x >> 6) & 0x00000001)

/*!  SDR_RX_UNF Interrupt */
#define I3C_SLV_IER_SDR_RX_UNF_POS 5
#define I3C_SLV_IER_SDR_RX_UNF_LEN 1
#define I3C_SLV_IER_SDR_RX_UNF_MASK 0x00000020
#define I3C_SLV_IER_SDR_RX_UNF_SET(x) (x << 5)
#define I3C_SLV_IER_SDR_RX_UNF_GET(x) ((x >> 5) & 0x00000001)

/*!  SDR_TX_OVF Interrupt */
#define I3C_SLV_IER_SDR_TX_OVF_POS 4
#define I3C_SLV_IER_SDR_TX_OVF_LEN 1
#define I3C_SLV_IER_SDR_TX_OVF_MASK 0x00000010
#define I3C_SLV_IER_SDR_TX_OVF_SET(x) (x << 4)
#define I3C_SLV_IER_SDR_TX_OVF_GET(x) ((x >> 4) & 0x00000001)

/*!  DDR_RD_COMP Interrupt */
#define I3C_SLV_IER_DDR_RD_COMP_POS 3
#define I3C_SLV_IER_DDR_RD_COMP_LEN 1
#define I3C_SLV_IER_DDR_RD_COMP_MASK 0x00000008
#define I3C_SLV_IER_DDR_RD_COMP_SET(x) (x << 3)
#define I3C_SLV_IER_DDR_RD_COMP_GET(x) ((x >> 3) & 0x00000001)

/*!  DDR_WR_COMP Interrupt */
#define I3C_SLV_IER_DDR_WR_COMP_POS 2
#define I3C_SLV_IER_DDR_WR_COMP_LEN 1
#define I3C_SLV_IER_DDR_WR_COMP_MASK 0x00000004
#define I3C_SLV_IER_DDR_WR_COMP_SET(x) (x << 2)
#define I3C_SLV_IER_DDR_WR_COMP_GET(x) ((x >> 2) & 0x00000001)

/*!  SDR_RD_COMP Interrupt */
#define I3C_SLV_IER_SDR_RD_COMP_POS 1
#define I3C_SLV_IER_SDR_RD_COMP_LEN 1
#define I3C_SLV_IER_SDR_RD_COMP_MASK 0x00000002
#define I3C_SLV_IER_SDR_RD_COMP_SET(x) (x << 1)
#define I3C_SLV_IER_SDR_RD_COMP_GET(x) ((x >> 1) & 0x00000001)

/*!  SDR_WR_COMP Interrupt */
#define I3C_SLV_IER_SDR_WR_COMP_POS 0
#define I3C_SLV_IER_SDR_WR_COMP_LEN 1
#define I3C_SLV_IER_SDR_WR_COMP_MASK 0x00000001
#define I3C_SLV_IER_SDR_WR_COMP_SET(x) (x << 0)
#define I3C_SLV_IER_SDR_WR_COMP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::SLV_IDR:: BitField descriptions
****************************************************/
/*!  DEFSLVS interrupt */
#define I3C_SLV_IDR_DEFSLVS_POS 21
#define I3C_SLV_IDR_DEFSLVS_LEN 1
#define I3C_SLV_IDR_DEFSLVS_MASK 0x00200000
#define I3C_SLV_IDR_DEFSLVS_SET(x) (x << 21)
#define I3C_SLV_IDR_DEFSLVS_GET(x) ((x >> 21) & 0x00000001)

/*!  TM Interrupt */
#define I3C_SLV_IDR_TM_POS 20
#define I3C_SLV_IDR_TM_LEN 1
#define I3C_SLV_IDR_TM_MASK 0x00100000
#define I3C_SLV_IDR_TM_SET(x) (x << 20)
#define I3C_SLV_IDR_TM_GET(x) ((x >> 20) & 0x00000001)

/*!  ERROR interrupt */
#define I3C_SLV_IDR_ERROR_POS 19
#define I3C_SLV_IDR_ERROR_LEN 1
#define I3C_SLV_IDR_ERROR_MASK 0x00080000
#define I3C_SLV_IDR_ERROR_SET(x) (x << 19)
#define I3C_SLV_IDR_ERROR_GET(x) ((x >> 19) & 0x00000001)

/*!  EVENT_UP interrupt */
#define I3C_SLV_IDR_EVENT_UP_POS 18
#define I3C_SLV_IDR_EVENT_UP_LEN 1
#define I3C_SLV_IDR_EVENT_UP_MASK 0x00040000
#define I3C_SLV_IDR_EVENT_UP_SET(x) (x << 18)
#define I3C_SLV_IDR_EVENT_UP_GET(x) ((x >> 18) & 0x00000001)

/*!  HJ_DONE Interrupt */
#define I3C_SLV_IDR_HJ_DONE_POS 17
#define I3C_SLV_IDR_HJ_DONE_LEN 1
#define I3C_SLV_IDR_HJ_DONE_MASK 0x00020000
#define I3C_SLV_IDR_HJ_DONE_SET(x) (x << 17)
#define I3C_SLV_IDR_HJ_DONE_GET(x) ((x >> 17) & 0x00000001)

/*!  MR_DONE interrupt */
#define I3C_SLV_IDR_MR_DONE_POS 16
#define I3C_SLV_IDR_MR_DONE_LEN 1
#define I3C_SLV_IDR_MR_DONE_MASK 0x00010000
#define I3C_SLV_IDR_MR_DONE_SET(x) (x << 16)
#define I3C_SLV_IDR_MR_DONE_GET(x) ((x >> 16) & 0x00000001)

/*!  DA_UPDATE Interrupt */
#define I3C_SLV_IDR_DA_UPDATE_POS 15
#define I3C_SLV_IDR_DA_UPDATE_LEN 1
#define I3C_SLV_IDR_DA_UPDATE_MASK 0x00008000
#define I3C_SLV_IDR_DA_UPDATE_SET(x) (x << 15)
#define I3C_SLV_IDR_DA_UPDATE_GET(x) ((x >> 15) & 0x00000001)

/*!  SDR_FAIL interrupt */
#define I3C_SLV_IDR_SDR_FAIL_POS 14
#define I3C_SLV_IDR_SDR_FAIL_LEN 1
#define I3C_SLV_IDR_SDR_FAIL_MASK 0x00004000
#define I3C_SLV_IDR_SDR_FAIL_SET(x) (x << 14)
#define I3C_SLV_IDR_SDR_FAIL_GET(x) ((x >> 14) & 0x00000001)

/*!  DDR_FAIL Interrupt */
#define I3C_SLV_IDR_DDR_FAIL_POS 13
#define I3C_SLV_IDR_DDR_FAIL_LEN 1
#define I3C_SLV_IDR_DDR_FAIL_MASK 0x00002000
#define I3C_SLV_IDR_DDR_FAIL_SET(x) (x << 13)
#define I3C_SLV_IDR_DDR_FAIL_GET(x) ((x >> 13) & 0x00000001)

/*!  M_RD_ABORT interrupt */
#define I3C_SLV_IDR_M_RD_ABORT_POS 12
#define I3C_SLV_IDR_M_RD_ABORT_LEN 1
#define I3C_SLV_IDR_M_RD_ABORT_MASK 0x00001000
#define I3C_SLV_IDR_M_RD_ABORT_SET(x) (x << 12)
#define I3C_SLV_IDR_M_RD_ABORT_GET(x) ((x >> 12) & 0x00000001)

/*!  DDR_RX_THR Interrupt */
#define I3C_SLV_IDR_DDR_RX_THR_POS 11
#define I3C_SLV_IDR_DDR_RX_THR_LEN 1
#define I3C_SLV_IDR_DDR_RX_THR_MASK 0x00000800
#define I3C_SLV_IDR_DDR_RX_THR_SET(x) (x << 11)
#define I3C_SLV_IDR_DDR_RX_THR_GET(x) ((x >> 11) & 0x00000001)

/*!  DDR_TX_THR Interrupt */
#define I3C_SLV_IDR_DDR_TX_THR_POS 10
#define I3C_SLV_IDR_DDR_TX_THR_LEN 1
#define I3C_SLV_IDR_DDR_TX_THR_MASK 0x00000400
#define I3C_SLV_IDR_DDR_TX_THR_SET(x) (x << 10)
#define I3C_SLV_IDR_DDR_TX_THR_GET(x) ((x >> 10) & 0x00000001)

/*!  SDR_RX_THR Interrupt */
#define I3C_SLV_IDR_SDR_RX_THR_POS 9
#define I3C_SLV_IDR_SDR_RX_THR_LEN 1
#define I3C_SLV_IDR_SDR_RX_THR_MASK 0x00000200
#define I3C_SLV_IDR_SDR_RX_THR_SET(x) (x << 9)
#define I3C_SLV_IDR_SDR_RX_THR_GET(x) ((x >> 9) & 0x00000001)

/*!  SDR_TX_THR Interrupt */
#define I3C_SLV_IDR_SDR_TX_THR_POS 8
#define I3C_SLV_IDR_SDR_TX_THR_LEN 1
#define I3C_SLV_IDR_SDR_TX_THR_MASK 0x00000100
#define I3C_SLV_IDR_SDR_TX_THR_SET(x) (x << 8)
#define I3C_SLV_IDR_SDR_TX_THR_GET(x) ((x >> 8) & 0x00000001)

/*!  DDR_RX_UNF Interrupt */
#define I3C_SLV_IDR_DDR_RX_UNF_POS 7
#define I3C_SLV_IDR_DDR_RX_UNF_LEN 1
#define I3C_SLV_IDR_DDR_RX_UNF_MASK 0x00000080
#define I3C_SLV_IDR_DDR_RX_UNF_SET(x) (x << 7)
#define I3C_SLV_IDR_DDR_RX_UNF_GET(x) ((x >> 7) & 0x00000001)

/*!  DDR_TX_OVF Interrupt */
#define I3C_SLV_IDR_DDR_TX_OVF_POS 6
#define I3C_SLV_IDR_DDR_TX_OVF_LEN 1
#define I3C_SLV_IDR_DDR_TX_OVF_MASK 0x00000040
#define I3C_SLV_IDR_DDR_TX_OVF_SET(x) (x << 6)
#define I3C_SLV_IDR_DDR_TX_OVF_GET(x) ((x >> 6) & 0x00000001)

/*!  SDR_RX_UNF Interrupt */
#define I3C_SLV_IDR_SDR_RX_UNF_POS 5
#define I3C_SLV_IDR_SDR_RX_UNF_LEN 1
#define I3C_SLV_IDR_SDR_RX_UNF_MASK 0x00000020
#define I3C_SLV_IDR_SDR_RX_UNF_SET(x) (x << 5)
#define I3C_SLV_IDR_SDR_RX_UNF_GET(x) ((x >> 5) & 0x00000001)

/*!  SDR_TX_OVF Interrupt */
#define I3C_SLV_IDR_SDR_TX_OVF_POS 4
#define I3C_SLV_IDR_SDR_TX_OVF_LEN 1
#define I3C_SLV_IDR_SDR_TX_OVF_MASK 0x00000010
#define I3C_SLV_IDR_SDR_TX_OVF_SET(x) (x << 4)
#define I3C_SLV_IDR_SDR_TX_OVF_GET(x) ((x >> 4) & 0x00000001)

/*!  DDR_RD_COMP Interrupt */
#define I3C_SLV_IDR_DDR_RD_COMP_POS 3
#define I3C_SLV_IDR_DDR_RD_COMP_LEN 1
#define I3C_SLV_IDR_DDR_RD_COMP_MASK 0x00000008
#define I3C_SLV_IDR_DDR_RD_COMP_SET(x) (x << 3)
#define I3C_SLV_IDR_DDR_RD_COMP_GET(x) ((x >> 3) & 0x00000001)

/*!  DDR_WR_COMP Interrupt */
#define I3C_SLV_IDR_DDR_WR_COMP_POS 2
#define I3C_SLV_IDR_DDR_WR_COMP_LEN 1
#define I3C_SLV_IDR_DDR_WR_COMP_MASK 0x00000004
#define I3C_SLV_IDR_DDR_WR_COMP_SET(x) (x << 2)
#define I3C_SLV_IDR_DDR_WR_COMP_GET(x) ((x >> 2) & 0x00000001)

/*!  SDR_RD_COMP Interrupt */
#define I3C_SLV_IDR_SDR_RD_COMP_POS 1
#define I3C_SLV_IDR_SDR_RD_COMP_LEN 1
#define I3C_SLV_IDR_SDR_RD_COMP_MASK 0x00000002
#define I3C_SLV_IDR_SDR_RD_COMP_SET(x) (x << 1)
#define I3C_SLV_IDR_SDR_RD_COMP_GET(x) ((x >> 1) & 0x00000001)

/*!  SDR_WR_COMP Interrupt */
#define I3C_SLV_IDR_SDR_WR_COMP_POS 0
#define I3C_SLV_IDR_SDR_WR_COMP_LEN 1
#define I3C_SLV_IDR_SDR_WR_COMP_MASK 0x00000001
#define I3C_SLV_IDR_SDR_WR_COMP_SET(x) (x << 0)
#define I3C_SLV_IDR_SDR_WR_COMP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::SLV_IMR:: BitField descriptions
****************************************************/
/*!  DEFSLVS interrupt */
#define I3C_SLV_IMR_DEFSLVS_POS 21
#define I3C_SLV_IMR_DEFSLVS_LEN 1
#define I3C_SLV_IMR_DEFSLVS_MASK 0x00200000
#define I3C_SLV_IMR_DEFSLVS_SET(x) (x << 21)
#define I3C_SLV_IMR_DEFSLVS_GET(x) ((x >> 21) & 0x00000001)

/*!  TM Interrupt */
#define I3C_SLV_IMR_TM_POS 20
#define I3C_SLV_IMR_TM_LEN 1
#define I3C_SLV_IMR_TM_MASK 0x00100000
#define I3C_SLV_IMR_TM_SET(x) (x << 20)
#define I3C_SLV_IMR_TM_GET(x) ((x >> 20) & 0x00000001)

/*!  ERROR interrupt */
#define I3C_SLV_IMR_ERROR_POS 19
#define I3C_SLV_IMR_ERROR_LEN 1
#define I3C_SLV_IMR_ERROR_MASK 0x00080000
#define I3C_SLV_IMR_ERROR_SET(x) (x << 19)
#define I3C_SLV_IMR_ERROR_GET(x) ((x >> 19) & 0x00000001)

/*!  EVENT_UP interrupt */
#define I3C_SLV_IMR_EVENT_UP_POS 18
#define I3C_SLV_IMR_EVENT_UP_LEN 1
#define I3C_SLV_IMR_EVENT_UP_MASK 0x00040000
#define I3C_SLV_IMR_EVENT_UP_SET(x) (x << 18)
#define I3C_SLV_IMR_EVENT_UP_GET(x) ((x >> 18) & 0x00000001)

/*!  HJ_DONE Interrupt */
#define I3C_SLV_IMR_HJ_DONE_POS 17
#define I3C_SLV_IMR_HJ_DONE_LEN 1
#define I3C_SLV_IMR_HJ_DONE_MASK 0x00020000
#define I3C_SLV_IMR_HJ_DONE_SET(x) (x << 17)
#define I3C_SLV_IMR_HJ_DONE_GET(x) ((x >> 17) & 0x00000001)

/*!  MR_DONE interrupt */
#define I3C_SLV_IMR_MR_DONE_POS 16
#define I3C_SLV_IMR_MR_DONE_LEN 1
#define I3C_SLV_IMR_MR_DONE_MASK 0x00010000
#define I3C_SLV_IMR_MR_DONE_SET(x) (x << 16)
#define I3C_SLV_IMR_MR_DONE_GET(x) ((x >> 16) & 0x00000001)

/*!  DA_UPDATE Interrupt */
#define I3C_SLV_IMR_DA_UPDATE_POS 15
#define I3C_SLV_IMR_DA_UPDATE_LEN 1
#define I3C_SLV_IMR_DA_UPDATE_MASK 0x00008000
#define I3C_SLV_IMR_DA_UPDATE_SET(x) (x << 15)
#define I3C_SLV_IMR_DA_UPDATE_GET(x) ((x >> 15) & 0x00000001)

/*!  SDR_FAIL interrupt */
#define I3C_SLV_IMR_SDR_FAIL_POS 14
#define I3C_SLV_IMR_SDR_FAIL_LEN 1
#define I3C_SLV_IMR_SDR_FAIL_MASK 0x00004000
#define I3C_SLV_IMR_SDR_FAIL_SET(x) (x << 14)
#define I3C_SLV_IMR_SDR_FAIL_GET(x) ((x >> 14) & 0x00000001)

/*!  DDR_FAIL Interrupt */
#define I3C_SLV_IMR_DDR_FAIL_POS 13
#define I3C_SLV_IMR_DDR_FAIL_LEN 1
#define I3C_SLV_IMR_DDR_FAIL_MASK 0x00002000
#define I3C_SLV_IMR_DDR_FAIL_SET(x) (x << 13)
#define I3C_SLV_IMR_DDR_FAIL_GET(x) ((x >> 13) & 0x00000001)

/*!  M_RD_ABORT interrupt */
#define I3C_SLV_IMR_M_RD_ABORT_POS 12
#define I3C_SLV_IMR_M_RD_ABORT_LEN 1
#define I3C_SLV_IMR_M_RD_ABORT_MASK 0x00001000
#define I3C_SLV_IMR_M_RD_ABORT_SET(x) (x << 12)
#define I3C_SLV_IMR_M_RD_ABORT_GET(x) ((x >> 12) & 0x00000001)

/*!  DDR_RX_THR Interrupt */
#define I3C_SLV_IMR_DDR_RX_THR_POS 11
#define I3C_SLV_IMR_DDR_RX_THR_LEN 1
#define I3C_SLV_IMR_DDR_RX_THR_MASK 0x00000800
#define I3C_SLV_IMR_DDR_RX_THR_SET(x) (x << 11)
#define I3C_SLV_IMR_DDR_RX_THR_GET(x) ((x >> 11) & 0x00000001)

/*!  DDR_TX_THR Interrupt */
#define I3C_SLV_IMR_DDR_TX_THR_POS 10
#define I3C_SLV_IMR_DDR_TX_THR_LEN 1
#define I3C_SLV_IMR_DDR_TX_THR_MASK 0x00000400
#define I3C_SLV_IMR_DDR_TX_THR_SET(x) (x << 10)
#define I3C_SLV_IMR_DDR_TX_THR_GET(x) ((x >> 10) & 0x00000001)

/*!  SDR_RX_THR Interrupt */
#define I3C_SLV_IMR_SDR_RX_THR_POS 9
#define I3C_SLV_IMR_SDR_RX_THR_LEN 1
#define I3C_SLV_IMR_SDR_RX_THR_MASK 0x00000200
#define I3C_SLV_IMR_SDR_RX_THR_SET(x) (x << 9)
#define I3C_SLV_IMR_SDR_RX_THR_GET(x) ((x >> 9) & 0x00000001)

/*!  SDR_TX_THR Interrupt */
#define I3C_SLV_IMR_SDR_TX_THR_POS 8
#define I3C_SLV_IMR_SDR_TX_THR_LEN 1
#define I3C_SLV_IMR_SDR_TX_THR_MASK 0x00000100
#define I3C_SLV_IMR_SDR_TX_THR_SET(x) (x << 8)
#define I3C_SLV_IMR_SDR_TX_THR_GET(x) ((x >> 8) & 0x00000001)

/*!  DDR_RX_UNF Interrupt */
#define I3C_SLV_IMR_DDR_RX_UNF_POS 7
#define I3C_SLV_IMR_DDR_RX_UNF_LEN 1
#define I3C_SLV_IMR_DDR_RX_UNF_MASK 0x00000080
#define I3C_SLV_IMR_DDR_RX_UNF_SET(x) (x << 7)
#define I3C_SLV_IMR_DDR_RX_UNF_GET(x) ((x >> 7) & 0x00000001)

/*!  DDR_TX_OVF Interrupt */
#define I3C_SLV_IMR_DDR_TX_OVF_POS 6
#define I3C_SLV_IMR_DDR_TX_OVF_LEN 1
#define I3C_SLV_IMR_DDR_TX_OVF_MASK 0x00000040
#define I3C_SLV_IMR_DDR_TX_OVF_SET(x) (x << 6)
#define I3C_SLV_IMR_DDR_TX_OVF_GET(x) ((x >> 6) & 0x00000001)

/*!  SDR_RX_UNF Interrupt */
#define I3C_SLV_IMR_SDR_RX_UNF_POS 5
#define I3C_SLV_IMR_SDR_RX_UNF_LEN 1
#define I3C_SLV_IMR_SDR_RX_UNF_MASK 0x00000020
#define I3C_SLV_IMR_SDR_RX_UNF_SET(x) (x << 5)
#define I3C_SLV_IMR_SDR_RX_UNF_GET(x) ((x >> 5) & 0x00000001)

/*!  SDR_TX_OVF Interrupt */
#define I3C_SLV_IMR_SDR_TX_OVF_POS 4
#define I3C_SLV_IMR_SDR_TX_OVF_LEN 1
#define I3C_SLV_IMR_SDR_TX_OVF_MASK 0x00000010
#define I3C_SLV_IMR_SDR_TX_OVF_SET(x) (x << 4)
#define I3C_SLV_IMR_SDR_TX_OVF_GET(x) ((x >> 4) & 0x00000001)

/*!  DDR_RD_COMP Interrupt */
#define I3C_SLV_IMR_DDR_RD_COMP_POS 3
#define I3C_SLV_IMR_DDR_RD_COMP_LEN 1
#define I3C_SLV_IMR_DDR_RD_COMP_MASK 0x00000008
#define I3C_SLV_IMR_DDR_RD_COMP_SET(x) (x << 3)
#define I3C_SLV_IMR_DDR_RD_COMP_GET(x) ((x >> 3) & 0x00000001)

/*!  DDR_WR_COMP Interrupt */
#define I3C_SLV_IMR_DDR_WR_COMP_POS 2
#define I3C_SLV_IMR_DDR_WR_COMP_LEN 1
#define I3C_SLV_IMR_DDR_WR_COMP_MASK 0x00000004
#define I3C_SLV_IMR_DDR_WR_COMP_SET(x) (x << 2)
#define I3C_SLV_IMR_DDR_WR_COMP_GET(x) ((x >> 2) & 0x00000001)

/*!  SDR_RD_COMP Interrupt */
#define I3C_SLV_IMR_SDR_RD_COMP_POS 1
#define I3C_SLV_IMR_SDR_RD_COMP_LEN 1
#define I3C_SLV_IMR_SDR_RD_COMP_MASK 0x00000002
#define I3C_SLV_IMR_SDR_RD_COMP_SET(x) (x << 1)
#define I3C_SLV_IMR_SDR_RD_COMP_GET(x) ((x >> 1) & 0x00000001)

/*!  SDR_WR_COMP Interrupt */
#define I3C_SLV_IMR_SDR_WR_COMP_POS 0
#define I3C_SLV_IMR_SDR_WR_COMP_LEN 1
#define I3C_SLV_IMR_SDR_WR_COMP_MASK 0x00000001
#define I3C_SLV_IMR_SDR_WR_COMP_SET(x) (x << 0)
#define I3C_SLV_IMR_SDR_WR_COMP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::SLV_ICR:: BitField descriptions
****************************************************/
/*!  DEFSLVS interrupt */
#define I3C_SLV_ICR_DEFSLVS_POS 21
#define I3C_SLV_ICR_DEFSLVS_LEN 1
#define I3C_SLV_ICR_DEFSLVS_MASK 0x00200000
#define I3C_SLV_ICR_DEFSLVS_SET(x) (x << 21)
#define I3C_SLV_ICR_DEFSLVS_GET(x) ((x >> 21) & 0x00000001)

/*!  TM Interrupt */
#define I3C_SLV_ICR_TM_POS 20
#define I3C_SLV_ICR_TM_LEN 1
#define I3C_SLV_ICR_TM_MASK 0x00100000
#define I3C_SLV_ICR_TM_SET(x) (x << 20)
#define I3C_SLV_ICR_TM_GET(x) ((x >> 20) & 0x00000001)

/*!  ERROR interrupt */
#define I3C_SLV_ICR_ERROR_POS 19
#define I3C_SLV_ICR_ERROR_LEN 1
#define I3C_SLV_ICR_ERROR_MASK 0x00080000
#define I3C_SLV_ICR_ERROR_SET(x) (x << 19)
#define I3C_SLV_ICR_ERROR_GET(x) ((x >> 19) & 0x00000001)

/*!  EVENT_UP interrupt */
#define I3C_SLV_ICR_EVENT_UP_POS 18
#define I3C_SLV_ICR_EVENT_UP_LEN 1
#define I3C_SLV_ICR_EVENT_UP_MASK 0x00040000
#define I3C_SLV_ICR_EVENT_UP_SET(x) (x << 18)
#define I3C_SLV_ICR_EVENT_UP_GET(x) ((x >> 18) & 0x00000001)

/*!  HJ_DONE Interrupt */
#define I3C_SLV_ICR_HJ_DONE_POS 17
#define I3C_SLV_ICR_HJ_DONE_LEN 1
#define I3C_SLV_ICR_HJ_DONE_MASK 0x00020000
#define I3C_SLV_ICR_HJ_DONE_SET(x) (x << 17)
#define I3C_SLV_ICR_HJ_DONE_GET(x) ((x >> 17) & 0x00000001)

/*!  MR_DONE interrupt */
#define I3C_SLV_ICR_MR_DONE_POS 16
#define I3C_SLV_ICR_MR_DONE_LEN 1
#define I3C_SLV_ICR_MR_DONE_MASK 0x00010000
#define I3C_SLV_ICR_MR_DONE_SET(x) (x << 16)
#define I3C_SLV_ICR_MR_DONE_GET(x) ((x >> 16) & 0x00000001)

/*!  DA_UPDATE Interrupt */
#define I3C_SLV_ICR_DA_UPDATE_POS 15
#define I3C_SLV_ICR_DA_UPDATE_LEN 1
#define I3C_SLV_ICR_DA_UPDATE_MASK 0x00008000
#define I3C_SLV_ICR_DA_UPDATE_SET(x) (x << 15)
#define I3C_SLV_ICR_DA_UPDATE_GET(x) ((x >> 15) & 0x00000001)

/*!  SDR_FAIL interrupt */
#define I3C_SLV_ICR_SDR_FAIL_POS 14
#define I3C_SLV_ICR_SDR_FAIL_LEN 1
#define I3C_SLV_ICR_SDR_FAIL_MASK 0x00004000
#define I3C_SLV_ICR_SDR_FAIL_SET(x) (x << 14)
#define I3C_SLV_ICR_SDR_FAIL_GET(x) ((x >> 14) & 0x00000001)

/*!  DDR_FAIL Interrupt */
#define I3C_SLV_ICR_DDR_FAIL_POS 13
#define I3C_SLV_ICR_DDR_FAIL_LEN 1
#define I3C_SLV_ICR_DDR_FAIL_MASK 0x00002000
#define I3C_SLV_ICR_DDR_FAIL_SET(x) (x << 13)
#define I3C_SLV_ICR_DDR_FAIL_GET(x) ((x >> 13) & 0x00000001)

/*!  M_RD_ABORT interrupt */
#define I3C_SLV_ICR_M_RD_ABORT_POS 12
#define I3C_SLV_ICR_M_RD_ABORT_LEN 1
#define I3C_SLV_ICR_M_RD_ABORT_MASK 0x00001000
#define I3C_SLV_ICR_M_RD_ABORT_SET(x) (x << 12)
#define I3C_SLV_ICR_M_RD_ABORT_GET(x) ((x >> 12) & 0x00000001)

/*!  DDR_RX_THR Interrupt */
#define I3C_SLV_ICR_DDR_RX_THR_POS 11
#define I3C_SLV_ICR_DDR_RX_THR_LEN 1
#define I3C_SLV_ICR_DDR_RX_THR_MASK 0x00000800
#define I3C_SLV_ICR_DDR_RX_THR_SET(x) (x << 11)
#define I3C_SLV_ICR_DDR_RX_THR_GET(x) ((x >> 11) & 0x00000001)

/*!  DDR_TX_THR Interrupt */
#define I3C_SLV_ICR_DDR_TX_THR_POS 10
#define I3C_SLV_ICR_DDR_TX_THR_LEN 1
#define I3C_SLV_ICR_DDR_TX_THR_MASK 0x00000400
#define I3C_SLV_ICR_DDR_TX_THR_SET(x) (x << 10)
#define I3C_SLV_ICR_DDR_TX_THR_GET(x) ((x >> 10) & 0x00000001)

/*!  SDR_RX_THR Interrupt */
#define I3C_SLV_ICR_SDR_RX_THR_POS 9
#define I3C_SLV_ICR_SDR_RX_THR_LEN 1
#define I3C_SLV_ICR_SDR_RX_THR_MASK 0x00000200
#define I3C_SLV_ICR_SDR_RX_THR_SET(x) (x << 9)
#define I3C_SLV_ICR_SDR_RX_THR_GET(x) ((x >> 9) & 0x00000001)

/*!  SDR_TX_THR Interrupt */
#define I3C_SLV_ICR_SDR_TX_THR_POS 8
#define I3C_SLV_ICR_SDR_TX_THR_LEN 1
#define I3C_SLV_ICR_SDR_TX_THR_MASK 0x00000100
#define I3C_SLV_ICR_SDR_TX_THR_SET(x) (x << 8)
#define I3C_SLV_ICR_SDR_TX_THR_GET(x) ((x >> 8) & 0x00000001)

/*!  DDR_RX_UNF Interrupt */
#define I3C_SLV_ICR_DDR_RX_UNF_POS 7
#define I3C_SLV_ICR_DDR_RX_UNF_LEN 1
#define I3C_SLV_ICR_DDR_RX_UNF_MASK 0x00000080
#define I3C_SLV_ICR_DDR_RX_UNF_SET(x) (x << 7)
#define I3C_SLV_ICR_DDR_RX_UNF_GET(x) ((x >> 7) & 0x00000001)

/*!  DDR_TX_OVF Interrupt */
#define I3C_SLV_ICR_DDR_TX_OVF_POS 6
#define I3C_SLV_ICR_DDR_TX_OVF_LEN 1
#define I3C_SLV_ICR_DDR_TX_OVF_MASK 0x00000040
#define I3C_SLV_ICR_DDR_TX_OVF_SET(x) (x << 6)
#define I3C_SLV_ICR_DDR_TX_OVF_GET(x) ((x >> 6) & 0x00000001)

/*!  SDR_RX_UNF Interrupt */
#define I3C_SLV_ICR_SDR_RX_UNF_POS 5
#define I3C_SLV_ICR_SDR_RX_UNF_LEN 1
#define I3C_SLV_ICR_SDR_RX_UNF_MASK 0x00000020
#define I3C_SLV_ICR_SDR_RX_UNF_SET(x) (x << 5)
#define I3C_SLV_ICR_SDR_RX_UNF_GET(x) ((x >> 5) & 0x00000001)

/*!  SDR_TX_OVF Interrupt */
#define I3C_SLV_ICR_SDR_TX_OVF_POS 4
#define I3C_SLV_ICR_SDR_TX_OVF_LEN 1
#define I3C_SLV_ICR_SDR_TX_OVF_MASK 0x00000010
#define I3C_SLV_ICR_SDR_TX_OVF_SET(x) (x << 4)
#define I3C_SLV_ICR_SDR_TX_OVF_GET(x) ((x >> 4) & 0x00000001)

/*!  DDR_RD_COMP Interrupt */
#define I3C_SLV_ICR_DDR_RD_COMP_POS 3
#define I3C_SLV_ICR_DDR_RD_COMP_LEN 1
#define I3C_SLV_ICR_DDR_RD_COMP_MASK 0x00000008
#define I3C_SLV_ICR_DDR_RD_COMP_SET(x) (x << 3)
#define I3C_SLV_ICR_DDR_RD_COMP_GET(x) ((x >> 3) & 0x00000001)

/*!  DDR_WR_COMP Interrupt */
#define I3C_SLV_ICR_DDR_WR_COMP_POS 2
#define I3C_SLV_ICR_DDR_WR_COMP_LEN 1
#define I3C_SLV_ICR_DDR_WR_COMP_MASK 0x00000004
#define I3C_SLV_ICR_DDR_WR_COMP_SET(x) (x << 2)
#define I3C_SLV_ICR_DDR_WR_COMP_GET(x) ((x >> 2) & 0x00000001)

/*!  SDR_RD_COMP Interrupt */
#define I3C_SLV_ICR_SDR_RD_COMP_POS 1
#define I3C_SLV_ICR_SDR_RD_COMP_LEN 1
#define I3C_SLV_ICR_SDR_RD_COMP_MASK 0x00000002
#define I3C_SLV_ICR_SDR_RD_COMP_SET(x) (x << 1)
#define I3C_SLV_ICR_SDR_RD_COMP_GET(x) ((x >> 1) & 0x00000001)

/*!  SDR_WR_COMP Interrupt */
#define I3C_SLV_ICR_SDR_WR_COMP_POS 0
#define I3C_SLV_ICR_SDR_WR_COMP_LEN 1
#define I3C_SLV_ICR_SDR_WR_COMP_MASK 0x00000001
#define I3C_SLV_ICR_SDR_WR_COMP_SET(x) (x << 0)
#define I3C_SLV_ICR_SDR_WR_COMP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::SLV_ISR:: BitField descriptions
****************************************************/
/*!  DEFSLVS interrupt */
#define I3C_SLV_ISR_DEFSLVS_POS 21
#define I3C_SLV_ISR_DEFSLVS_LEN 1
#define I3C_SLV_ISR_DEFSLVS_MASK 0x00200000
#define I3C_SLV_ISR_DEFSLVS_SET(x) (x << 21)
#define I3C_SLV_ISR_DEFSLVS_GET(x) ((x >> 21) & 0x00000001)

/*!  TM Interrupt */
#define I3C_SLV_ISR_TM_POS 20
#define I3C_SLV_ISR_TM_LEN 1
#define I3C_SLV_ISR_TM_MASK 0x00100000
#define I3C_SLV_ISR_TM_SET(x) (x << 20)
#define I3C_SLV_ISR_TM_GET(x) ((x >> 20) & 0x00000001)

/*!  ERROR interrupt */
#define I3C_SLV_ISR_ERROR_POS 19
#define I3C_SLV_ISR_ERROR_LEN 1
#define I3C_SLV_ISR_ERROR_MASK 0x00080000
#define I3C_SLV_ISR_ERROR_SET(x) (x << 19)
#define I3C_SLV_ISR_ERROR_GET(x) ((x >> 19) & 0x00000001)

/*!  EVENT_UP interrupt */
#define I3C_SLV_ISR_EVENT_UP_POS 18
#define I3C_SLV_ISR_EVENT_UP_LEN 1
#define I3C_SLV_ISR_EVENT_UP_MASK 0x00040000
#define I3C_SLV_ISR_EVENT_UP_SET(x) (x << 18)
#define I3C_SLV_ISR_EVENT_UP_GET(x) ((x >> 18) & 0x00000001)

/*!  HJ_DONE Interrupt */
#define I3C_SLV_ISR_HJ_DONE_POS 17
#define I3C_SLV_ISR_HJ_DONE_LEN 1
#define I3C_SLV_ISR_HJ_DONE_MASK 0x00020000
#define I3C_SLV_ISR_HJ_DONE_SET(x) (x << 17)
#define I3C_SLV_ISR_HJ_DONE_GET(x) ((x >> 17) & 0x00000001)

/*!  MR_DONE interrupt */
#define I3C_SLV_ISR_MR_DONE_POS 16
#define I3C_SLV_ISR_MR_DONE_LEN 1
#define I3C_SLV_ISR_MR_DONE_MASK 0x00010000
#define I3C_SLV_ISR_MR_DONE_SET(x) (x << 16)
#define I3C_SLV_ISR_MR_DONE_GET(x) ((x >> 16) & 0x00000001)

/*!  DA_UPDATE Interrupt */
#define I3C_SLV_ISR_DA_UPDATE_POS 15
#define I3C_SLV_ISR_DA_UPDATE_LEN 1
#define I3C_SLV_ISR_DA_UPDATE_MASK 0x00008000
#define I3C_SLV_ISR_DA_UPDATE_SET(x) (x << 15)
#define I3C_SLV_ISR_DA_UPDATE_GET(x) ((x >> 15) & 0x00000001)

/*!  SDR_FAIL interrupt */
#define I3C_SLV_ISR_SDR_FAIL_POS 14
#define I3C_SLV_ISR_SDR_FAIL_LEN 1
#define I3C_SLV_ISR_SDR_FAIL_MASK 0x00004000
#define I3C_SLV_ISR_SDR_FAIL_SET(x) (x << 14)
#define I3C_SLV_ISR_SDR_FAIL_GET(x) ((x >> 14) & 0x00000001)

/*!  DDR_FAIL Interrupt */
#define I3C_SLV_ISR_DDR_FAIL_POS 13
#define I3C_SLV_ISR_DDR_FAIL_LEN 1
#define I3C_SLV_ISR_DDR_FAIL_MASK 0x00002000
#define I3C_SLV_ISR_DDR_FAIL_SET(x) (x << 13)
#define I3C_SLV_ISR_DDR_FAIL_GET(x) ((x >> 13) & 0x00000001)

/*!  M_RD_ABORT interrupt */
#define I3C_SLV_ISR_M_RD_ABORT_POS 12
#define I3C_SLV_ISR_M_RD_ABORT_LEN 1
#define I3C_SLV_ISR_M_RD_ABORT_MASK 0x00001000
#define I3C_SLV_ISR_M_RD_ABORT_SET(x) (x << 12)
#define I3C_SLV_ISR_M_RD_ABORT_GET(x) ((x >> 12) & 0x00000001)

/*!  DDR_RX_THR Interrupt */
#define I3C_SLV_ISR_DDR_RX_THR_POS 11
#define I3C_SLV_ISR_DDR_RX_THR_LEN 1
#define I3C_SLV_ISR_DDR_RX_THR_MASK 0x00000800
#define I3C_SLV_ISR_DDR_RX_THR_SET(x) (x << 11)
#define I3C_SLV_ISR_DDR_RX_THR_GET(x) ((x >> 11) & 0x00000001)

/*!  DDR_TX_THR Interrupt */
#define I3C_SLV_ISR_DDR_TX_THR_POS 10
#define I3C_SLV_ISR_DDR_TX_THR_LEN 1
#define I3C_SLV_ISR_DDR_TX_THR_MASK 0x00000400
#define I3C_SLV_ISR_DDR_TX_THR_SET(x) (x << 10)
#define I3C_SLV_ISR_DDR_TX_THR_GET(x) ((x >> 10) & 0x00000001)

/*!  SDR_RX_THR Interrupt */
#define I3C_SLV_ISR_SDR_RX_THR_POS 9
#define I3C_SLV_ISR_SDR_RX_THR_LEN 1
#define I3C_SLV_ISR_SDR_RX_THR_MASK 0x00000200
#define I3C_SLV_ISR_SDR_RX_THR_SET(x) (x << 9)
#define I3C_SLV_ISR_SDR_RX_THR_GET(x) ((x >> 9) & 0x00000001)

/*!  SDR_TX_THR Interrupt */
#define I3C_SLV_ISR_SDR_TX_THR_POS 8
#define I3C_SLV_ISR_SDR_TX_THR_LEN 1
#define I3C_SLV_ISR_SDR_TX_THR_MASK 0x00000100
#define I3C_SLV_ISR_SDR_TX_THR_SET(x) (x << 8)
#define I3C_SLV_ISR_SDR_TX_THR_GET(x) ((x >> 8) & 0x00000001)

/*!  DDR_RX_UNF Interrupt */
#define I3C_SLV_ISR_DDR_RX_UNF_POS 7
#define I3C_SLV_ISR_DDR_RX_UNF_LEN 1
#define I3C_SLV_ISR_DDR_RX_UNF_MASK 0x00000080
#define I3C_SLV_ISR_DDR_RX_UNF_SET(x) (x << 7)
#define I3C_SLV_ISR_DDR_RX_UNF_GET(x) ((x >> 7) & 0x00000001)

/*!  DDR_TX_OVF Interrupt */
#define I3C_SLV_ISR_DDR_TX_OVF_POS 6
#define I3C_SLV_ISR_DDR_TX_OVF_LEN 1
#define I3C_SLV_ISR_DDR_TX_OVF_MASK 0x00000040
#define I3C_SLV_ISR_DDR_TX_OVF_SET(x) (x << 6)
#define I3C_SLV_ISR_DDR_TX_OVF_GET(x) ((x >> 6) & 0x00000001)

/*!  SDR_RX_UNF Interrupt */
#define I3C_SLV_ISR_SDR_RX_UNF_POS 5
#define I3C_SLV_ISR_SDR_RX_UNF_LEN 1
#define I3C_SLV_ISR_SDR_RX_UNF_MASK 0x00000020
#define I3C_SLV_ISR_SDR_RX_UNF_SET(x) (x << 5)
#define I3C_SLV_ISR_SDR_RX_UNF_GET(x) ((x >> 5) & 0x00000001)

/*!  SDR_TX_OVF Interrupt */
#define I3C_SLV_ISR_SDR_TX_OVF_POS 4
#define I3C_SLV_ISR_SDR_TX_OVF_LEN 1
#define I3C_SLV_ISR_SDR_TX_OVF_MASK 0x00000010
#define I3C_SLV_ISR_SDR_TX_OVF_SET(x) (x << 4)
#define I3C_SLV_ISR_SDR_TX_OVF_GET(x) ((x >> 4) & 0x00000001)

/*!  DDR_RD_COMP Interrupt */
#define I3C_SLV_ISR_DDR_RD_COMP_POS 3
#define I3C_SLV_ISR_DDR_RD_COMP_LEN 1
#define I3C_SLV_ISR_DDR_RD_COMP_MASK 0x00000008
#define I3C_SLV_ISR_DDR_RD_COMP_SET(x) (x << 3)
#define I3C_SLV_ISR_DDR_RD_COMP_GET(x) ((x >> 3) & 0x00000001)

/*!  DDR_WR_COMP Interrupt */
#define I3C_SLV_ISR_DDR_WR_COMP_POS 2
#define I3C_SLV_ISR_DDR_WR_COMP_LEN 1
#define I3C_SLV_ISR_DDR_WR_COMP_MASK 0x00000004
#define I3C_SLV_ISR_DDR_WR_COMP_SET(x) (x << 2)
#define I3C_SLV_ISR_DDR_WR_COMP_GET(x) ((x >> 2) & 0x00000001)

/*!  SDR_RD_COMP Interrupt */
#define I3C_SLV_ISR_SDR_RD_COMP_POS 1
#define I3C_SLV_ISR_SDR_RD_COMP_LEN 1
#define I3C_SLV_ISR_SDR_RD_COMP_MASK 0x00000002
#define I3C_SLV_ISR_SDR_RD_COMP_SET(x) (x << 1)
#define I3C_SLV_ISR_SDR_RD_COMP_GET(x) ((x >> 1) & 0x00000001)

/*!  SDR_WR_COMP Interrupt */
#define I3C_SLV_ISR_SDR_WR_COMP_POS 0
#define I3C_SLV_ISR_SDR_WR_COMP_LEN 1
#define I3C_SLV_ISR_SDR_WR_COMP_MASK 0x00000001
#define I3C_SLV_ISR_SDR_WR_COMP_SET(x) (x << 0)
#define I3C_SLV_ISR_SDR_WR_COMP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::SLV_STATUS0:: BitField descriptions
****************************************************/
/*! Transfer bytes */

/*! Register Address */
#define I3C_BKP_CONF_STATUS0_REG_ADDR_POS 16
#define I3C_BKP_CONF_STATUS0_REG_ADDR_LEN 8
#define I3C_BKP_CONF_STATUS0_REG_ADDR_MASK 0x00ff0000
#define I3C_BKP_CONF_STATUS0_REG_ADDR_SET(x) (x << 16)
#define I3C_BKP_CONF_STATUS0_REG_ADDR_GET(x) ((x >> 16) & 0x000000ff)

#define I3C_BKP_CONF_STATUS0_XFER_BYTES_POS 0
#define I3C_BKP_CONF_STATUS0_XFER_BYTES_LEN 16
#define I3C_BKP_CONF_STATUS0_XFER_BYTES_MASK 0x0000ffff
#define I3C_BKP_CONF_STATUS0_XFER_BYTES_SET(x) (x << 0)
#define I3C_BKP_CONF_STATUS0_XFER_BYTES_GET(x) ((x >> 0) & 0x0000ffff)

/****************************************************
  ::SLV_STATUS1:: BitField descriptions
****************************************************/
/*!  indicate current Activity State */
#define I3C_SLV_STATUS1_ENTAS_POS 20
#define I3C_SLV_STATUS1_ENTAS_LEN 2
#define I3C_SLV_STATUS1_ENTAS_MASK 0x00300000
#define I3C_SLV_STATUS1_ENTAS_SET(x) (x << 20)
#define I3C_SLV_STATUS1_ENTAS_GET(x) ((x >> 20) & 0x00000003)

/*!  Vendor Test Mode */
#define I3C_SLV_STATUS1_VEN_TM_POS 19
#define I3C_SLV_STATUS1_VEN_TM_LEN 1
#define I3C_SLV_STATUS1_VEN_TM_MASK 0x00080000
#define I3C_SLV_STATUS1_VEN_TM_SET(x) (x << 19)
#define I3C_SLV_STATUS1_VEN_TM_GET(x) ((x >> 19) & 0x00000001)

/*!  Hot-Join Disabled */
#define I3C_SLV_STATUS1_HJ_DIS_POS 18
#define I3C_SLV_STATUS1_HJ_DIS_LEN 1
#define I3C_SLV_STATUS1_HJ_DIS_MASK 0x00040000
#define I3C_SLV_STATUS1_HJ_DIS_SET(x) (x << 18)
#define I3C_SLV_STATUS1_HJ_DIS_GET(x) ((x >> 18) & 0x00000001)

/*!  MR request is disabled */
#define I3C_SLV_STATUS1_MR_DIS_POS 17
#define I3C_SLV_STATUS1_MR_DIS_LEN 1
#define I3C_SLV_STATUS1_MR_DIS_MASK 0x00020000
#define I3C_SLV_STATUS1_MR_DIS_SET(x) (x << 17)
#define I3C_SLV_STATUS1_MR_DIS_GET(x) ((x >> 17) & 0x00000001)

/*!  Protocol Error Condition Indicator */
#define I3C_SLV_STATUS1_PROT_ERROR_POS 16
#define I3C_SLV_STATUS1_PROT_ERROR_LEN 1
#define I3C_SLV_STATUS1_PROT_ERROR_MASK 0x00010000
#define I3C_SLV_STATUS1_PROT_ERROR_SET(x) (x << 16)
#define I3C_SLV_STATUS1_PROT_ERROR_GET(x) ((x >> 16) & 0x00000001)

/*!  Current Slave Dynamic Address */
#define I3C_SLV_STATUS1_DA_POS 9
#define I3C_SLV_STATUS1_DA_LEN 7
#define I3C_SLV_STATUS1_DA_MASK 0x0000fe00
#define I3C_SLV_STATUS1_DA_SET(x) (x << 9)
#define I3C_SLV_STATUS1_DA_GET(x) ((x >> 9) & 0x0000007f)

/*!  Slave has Dynamic Address assigned */
#define I3C_SLV_STATUS1_HAS_DA_POS 8
#define I3C_SLV_STATUS1_HAS_DA_LEN 1
#define I3C_SLV_STATUS1_HAS_DA_MASK 0x00000100
#define I3C_SLV_STATUS1_HAS_DA_SET(x) (x << 8)
#define I3C_SLV_STATUS1_HAS_DA_GET(x) ((x >> 8) & 0x00000001)

/*!  DDRRX FIFO FULL */
#define I3C_SLV_STATUS1_DDRRX_FULL_POS 7
#define I3C_SLV_STATUS1_DDRRX_FULL_LEN 1
#define I3C_SLV_STATUS1_DDRRX_FULL_MASK 0x00000080
#define I3C_SLV_STATUS1_DDRRX_FULL_SET(x) (x << 7)
#define I3C_SLV_STATUS1_DDRRX_FULL_GET(x) ((x >> 7) & 0x00000001)

/*!  DDRTX FIFO FULL */
#define I3C_SLV_STATUS1_DDRTX_FULL_POS 6
#define I3C_SLV_STATUS1_DDRTX_FULL_LEN 1
#define I3C_SLV_STATUS1_DDRTX_FULL_MASK 0x00000040
#define I3C_SLV_STATUS1_DDRTX_FULL_SET(x) (x << 6)
#define I3C_SLV_STATUS1_DDRTX_FULL_GET(x) ((x >> 6) & 0x00000001)

/*!  DDRRX FIFO EMPTY */
#define I3C_SLV_STATUS1_DDRRX_EMPTY_POS 5
#define I3C_SLV_STATUS1_DDRRX_EMPTY_LEN 1
#define I3C_SLV_STATUS1_DDRRX_EMPTY_MASK 0x00000020
#define I3C_SLV_STATUS1_DDRRX_EMPTY_SET(x) (x << 5)
#define I3C_SLV_STATUS1_DDRRX_EMPTY_GET(x) ((x >> 5) & 0x00000001)

/*!  DDRTX FIFO EMPTY */
#define I3C_SLV_STATUS1_DDRTX_EMPTY_POS 4
#define I3C_SLV_STATUS1_DDRTX_EMPTY_LEN 1
#define I3C_SLV_STATUS1_DDRTX_EMPTY_MASK 0x00000010
#define I3C_SLV_STATUS1_DDRTX_EMPTY_SET(x) (x << 4)
#define I3C_SLV_STATUS1_DDRTX_EMPTY_GET(x) ((x >> 4) & 0x00000001)

/*!  SDRRX FIFO FULL */
#define I3C_SLV_STATUS1_SDRRX_FULL_POS 3
#define I3C_SLV_STATUS1_SDRRX_FULL_LEN 1
#define I3C_SLV_STATUS1_SDRRX_FULL_MASK 0x00000008
#define I3C_SLV_STATUS1_SDRRX_FULL_SET(x) (x << 3)
#define I3C_SLV_STATUS1_SDRRX_FULL_GET(x) ((x >> 3) & 0x00000001)

/*!  SDRTX FIFO FULL */
#define I3C_SLV_STATUS1_SDTRX_FULL_POS 2
#define I3C_SLV_STATUS1_SDTRX_FULL_LEN 1
#define I3C_SLV_STATUS1_SDTRX_FULL_MASK 0x00000004
#define I3C_SLV_STATUS1_SDTRX_FULL_SET(x) (x << 2)
#define I3C_SLV_STATUS1_SDTRX_FULL_GET(x) ((x >> 2) & 0x00000001)

/*!  SDRRX FIFO EMPTY */
#define I3C_SLV_STATUS1_SDRRX_EMPTY_POS 1
#define I3C_SLV_STATUS1_SDRRX_EMPTY_LEN 1
#define I3C_SLV_STATUS1_SDRRX_EMPTY_MASK 0x00000002
#define I3C_SLV_STATUS1_SDRRX_EMPTY_SET(x) (x << 1)
#define I3C_SLV_STATUS1_SDRRX_EMPTY_GET(x) ((x >> 1) & 0x00000001)

/*!  SDRTX FIFO EMPTY */
#define I3C_SLV_STATUS1_SDTRX_EMPTY_POS 0
#define I3C_SLV_STATUS1_SDTRX_EMPTY_LEN 1
#define I3C_SLV_STATUS1_SDTRX_EMPTY_MASK 0x00000001
#define I3C_SLV_STATUS1_SDTRX_EMPTY_SET(x) (x << 0)
#define I3C_SLV_STATUS1_SDTRX_EMPTY_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::CMD0_FIFO:: BitField descriptions
****************************************************/
/*!  IS DDR command */
#define I3C_CMD0_FIFO_IS_DDR_POS 31
#define I3C_CMD0_FIFO_IS_DDR_LEN 1
#define I3C_CMD0_FIFO_IS_DDR_MASK 0x80000000
#define I3C_CMD0_FIFO_IS_DDR_SET(x) (x << 31)
#define I3C_CMD0_FIFO_IS_DDR_GET(x) ((x >> 31) & 0x00000001)

#define I3C_CMD0_FIFO_IS_DDR_SDR_MODE 0x00000
#define I3C_CMD0_FIFO_IS_DDR_DDR_MODE 0x00001
/*!  CCC or generic command */
#define I3C_CMD0_FIFO_IS_CCC_POS 30
#define I3C_CMD0_FIFO_IS_CCC_LEN 1
#define I3C_CMD0_FIFO_IS_CCC_MASK 0x40000000
#define I3C_CMD0_FIFO_IS_CCC_SET(x) (x << 30)
#define I3C_CMD0_FIFO_IS_CCC_GET(x) ((x >> 30) & 0x00000001)

#define I3C_CMD0_FIFO_IS_CCC_GEN_CMD 0x00000
#define I3C_CMD0_FIFO_IS_CCC_CCC_CMD 0x00001
/*!  Broadcast Header */
#define I3C_CMD0_FIFO_BCH_POS 29
#define I3C_CMD0_FIFO_BCH_LEN 1
#define I3C_CMD0_FIFO_BCH_MASK 0x20000000
#define I3C_CMD0_FIFO_BCH_SET(x) (x << 29)
#define I3C_CMD0_FIFO_BCH_GET(x) ((x >> 29) & 0x00000001)

#define I3C_CMD0_FIFO_BCH_BCH_DISABLED 0x00000
#define I3C_CMD0_FIFO_BCH_BCH_ENABLED 0x00001
/*!  transfer modes for I3C private read/write commands */
#define I3C_CMD0_FIFO_XMIT_MODE_POS 27
#define I3C_CMD0_FIFO_XMIT_MODE_LEN 2
#define I3C_CMD0_FIFO_XMIT_MODE_MASK 0x18000000
#define I3C_CMD0_FIFO_XMIT_MODE_SET(x) (x << 27)
#define I3C_CMD0_FIFO_XMIT_MODE_GET(x) ((x >> 27) & 0x00000003)

#define I3C_CMD0_FIFO_XMIT_MODE_BURST_WITH_SELF_INC_ADDR 0x00000
#define I3C_CMD0_FIFO_XMIT_MODE_SINGLE_WITH_SELF_INC_ADDR 0x00001
#define I3C_CMD0_FIFO_XMIT_MODE_SINGLE 0x00002
#define I3C_CMD0_FIFO_XMIT_MODE_BURST 0x00003
/*!  sixteen Bits register sub-addressing */
#define I3C_CMD0_FIFO_SBCA_POS 26
#define I3C_CMD0_FIFO_SBCA_LEN 1
#define I3C_CMD0_FIFO_SBCA_MASK 0x04000000
#define I3C_CMD0_FIFO_SBCA_SET(x) (x << 26)
#define I3C_CMD0_FIFO_SBCA_GET(x) ((x >> 26) & 0x00000001)

/*!  Repeated Start Between Commands */
#define I3C_CMD0_FIFO_RSBC_POS 25
#define I3C_CMD0_FIFO_RSBC_LEN 1
#define I3C_CMD0_FIFO_RSBC_MASK 0x02000000
#define I3C_CMD0_FIFO_RSBC_SET(x) (x << 25)
#define I3C_CMD0_FIFO_RSBC_GET(x) ((x >> 25) & 0x00000001)

/*!  Normal/Extended Address selector */
#define I3C_CMD0_FIFO_IS_10B_POS 24
#define I3C_CMD0_FIFO_IS_10B_LEN 1
#define I3C_CMD0_FIFO_IS_10B_MASK 0x01000000
#define I3C_CMD0_FIFO_IS_10B_SET(x) (x << 24)
#define I3C_CMD0_FIFO_IS_10B_GET(x) ((x >> 24) & 0x00000001)

/*!  number of bytes to be send */
#define I3C_CMD0_FIFO_PL_LEN_POS 12
#define I3C_CMD0_FIFO_PL_LEN_LEN 12
#define I3C_CMD0_FIFO_PL_LEN_MASK 0x00fff000
#define I3C_CMD0_FIFO_PL_LEN_SET(x) (x << 12)
#define I3C_CMD0_FIFO_PL_LEN_GET(x) ((x >> 12) & 0x00000fff)

/*!  3 MSBs of legacy I2C 10-bit address */
#define I3C_CMD0_FIFO_DEV_ADDR_MSB_POS 8
#define I3C_CMD0_FIFO_DEV_ADDR_MSB_LEN 3
#define I3C_CMD0_FIFO_DEV_ADDR_MSB_MASK 0x00000700
#define I3C_CMD0_FIFO_DEV_ADDR_MSB_SET(x) (x << 8)
#define I3C_CMD0_FIFO_DEV_ADDR_MSB_GET(x) ((x >> 8) & 0x00000007)

/*!  Corresponds to a given slave Dynamic or Static Address */
#define I3C_CMD0_FIFO_DEV_ADDR_POS 1
#define I3C_CMD0_FIFO_DEV_ADDR_LEN 7
#define I3C_CMD0_FIFO_DEV_ADDR_MASK 0x000000fe
#define I3C_CMD0_FIFO_DEV_ADDR_SET(x) (x << 1)
#define I3C_CMD0_FIFO_DEV_ADDR_GET(x) ((x >> 1) & 0x0000007f)

/*!  direction of transfer */
#define I3C_CMD0_FIFO_RNW_POS 0
#define I3C_CMD0_FIFO_RNW_LEN 1
#define I3C_CMD0_FIFO_RNW_MASK 0x00000001
#define I3C_CMD0_FIFO_RNW_SET(x) (x << 0)
#define I3C_CMD0_FIFO_RNW_GET(x) ((x >> 0) & 0x00000001)

#define I3C_CMD0_FIFO_RNW_WRITE_XFER 0x00000
#define I3C_CMD0_FIFO_RNW_READ_XFER 0x00001
/****************************************************
  ::CMD1_FIFO:: BitField descriptions
****************************************************/
/*!  command identifier */
#define I3C_CMD1_FIFO_CMD_ID_POS 24
#define I3C_CMD1_FIFO_CMD_ID_LEN 8
#define I3C_CMD1_FIFO_CMD_ID_MASK 0xff000000
#define I3C_CMD1_FIFO_CMD_ID_SET(x) (x << 24)
#define I3C_CMD1_FIFO_CMD_ID_GET(x) ((x >> 24) & 0x000000ff)

/*!  second byte of the slave register sub-address */
#define I3C_CMD1_FIFO_CSR_ADDR1_POS 8
#define I3C_CMD1_FIFO_CSR_ADDR1_LEN 8
#define I3C_CMD1_FIFO_CSR_ADDR1_MASK 0x0000ff00
#define I3C_CMD1_FIFO_CSR_ADDR1_SET(x) (x << 8)
#define I3C_CMD1_FIFO_CSR_ADDR1_GET(x) ((x >> 8) & 0x000000ff)

/*!  CCC or CSR Address */
#define I3C_CMD1_FIFO_CCC_CSR_ADDR0_POS 0
#define I3C_CMD1_FIFO_CCC_CSR_ADDR0_LEN 8
#define I3C_CMD1_FIFO_CCC_CSR_ADDR0_MASK 0x000000ff
#define I3C_CMD1_FIFO_CCC_CSR_ADDR0_SET(x) (x << 0)
#define I3C_CMD1_FIFO_CCC_CSR_ADDR0_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::TX_FIFO:: BitField descriptions
****************************************************/
/*!  Tx Data FIFO */
#define I3C_TX_FIFO_DATA_POS 0
#define I3C_TX_FIFO_DATA_LEN 32
#define I3C_TX_FIFO_DATA_MASK 0xffffffff
#define I3C_TX_FIFO_DATA_SET(x) (x)
#define I3C_TX_FIFO_DATA_GET(x) (x)

/****************************************************
  ::IMD_CMD0:: BitField descriptions
****************************************************/
/*!  Payload Length */
#define I3C_IMD_CMD0_PL_LEN_POS 12
#define I3C_IMD_CMD0_PL_LEN_LEN 3
#define I3C_IMD_CMD0_PL_LEN_MASK 0x00007000
#define I3C_IMD_CMD0_PL_LEN_SET(x) (x << 12)
#define I3C_IMD_CMD0_PL_LEN_GET(x) ((x >> 12) & 0x00000007)

/*!  Static/Dynamic slave Address */
#define I3C_IMD_CMD0_DEV_ADDR_POS 1
#define I3C_IMD_CMD0_DEV_ADDR_LEN 7
#define I3C_IMD_CMD0_DEV_ADDR_MASK 0x000000fe
#define I3C_IMD_CMD0_DEV_ADDR_SET(x) (x << 1)
#define I3C_IMD_CMD0_DEV_ADDR_GET(x) ((x >> 1) & 0x0000007f)

/*!  direction of transfer */
#define I3C_IMD_CMD0_RNW_POS 0
#define I3C_IMD_CMD0_RNW_LEN 1
#define I3C_IMD_CMD0_RNW_MASK 0x00000001
#define I3C_IMD_CMD0_RNW_SET(x) (x << 0)
#define I3C_IMD_CMD0_RNW_GET(x) ((x >> 0) & 0x00000001)

#define I3C_IMD_CMD0_RNW_WRITE_XFER 0x00000
#define I3C_IMD_CMD0_RNW_READ_XFER 0x00001
/****************************************************
  ::IMD_CMD1:: BitField descriptions
****************************************************/
/*!  command identifier */
#define I3C_BKP_IMD_CMD1_CMD_ID_POS 24
#define I3C_BKP_IMD_CMD1_CMD_ID_LEN 8
#define I3C_BKP_IMD_CMD1_CMD_ID_MASK 0xff000000
#define I3C_BKP_IMD_CMD1_CMD_ID_SET(x) (x << 24)
#define I3C_BKP_IMD_CMD1_CMD_ID_GET(x) ((x >> 24) & 0x000000ff)

/*!  CCC code */
#define I3C_IMD_CMD1_CCC_POS 0
#define I3C_IMD_CMD1_CCC_LEN 8
#define I3C_IMD_CMD1_CCC_MASK 0x000000ff
#define I3C_IMD_CMD1_CCC_SET(x) (x << 0)
#define I3C_IMD_CMD1_CCC_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::IMD_DATA:: BitField descriptions
****************************************************/
/*!   DATA */
#define I3C_IMD_DATA_DATA_POS 0
#define I3C_IMD_DATA_DATA_LEN 32
#define I3C_IMD_DATA_DATA_MASK 0xffffffff
#define I3C_IMD_DATA_DATA_SET(x) (x)
#define I3C_IMD_DATA_DATA_GET(x) (x)

/****************************************************
  ::RX_FIFO:: BitField descriptions
****************************************************/
/*!   DATA */
#define I3C_RX_FIFO_DATA_POS 0
#define I3C_RX_FIFO_DATA_LEN 32
#define I3C_RX_FIFO_DATA_MASK 0xffffffff
#define I3C_RX_FIFO_DATA_SET(x) (x)
#define I3C_RX_FIFO_DATA_GET(x) (x)

/****************************************************
  ::IBI_DATA_FIFO:: BitField descriptions
****************************************************/
/*!   DATA */
#define I3C_IBI_DATA_FIFO_DATA_POS 0
#define I3C_IBI_DATA_FIFO_DATA_LEN 32
#define I3C_IBI_DATA_FIFO_DATA_MASK 0xffffffff
#define I3C_IBI_DATA_FIFO_DATA_SET(x) (x)
#define I3C_IBI_DATA_FIFO_DATA_GET(x) (x)

/****************************************************
  ::SLV_DDR_TX_FIFO:: BitField descriptions
****************************************************/
/*!   DATA */
#define I3C_SLV_DDR_TX_FIFO_DATA_POS 0
#define I3C_SLV_DDR_TX_FIFO_DATA_LEN 20
#define I3C_SLV_DDR_TX_FIFO_DATA_MASK 0x000fffff
#define I3C_SLV_DDR_TX_FIFO_DATA_SET(x) (x << 0)
#define I3C_SLV_DDR_TX_FIFO_DATA_GET(x) ((x >> 0) & 0x000fffff)

/****************************************************
  ::SLV_DDR_RX_FIFO:: BitField descriptions
****************************************************/
/*!   DATA */
#define I3C_SLV_DDR_RX_FIFO_DATA_POS 0
#define I3C_SLV_DDR_RX_FIFO_DATA_LEN 20
#define I3C_SLV_DDR_RX_FIFO_DATA_MASK 0x000fffff
#define I3C_SLV_DDR_RX_FIFO_DATA_SET(x) (x << 0)
#define I3C_SLV_DDR_RX_FIFO_DATA_GET(x) ((x >> 0) & 0x000fffff)

/****************************************************
  ::CMD_IBI_THR_CTRL:: BitField descriptions
****************************************************/
/*!  IBIR THR */
#define I3C_CMD_IBI_THR_CTRL_IBIR_THR_POS 24
#define I3C_CMD_IBI_THR_CTRL_IBIR_THR_LEN 6
#define I3C_CMD_IBI_THR_CTRL_IBIR_THR_MASK 0x3f000000
#define I3C_CMD_IBI_THR_CTRL_IBIR_THR_SET(x) (x << 24)
#define I3C_CMD_IBI_THR_CTRL_IBIR_THR_GET(x) ((x >> 24) & 0x0000003f)

/*!  CMDR_THR */
#define I3C_CMD_IBI_THR_CTRL_CMDR_THR_POS 16
#define I3C_CMD_IBI_THR_CTRL_CMDR_THR_LEN 5
#define I3C_CMD_IBI_THR_CTRL_CMDR_THR_MASK 0x001f0000
#define I3C_CMD_IBI_THR_CTRL_CMDR_THR_SET(x) (x << 16)
#define I3C_CMD_IBI_THR_CTRL_CMDR_THR_GET(x) ((x >> 16) & 0x0000001f)

/*!  IBI THR */
#define I3C_CMD_IBI_THR_CTRL_IBI_THR_POS 8
#define I3C_CMD_IBI_THR_CTRL_IBI_THR_LEN 6
#define I3C_CMD_IBI_THR_CTRL_IBI_THR_MASK 0x00003f00
#define I3C_CMD_IBI_THR_CTRL_IBI_THR_SET(x) (x << 8)
#define I3C_CMD_IBI_THR_CTRL_IBI_THR_GET(x) ((x >> 8) & 0x0000003f)

/*!  CMD_THR */
#define I3C_CMD_IBI_THR_CTRL_CMD_THR_POS 0
#define I3C_CMD_IBI_THR_CTRL_CMD_THR_LEN 5
#define I3C_CMD_IBI_THR_CTRL_CMD_THR_MASK 0x0000001f
#define I3C_CMD_IBI_THR_CTRL_CMD_THR_SET(x) (x << 0)
#define I3C_CMD_IBI_THR_CTRL_CMD_THR_GET(x) ((x >> 0) & 0x0000001f)

/****************************************************
  ::TX_RX_THR_CTRL:: BitField descriptions
****************************************************/
/*!  RX THR */
#define I3C_TX_RX_THR_CTRL_RX_THR_POS 16
#define I3C_TX_RX_THR_CTRL_RX_THR_LEN 16
#define I3C_TX_RX_THR_CTRL_RX_THR_MASK 0xffff0000
#define I3C_TX_RX_THR_CTRL_RX_THR_SET(x) (x << 16)
#define I3C_TX_RX_THR_CTRL_RX_THR_GET(x) ((x >> 16) & 0x0000ffff)

/*!  TX_THR */
#define I3C_TX_RX_THR_CTRL_TX_THR_POS 0
#define I3C_TX_RX_THR_CTRL_TX_THR_LEN 16
#define I3C_TX_RX_THR_CTRL_TX_THR_MASK 0x0000ffff
#define I3C_TX_RX_THR_CTRL_TX_THR_SET(x) (x << 0)
#define I3C_TX_RX_THR_CTRL_TX_THR_GET(x) ((x >> 0) & 0x0000ffff)

/****************************************************
  ::SLV_DDR_TX_RX_THR_CTRL:: BitField descriptions
****************************************************/
/*!  RX THR */
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_RX_THR_POS 16
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_RX_THR_LEN 16
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_RX_THR_MASK 0xffff0000
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_RX_THR_SET(x) (x << 16)
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_RX_THR_GET(x) ((x >> 16) & 0x0000ffff)

/*!  TX_THR */
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_TX_THR_POS 0
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_TX_THR_LEN 16
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_TX_THR_MASK 0x0000ffff
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_TX_THR_SET(x) (x << 0)
#define I3C_SLV_DDR_TX_RX_THR_CTRL_SLV_DDR_TX_THR_GET(x) ((x >> 0) & 0x0000ffff)

/****************************************************
  ::FLUSH_CTRL:: BitField descriptions
****************************************************/
/*!  IBI RESP FLUSH */
#define I3C_FLUSH_CTRL_IBI_RESP_FLUSH_POS 24
#define I3C_FLUSH_CTRL_IBI_RESP_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_IBI_RESP_FLUSH_MASK 0x01000000
#define I3C_FLUSH_CTRL_IBI_RESP_FLUSH_SET(x) (x << 24)
#define I3C_FLUSH_CTRL_IBI_RESP_FLUSH_GET(x) ((x >> 24) & 0x00000001)

/*!  CMD RESP FLUSH */
#define I3C_FLUSH_CTRL_CMD_RESP_FLUSH_POS 23
#define I3C_FLUSH_CTRL_CMD_RESP_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_CMD_RESP_FLUSH_MASK 0x00800000
#define I3C_FLUSH_CTRL_CMD_RESP_FLUSH_SET(x) (x << 23)
#define I3C_FLUSH_CTRL_CMD_RESP_FLUSH_GET(x) ((x >> 23) & 0x00000001)

/*!  SLV DDR RX FIFO FLUSH */
#define I3C_FLUSH_CTRL_SLV_DDR_RX_FIFO_FLUSH_POS 22
#define I3C_FLUSH_CTRL_SLV_DDR_RX_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_SLV_DDR_RX_FIFO_FLUSH_MASK 0x00400000
#define I3C_FLUSH_CTRL_SLV_DDR_RX_FIFO_FLUSH_SET(x) (x << 22)
#define I3C_FLUSH_CTRL_SLV_DDR_RX_FIFO_FLUSH_GET(x) ((x >> 22) & 0x00000001)

/*!  SLV DDR TX FIFO FLUSH */
#define I3C_FLUSH_CTRL_SLV_DDR_TX_FIFO_FLUSH_POS 21
#define I3C_FLUSH_CTRL_SLV_DDR_TX_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_SLV_DDR_TX_FIFO_FLUSH_MASK 0x00200000
#define I3C_FLUSH_CTRL_SLV_DDR_TX_FIFO_FLUSH_SET(x) (x << 21)
#define I3C_FLUSH_CTRL_SLV_DDR_TX_FIFO_FLUSH_GET(x) ((x >> 21) & 0x00000001)

/*!  IMM_FIFO_FLUSH */
#define I3C_FLUSH_CTRL_IMM_FIFO_FLUSH_POS 20
#define I3C_FLUSH_CTRL_IMM_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_IMM_FIFO_FLUSH_MASK 0x00100000
#define I3C_FLUSH_CTRL_IMM_FIFO_FLUSH_SET(x) (x << 20)
#define I3C_FLUSH_CTRL_IMM_FIFO_FLUSH_GET(x) ((x >> 20) & 0x00000001)

/*!  IBI_FIFO_FLUSH */
#define I3C_FLUSH_CTRL_IBI_FIFO_FLUSH_POS 19
#define I3C_FLUSH_CTRL_IBI_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_IBI_FIFO_FLUSH_MASK 0x00080000
#define I3C_FLUSH_CTRL_IBI_FIFO_FLUSH_SET(x) (x << 19)
#define I3C_FLUSH_CTRL_IBI_FIFO_FLUSH_GET(x) ((x >> 19) & 0x00000001)

/*!  RX_FIFO_FLUSH */
#define I3C_FLUSH_CTRL_RX_FIFO_FLUSH_POS 18
#define I3C_FLUSH_CTRL_RX_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_RX_FIFO_FLUSH_MASK 0x00040000
#define I3C_FLUSH_CTRL_RX_FIFO_FLUSH_SET(x) (x << 18)
#define I3C_FLUSH_CTRL_RX_FIFO_FLUSH_GET(x) ((x >> 18) & 0x00000001)

/*!  TX_FIFO_FLUSH */
#define I3C_FLUSH_CTRL_TX_FIFO_FLUSH_POS 17
#define I3C_FLUSH_CTRL_TX_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_TX_FIFO_FLUSH_MASK 0x00020000
#define I3C_FLUSH_CTRL_TX_FIFO_FLUSH_SET(x) (x << 17)
#define I3C_FLUSH_CTRL_TX_FIFO_FLUSH_GET(x) ((x >> 17) & 0x00000001)

/*!  CMD_FIFO_FLUSH */
#define I3C_FLUSH_CTRL_CMD_FIFO_FLUSH_POS 16
#define I3C_FLUSH_CTRL_CMD_FIFO_FLUSH_LEN 1
#define I3C_FLUSH_CTRL_CMD_FIFO_FLUSH_MASK 0x00010000
#define I3C_FLUSH_CTRL_CMD_FIFO_FLUSH_SET(x) (x << 16)
#define I3C_FLUSH_CTRL_CMD_FIFO_FLUSH_GET(x) ((x >> 16) & 0x00000001)

/****************************************************
  ::TTO_PRESCL_CTRL0:: BitField descriptions
****************************************************/
/*!  Divider B */
#define I3C_TTO_PRESCL_CTRL0_DIV_B_POS 16
#define I3C_TTO_PRESCL_CTRL0_DIV_B_LEN 10
#define I3C_TTO_PRESCL_CTRL0_DIV_B_MASK 0x03ff0000
#define I3C_TTO_PRESCL_CTRL0_DIV_B_SET(x) (x << 16)
#define I3C_TTO_PRESCL_CTRL0_DIV_B_GET(x) ((x >> 16) & 0x000003ff)

/*!  Divider A */
#define I3C_TTO_PRESCL_CTRL0_DIV_A_POS 0
#define I3C_TTO_PRESCL_CTRL0_DIV_A_LEN 11
#define I3C_TTO_PRESCL_CTRL0_DIV_A_MASK 0x000007ff
#define I3C_TTO_PRESCL_CTRL0_DIV_A_SET(x) (x << 0)
#define I3C_TTO_PRESCL_CTRL0_DIV_A_GET(x) ((x >> 0) & 0x000007ff)

/****************************************************
  ::TTO_PRESCL_CTRL1:: BitField descriptions
****************************************************/
/*!  Divider B */
#define I3C_TTO_PRESCL_CTRL1_DIV_B_POS 16
#define I3C_TTO_PRESCL_CTRL1_DIV_B_LEN 10
#define I3C_TTO_PRESCL_CTRL1_DIV_B_MASK 0x03ff0000
#define I3C_TTO_PRESCL_CTRL1_DIV_B_SET(x) (x << 16)
#define I3C_TTO_PRESCL_CTRL1_DIV_B_GET(x) ((x >> 16) & 0x000003ff)

/*!  Divider A */
#define I3C_TTO_PRESCL_CTRL1_DIV_A_POS 0
#define I3C_TTO_PRESCL_CTRL1_DIV_A_LEN 11
#define I3C_TTO_PRESCL_CTRL1_DIV_A_MASK 0x000007ff
#define I3C_TTO_PRESCL_CTRL1_DIV_A_SET(x) (x << 0)
#define I3C_TTO_PRESCL_CTRL1_DIV_A_GET(x) ((x >> 0) & 0x000007ff)

/****************************************************
  ::DEVS_CTRL:: BitField descriptions
****************************************************/
/*!  clear Dev7 */
#define I3C_DEVS_CTRL_DEV7_CLR_POS 23
#define I3C_DEVS_CTRL_DEV7_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV7_CLR_MASK 0x00800000
#define I3C_DEVS_CTRL_DEV7_CLR_SET(x) (x << 23)
#define I3C_DEVS_CTRL_DEV7_CLR_GET(x) ((x >> 23) & 0x00000001)

/*!  clear Dev6 */
#define I3C_DEVS_CTRL_DEV6_CLR_POS 22
#define I3C_DEVS_CTRL_DEV6_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV6_CLR_MASK 0x00400000
#define I3C_DEVS_CTRL_DEV6_CLR_SET(x) (x << 22)
#define I3C_DEVS_CTRL_DEV6_CLR_GET(x) ((x >> 22) & 0x00000001)

/*!  clear Dev5 */
#define I3C_DEVS_CTRL_DEV5_CLR_POS 21
#define I3C_DEVS_CTRL_DEV5_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV5_CLR_MASK 0x00200000
#define I3C_DEVS_CTRL_DEV5_CLR_SET(x) (x << 21)
#define I3C_DEVS_CTRL_DEV5_CLR_GET(x) ((x >> 21) & 0x00000001)

/*!  clear Dev4 */
#define I3C_DEVS_CTRL_DEV4_CLR_POS 20
#define I3C_DEVS_CTRL_DEV4_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV4_CLR_MASK 0x00100000
#define I3C_DEVS_CTRL_DEV4_CLR_SET(x) (x << 20)
#define I3C_DEVS_CTRL_DEV4_CLR_GET(x) ((x >> 20) & 0x00000001)

/*!  clear Dev3 */
#define I3C_DEVS_CTRL_DEV3_CLR_POS 19
#define I3C_DEVS_CTRL_DEV3_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV3_CLR_MASK 0x00080000
#define I3C_DEVS_CTRL_DEV3_CLR_SET(x) (x << 19)
#define I3C_DEVS_CTRL_DEV3_CLR_GET(x) ((x >> 19) & 0x00000001)

/*!  clear Dev2 */
#define I3C_DEVS_CTRL_DEV2_CLR_POS 18
#define I3C_DEVS_CTRL_DEV2_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV2_CLR_MASK 0x00040000
#define I3C_DEVS_CTRL_DEV2_CLR_SET(x) (x << 18)
#define I3C_DEVS_CTRL_DEV2_CLR_GET(x) ((x >> 18) & 0x00000001)

/*!  clear Dev1 */
#define I3C_DEVS_CTRL_DEV1_CLR_POS 17
#define I3C_DEVS_CTRL_DEV1_CLR_LEN 1
#define I3C_DEVS_CTRL_DEV1_CLR_MASK 0x00020000
#define I3C_DEVS_CTRL_DEV1_CLR_SET(x) (x << 17)
#define I3C_DEVS_CTRL_DEV1_CLR_GET(x) ((x >> 17) & 0x00000001)

/*!  Active Dev7 */
#define I3C_DEVS_CTRL_DEV7_ACTIVE_POS 7
#define I3C_DEVS_CTRL_DEV7_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV7_ACTIVE_MASK 0x00000080
#define I3C_DEVS_CTRL_DEV7_ACTIVE_SET(x) (x << 7)
#define I3C_DEVS_CTRL_DEV7_ACTIVE_GET(x) ((x >> 7) & 0x00000001)

/*!  Active Dev6 */
#define I3C_DEVS_CTRL_DEV6_ACTIVE_POS 6
#define I3C_DEVS_CTRL_DEV6_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV6_ACTIVE_MASK 0x00000040
#define I3C_DEVS_CTRL_DEV6_ACTIVE_SET(x) (x << 6)
#define I3C_DEVS_CTRL_DEV6_ACTIVE_GET(x) ((x >> 6) & 0x00000001)

/*!  Active Dev5 */
#define I3C_DEVS_CTRL_DEV5_ACTIVE_POS 5
#define I3C_DEVS_CTRL_DEV5_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV5_ACTIVE_MASK 0x00000020
#define I3C_DEVS_CTRL_DEV5_ACTIVE_SET(x) (x << 5)
#define I3C_DEVS_CTRL_DEV5_ACTIVE_GET(x) ((x >> 5) & 0x00000001)

/*!  Active Dev4 */
#define I3C_DEVS_CTRL_DEV4_ACTIVE_POS 4
#define I3C_DEVS_CTRL_DEV4_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV4_ACTIVE_MASK 0x00000010
#define I3C_DEVS_CTRL_DEV4_ACTIVE_SET(x) (x << 4)
#define I3C_DEVS_CTRL_DEV4_ACTIVE_GET(x) ((x >> 4) & 0x00000001)

/*!  Active Dev3 */
#define I3C_DEVS_CTRL_DEV3_ACTIVE_POS 3
#define I3C_DEVS_CTRL_DEV3_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV3_ACTIVE_MASK 0x00000008
#define I3C_DEVS_CTRL_DEV3_ACTIVE_SET(x) (x << 3)
#define I3C_DEVS_CTRL_DEV3_ACTIVE_GET(x) ((x >> 3) & 0x00000001)

/*!  Active Dev2 */
#define I3C_DEVS_CTRL_DEV2_ACTIVE_POS 2
#define I3C_DEVS_CTRL_DEV2_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV2_ACTIVE_MASK 0x00000004
#define I3C_DEVS_CTRL_DEV2_ACTIVE_SET(x) (x << 2)
#define I3C_DEVS_CTRL_DEV2_ACTIVE_GET(x) ((x >> 2) & 0x00000001)

/*!  Active Dev1 */
#define I3C_DEVS_CTRL_DEV1_ACTIVE_POS 1
#define I3C_DEVS_CTRL_DEV1_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV1_ACTIVE_MASK 0x00000002
#define I3C_DEVS_CTRL_DEV1_ACTIVE_SET(x) (x << 1)
#define I3C_DEVS_CTRL_DEV1_ACTIVE_GET(x) ((x >> 1) & 0x00000001)

/*!  Active Dev0 */
#define I3C_DEVS_CTRL_DEV0_ACTIVE_POS 0
#define I3C_DEVS_CTRL_DEV0_ACTIVE_LEN 1
#define I3C_DEVS_CTRL_DEV0_ACTIVE_MASK 0x00000001
#define I3C_DEVS_CTRL_DEV0_ACTIVE_SET(x) (x << 0)
#define I3C_DEVS_CTRL_DEV0_ACTIVE_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::DEV_IDX_RR0:: BitField descriptions
****************************************************/
/*!  MSB bits of Legacy I2C Device */
#define I3C_DEV_IDX_RR0_LVR_SA_MSB_POS 13
#define I3C_DEV_IDX_RR0_LVR_SA_MSB_LEN 3
#define I3C_DEV_IDX_RR0_LVR_SA_MSB_MASK 0x0000e000
#define I3C_DEV_IDX_RR0_LVR_SA_MSB_SET(x) (x << 13)
#define I3C_DEV_IDX_RR0_LVR_SA_MSB_GET(x) ((x >> 13) & 0x00000007)

/*!  Address mode used */
#define I3C_DEV_IDX_RR0_LVR_EXT_ADDR_POS 11
#define I3C_DEV_IDX_RR0_LVR_EXT_ADDR_LEN 1
#define I3C_DEV_IDX_RR0_LVR_EXT_ADDR_MASK 0x00000800
#define I3C_DEV_IDX_RR0_LVR_EXT_ADDR_SET(x) (x << 11)
#define I3C_DEV_IDX_RR0_LVR_EXT_ADDR_GET(x) ((x >> 11) & 0x00000001)

/*!  I3C mode Operation */
#define I3C_DEV_IDX_RR0_IS_I3C_POS 9
#define I3C_DEV_IDX_RR0_IS_I3C_LEN 1
#define I3C_DEV_IDX_RR0_IS_I3C_MASK 0x00000200
#define I3C_DEV_IDX_RR0_IS_I3C_SET(x) (x << 9)
#define I3C_DEV_IDX_RR0_IS_I3C_GET(x) ((x >> 9) & 0x00000001)

/*!  slave Address and parity */
#define I3C_DEV_IDX_RR0_DEV_ADDR_POS 0
#define I3C_DEV_IDX_RR0_DEV_ADDR_LEN 8
#define I3C_DEV_IDX_RR0_DEV_ADDR_MASK 0x000000ff
#define I3C_DEV_IDX_RR0_DEV_ADDR_SET(x) (x << 0)
#define I3C_DEV_IDX_RR0_DEV_ADDR_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::DEV_IDX_RR1:: BitField descriptions
****************************************************/
/*!  48 to 16 Dev ID bits */
#define I3C_DEV_IDX_RR1_PID_MSB_POS 0
#define I3C_DEV_IDX_RR1_PID_MSB_LEN 32
#define I3C_DEV_IDX_RR1_PID_MSB_MASK 0xffffffff
#define I3C_DEV_IDX_RR1_PID_MSB_SET(x) (x)
#define I3C_DEV_IDX_RR1_PID_MSB_GET(x) (x)

/****************************************************
  ::DEV_IDX_RR2:: BitField descriptions
****************************************************/
/*!  16 to 0 Dev ID bits */
#define I3C_DEV_IDX_RR2_PID_LSB_POS 16
#define I3C_DEV_IDX_RR2_PID_LSB_LEN 16
#define I3C_DEV_IDX_RR2_PID_LSB_MASK 0xffff0000
#define I3C_DEV_IDX_RR2_PID_LSB_SET(x) (x << 16)
#define I3C_DEV_IDX_RR2_PID_LSB_GET(x) ((x >> 16) & 0x0000ffff)

/*!  BCR register */
#define I3C_DEV_IDX_RR2_BCR_POS 8
#define I3C_DEV_IDX_RR2_BCR_LEN 6
#define I3C_DEV_IDX_RR2_BCR_MASK 0x00003f00
#define I3C_DEV_IDX_RR2_BCR_SET(x) (x << 8)
#define I3C_DEV_IDX_RR2_BCR_GET(x) ((x >> 8) & 0x0000003f)

/*!  DCR (if I3C device) or LVR (if I2C device) register */
#define I3C_DEV_IDX_RR2_DCR_LVR_POS 0
#define I3C_DEV_IDX_RR2_DCR_LVR_LEN 8
#define I3C_DEV_IDX_RR2_DCR_LVR_MASK 0x000000ff
#define I3C_DEV_IDX_RR2_DCR_LVR_SET(x) (x << 0)
#define I3C_DEV_IDX_RR2_DCR_LVR_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::SIR_MAPX:: BitField descriptions
****************************************************/
/*!  Slave-initiated request Device ID1 BCR role */
#define I3C_SIR_MAPX1_DEVID1_ROLE_POS 30
#define I3C_SIR_MAPX_DEVID1_ROLE_LEN 2
#define I3C_SIR_MAPX_DEVID1_ROLE_MASK 0xc0000000
#define I3C_SIR_MAPX_DEVID1_ROLE_SET(x) (x << 30)
#define I3C_SIR_MAPX_DEVID1_ROLE_GET(x) ((x >> 30) & 0x00000003)

/*!  Slave-initiated request Device ID1 Max Data Speed Limitation */
#define I3C_SIR_MAPX_DEVID1_SLOW_POS 29
#define I3C_SIR_MAPX_DEVID1_SLOW_LEN 1
#define I3C_SIR_MAPX_DEVID1_SLOW_MASK 0x20000000
#define I3C_SIR_MAPX_DEVID1_SLOW_SET(x) (x << 29)
#define I3C_SIR_MAPX_DEVID1_SLOW_GET(x) ((x >> 29) & 0x00000001)

/*!  Slave-initiated request Device ID1 payload length */
#define I3C_SIR_MAPX_DEVID1_PL_POS 24
#define I3C_SIR_MAPX_DEVID1_PL_LEN 5
#define I3C_SIR_MAPX_DEVID1_PL_MASK 0x1f000000
#define I3C_SIR_MAPX_DEVID1_PL_SET(x) (x << 24)
#define I3C_SIR_MAPX_DEVID1_PL_GET(x) ((x >> 24) & 0x0000001f)

/*!  Slave-initiated request Device ID1 DA */
#define I3C_SIR_MAPX_DEVID1_DA_POS 17
#define I3C_SIR_MAPX_DEVID1_DA_LEN 7
#define I3C_SIR_MAPX_DEVID1_DA_MASK 0x00fe0000
#define I3C_SIR_MAPX_DEVID1_DA_SET(x) (x << 17)
#define I3C_SIR_MAPX_DEVID1_DA_GET(x) ((x >> 17) & 0x0000007f)

/*!  Slave-initiated request Device ID1 Ack/Nack response */
#define I3C_SIR_MAPX_DEVID1_RESP_POS 16
#define I3C_SIR_MAPX_DEVID1_RESP_LEN 1
#define I3C_SIR_MAPX_DEVID1_RESP_MASK 0x00010000
#define I3C_SIR_MAPX_DEVID1_RESP_SET(x) (x << 16)
#define I3C_SIR_MAPX_DEVID1_RESP_GET(x) ((x >> 16) & 0x00000001)

/*!  Slave-initiated request Device ID0 BCR role */
#define I3C_SIR_MAPX_DEVID0_ROLE_POS 14
#define I3C_SIR_MAPX_DEVID0_ROLE_LEN 2
#define I3C_SIR_MAPX_DEVID0_ROLE_MASK 0x0000c000
#define I3C_SIR_MAPX_DEVID0_ROLE_SET(x) (x << 14)
#define I3C_SIR_MAPX_DEVID0_ROLE_GET(x) ((x >> 14) & 0x00000003)

/*!  Slave-initiated request Device ID0 Max Data Speed Limitation */
#define I3C_SIR_MAPX_DEVID0_SLOW_POS 13
#define I3C_SIR_MAPX_DEVID0_SLOW_LEN 1
#define I3C_SIR_MAPX_DEVID0_SLOW_MASK 0x00002000
#define I3C_SIR_MAPX_DEVID0_SLOW_SET(x) (x << 13)
#define I3C_SIR_MAPX_DEVID0_SLOW_GET(x) ((x >> 13) & 0x00000001)

/*!  Slave-initiated request Device ID0 payload length */
#define I3C_SIR_MAPX_DEVID0_PL_POS 8
#define I3C_SIR_MAPX_DEVID0_PL_LEN 5
#define I3C_SIR_MAPX_DEVID0_PL_MASK 0x00001f00
#define I3C_SIR_MAPX_DEVID0_PL_SET(x) (x << 8)
#define I3C_SIR_MAPX_DEVID0_PL_GET(x) ((x >> 8) & 0x0000001f)

/*!  Slave-initiated request Device ID0 DA */
#define I3C_SIR_MAPX_DEVID0_DA_POS 1
#define I3C_SIR_MAPX_DEVID0_DA_LEN 7
#define I3C_SIR_MAPX_DEVID0_DA_MASK 0x000000fe
#define I3C_SIR_MAPX_DEVID0_DA_SET(x) (x << 1)
#define I3C_SIR_MAPX_DEVID0_DA_GET(x) ((x >> 1) & 0x0000007f)

/*!  Slave-initiated request Device ID0 Ack/Nack response */
#define I3C_SIR_MAPX_DEVID0_RESP_POS 0
#define I3C_SIR_MAPX_DEVID0_RESP_LEN 1
#define I3C_SIR_MAPX_DEVID0_RESP_MASK 0x00000001
#define I3C_SIR_MAPX_DEVID0_RESP_SET(x) (x << 0)
#define I3C_SIR_MAPX_DEVID0_RESP_GET(x) ((x >> 0) & 0x00000001)

/****************************************************
  ::GPIR_WORDx:: BitField descriptions
****************************************************/
/*!  User Defined GPI Register 3 */
#define I3C_GPIR_WORDx_GPI3_POS 24
#define I3C_GPIR_WORDx_GPI3_LEN 8
#define I3C_GPIR_WORDx_GPI3_MASK 0xff000000
#define I3C_GPIR_WORDx_GPI3_SET(x) (x << 24)
#define I3C_GPIR_WORDx_GPI3_GET(x) ((x >> 24) & 0x000000ff)

/*!  User Defined GPI Register 2 */
#define I3C_GPIR_WORDx_GPI2_POS 16
#define I3C_GPIR_WORDx_GPI2_LEN 8
#define I3C_GPIR_WORDx_GPI2_MASK 0x00ff0000
#define I3C_GPIR_WORDx_GPI2_SET(x) (x << 16)
#define I3C_GPIR_WORDx_GPI2_GET(x) ((x >> 16) & 0x000000ff)

/*!  User Defined GPI Register 1 */
#define I3C_GPIR_WORDx_GPI1_POS 8
#define I3C_GPIR_WORDx_GPI1_LEN 8
#define I3C_GPIR_WORDx_GPI1_MASK 0x0000ff00
#define I3C_GPIR_WORDx_GPI1_SET(x) (x << 8)
#define I3C_GPIR_WORDx_GPI1_GET(x) ((x >> 8) & 0x000000ff)

/*!  User Defined GPI Register 0 */
#define I3C_GPIR_WORDx_GPI0_POS 0
#define I3C_GPIR_WORDx_GPI0_LEN 8
#define I3C_GPIR_WORDx_GPI0_MASK 0x000000ff
#define I3C_GPIR_WORDx_GPI0_SET(x) (x << 0)
#define I3C_GPIR_WORDx_GPI0_GET(x) ((x >> 0) & 0x000000ff)

/****************************************************
  ::GPOR_WORDx:: BitField descriptions
****************************************************/
/*!  User Defined GPO Register 3 */
#define I3C_GPOR_WORDx_GPO3_POS 24
#define I3C_GPOR_WORDx_GPO3_LEN 8
#define I3C_GPOR_WORDx_GPO3_MASK 0xff000000
#define I3C_GPOR_WORDx_GPO3_SET(x) (x << 24)
#define I3C_GPOR_WORDx_GPO3_GET(x) ((x >> 24) & 0x000000ff)

/*!  User Defined GPO Register 2 */
#define I3C_GPOR_WORDx_GPO2_POS 16
#define I3C_GPOR_WORDx_GPO2_LEN 8
#define I3C_GPOR_WORDx_GPO2_MASK 0x00ff0000
#define I3C_GPOR_WORDx_GPO2_SET(x) (x << 16)
#define I3C_GPOR_WORDx_GPO2_GET(x) ((x >> 16) & 0x000000ff)

/*!  User Defined GPO Register 1 */
#define I3C_GPOR_WORDx_GPO1_POS 8
#define I3C_GPOR_WORDx_GPO1_LEN 8
#define I3C_GPOR_WORDx_GPO1_MASK 0x0000ff00
#define I3C_GPOR_WORDx_GPO1_SET(x) (x << 8)
#define I3C_GPOR_WORDx_GPO1_GET(x) ((x >> 8) & 0x000000ff)

/*!  User Defined GPO Register 0 */
#define I3C_GPOR_WORDx_GPO0_POS 0
#define I3C_GPOR_WORDx_GPO0_LEN 8
#define I3C_GPOR_WORDx_GPO0_MASK 0x000000ff
#define I3C_GPOR_WORDx_GPO0_SET(x) (x << 0)
#define I3C_GPOR_WORDx_GPO0_GET(x) ((x >> 0) & 0x000000ff)

#endif /*__I3C_REG_H_*/
