#ifndef __EXIU_REG_H_
#define __EXIU_REG_H_

#include <stdint.h>
#include "stdio.h"

typedef volatile struct {
    __IO uint32_t EIMASK;     /*Interrupt Masking Register*/
    __IO uint32_t EISRCSEL;   /*Interrupt Source Select Register*/
    __I uint32_t EIREQSTA;    /*Internal Interrupt Request Status Register*/
    __I uint32_t EIRAWREQSTA; /*Raw Interrupt Request Status Register*/
    __O uint32_t EIREQCLR;    /*Interrupt Clear Register*/
    __IO uint32_t EILVL;      /*External Interrupt Level Setting Register*/
    __IO uint32_t EIEDG;      /*Interrupt Detection Method Setting Register*/
    __IO uint32_t EISIR;      /*Software Interrupt Register*/
} exiu_t;

#define EXIU ((exiu_t*)EXIU_BASE)

/***************  Bit definition of EIMASK register  ***************/
#define EXIU_EIMASK ((u32)0xFFFFFFFF)  /* Mask Register */
#define EXIU_EIMASK0 ((u32)0x1 << 0)   /* EXTINT 0 */
#define EXIU_EIMASK1 ((u32)0x1 << 1)   /* EXTINT 1 */
#define EXIU_EIMASK2 ((u32)0x1 << 2)   /* EXTINT 2 */
#define EXIU_EIMASK3 ((u32)0x1 << 3)   /* EXTINT 3 */
#define EXIU_EIMASK4 ((u32)0x1 << 4)   /* EXTINT 4 */
#define EXIU_EIMASK5 ((u32)0x1 << 5)   /* EXTINT 5 */
#define EXIU_EIMASK6 ((u32)0x1 << 6)   /* EXTINT 6 */
#define EXIU_EIMASK7 ((u32)0x1 << 7)   /* EXTINT 7 */
#define EXIU_EIMASK8 ((u32)0x1 << 8)   /* EXTINT 8 */
#define EXIU_EIMASK9 ((u32)0x1 << 9)   /* EXTINT 9 */
#define EXIU_EIMASK10 ((u32)0x1 << 10) /* EXTINT 10 */
#define EXIU_EIMASK11 ((u32)0x1 << 11) /* EXTINT 11 */
#define EXIU_EIMASK12 ((u32)0x1 << 12) /* EXTINT 12 */
#define EXIU_EIMASK13 ((u32)0x1 << 13) /* EXTINT 13 */
#define EXIU_EIMASK14 ((u32)0x1 << 14) /* EXTINT 14 */
#define EXIU_EIMASK15 ((u32)0x1 << 15) /* EXTINT 15 */

/***************  Bit definition of EISRCSEL register  ***************/
#define EXIU_EISRCSEL ((u32)0xFFFFFFFF)  /*Interrupt Source Select*/
#define EXIU_EISRCSEL0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EISRCSEL1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EISRCSEL2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EISRCSEL3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EISRCSEL4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EISRCSEL5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EISRCSEL6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EISRCSEL7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EISRCSEL8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EISRCSEL9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EISRCSEL10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EISRCSEL11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EISRCSEL12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EISRCSEL13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EISRCSEL14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EISRCSEL15 ((u32)0x1 << 15) /* EXTINT15 */

/***************  Bit definition of EIREQSTA register  ***************/
#define EXIU_EIREQSTA ((u32)0xFFFFFFFF)  /* Interrupt Request Status */
#define EXIU_EIREQSTA0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EIREQSTA1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EIREQSTA2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EIREQSTA3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EIREQSTA4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EIREQSTA5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EIREQSTA6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EIREQSTA7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EIREQSTA8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EIREQSTA9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EIREQSTA10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EIREQSTA11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EIREQSTA12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EIREQSTA13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EIREQSTA14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EIREQSTA15 ((u32)0x1 << 15) /* EXTINT15 */

/***************  Bit definition of EIRAWREQSTA register  ***************/
#define EXIU_EIRAWREQSTA ((u32)0xFFFFFFFF)  /* Raw Interrupt Request Status */
#define EXIU_EIRAWREQSTA0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EIRAWREQSTA1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EIRAWREQSTA2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EIRAWREQSTA3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EIRAWREQSTA4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EIRAWREQSTA5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EIRAWREQSTA6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EIRAWREQSTA7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EIRAWREQSTA8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EIRAWREQSTA9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EIRAWREQSTA10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EIRAWREQSTA11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EIRAWREQSTA12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EIRAWREQSTA13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EIRAWREQSTA14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EIRAWREQSTA15 ((u32)0x1 << 15) /* EXTINT15 */

/***************  Bit definition of EIREQCLR register  ***************/
#define EXIU_EIREQCLR ((u32)0xFFFFFFFF)  /* Interrupt Requst Clear */
#define EXIU_EIREQCLR0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EIREQCLR1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EIREQCLR2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EIREQCLR3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EIREQCLR4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EIREQCLR5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EIREQCLR6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EIREQCLR7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EIREQCLR8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EIREQCLR9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EIREQCLR10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EIREQCLR11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EIREQCLR12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EIREQCLR13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EIREQCLR14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EIREQCLR15 ((u32)0x1 << 15) /* EXTINT15 */

/***************  Bit definition of EILVL register  ***************/
#define EXIU_EILVL ((u32)0xFFFFFFFF)  /* Trigger Level */
#define EXIU_EILVL0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EILVL1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EILVL2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EILVL3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EILVL4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EILVL5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EILVL6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EILVL7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EILVL8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EILVL9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EILVL10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EILVL11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EILVL12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EILVL13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EILVL14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EILVL15 ((u32)0x1 << 15) /* EXTINT15 */

/***************  Bit definition of EIEDG register  ***************/
#define EXIU_EIEDG ((u32)0xFFFFFFFF)  /* Edge Trigger */
#define EXIU_EIEDG0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EIEDG1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EIEDG2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EIEDG3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EIEDG4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EIEDG5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EIEDG6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EIEDG7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EIEDG8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EIEDG9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EIEDG10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EIEDG11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EIEDG12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EIEDG13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EIEDG14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EIEDG15 ((u32)0x1 << 15) /* EXTINT15 */

/***************  Bit definition of EISIR register  ***************/
#define EXIU_EISIR ((u32)0xFFFFFFFF)  /* Software Interrupt Request */
#define EXIU_EISIR0 ((u32)0x1 << 0)   /* EXTINT0 */
#define EXIU_EISIR1 ((u32)0x1 << 1)   /* EXTINT1 */
#define EXIU_EISIR2 ((u32)0x1 << 2)   /* EXTINT2 */
#define EXIU_EISIR3 ((u32)0x1 << 3)   /* EXTINT3 */
#define EXIU_EISIR4 ((u32)0x1 << 4)   /* EXTINT4 */
#define EXIU_EISIR5 ((u32)0x1 << 5)   /* EXTINT5 */
#define EXIU_EISIR6 ((u32)0x1 << 6)   /* EXTINT6 */
#define EXIU_EISIR7 ((u32)0x1 << 7)   /* EXTINT7 */
#define EXIU_EISIR8 ((u32)0x1 << 8)   /* EXTINT8 */
#define EXIU_EISIR9 ((u32)0x1 << 9)   /* EXTINT9 */
#define EXIU_EISIR10 ((u32)0x1 << 10) /* EXTINT10 */
#define EXIU_EISIR11 ((u32)0x1 << 11) /* EXTINT11 */
#define EXIU_EISIR12 ((u32)0x1 << 12) /* EXTINT12 */
#define EXIU_EISIR13 ((u32)0x1 << 13) /* EXTINT13 */
#define EXIU_EISIR14 ((u32)0x1 << 14) /* EXTINT14 */
#define EXIU_EISIR15 ((u32)0x1 << 15) /* EXTINT15 */

#endif  // __EXIU_REG_H_
