#include "common.h"

/** A structure to abstract
 **  SPI BUS registers
 **/
typedef volatile struct {
    __IO uint32_t MCTRL;
    __IO uint32_t PCC[4];
    __IO uint32_t TXF;
    __IO uint32_t TXE;
    __IO uint32_t TXC;
    __IO uint32_t RXF;
    __IO uint32_t RXE;
    __IO uint32_t RXC;
    __IO uint32_t FAULTF;
    __IO uint32_t FAULTC;
    __IO uint32_t DM;
    __IO uint32_t DMCTRL;
    __IO uint32_t COUNT;
    __I uint32_t DMSTATUS;
    uint32_t Reserved1[2];
    __IO uint32_t FIFOCFG;
    __IO uint32_t TXFIFO[16];
    __IO uint32_t RXFIFO[16];
    __IO uint32_t CSCFG;
    __IO uint32_t CSITIME;
    __IO uint32_t CSAEXT;
    __IO uint32_t RDCSDC[4];
    __IO uint32_t WRCSDC[4];
    __IO uint32_t MID;
} SPI_t;

SPI_t* SPI = ((SPI_t*)SPI_BASE); /*!< SPI Controller Configuration structure*/

/****************************************************
  ::MCTRL:: BitField descriptions
****************************************************/
/*! Module Enable */
#define BC_HSSPIn_MCTRL_MEN_POS 0
#define BC_HSSPIn_MCTRL_MEN_LEN 1
#define BC_HSSPIn_MCTRL_MEN_MASK 0x00000001
#define BC_HSSPIn_MCTRL_MEN_SET(x) (x << 0)
#define BC_HSSPIn_MCTRL_MEN_GET(x) ((x >> 0) & 0x00000001)

/*! Command Sequencer Enable */
#define BC_HSSPIn_MCTRL_CSEN_POS 1
#define BC_HSSPIn_MCTRL_CSEN_LEN 1
#define BC_HSSPIn_MCTRL_CSEN_MASK 0x00000002
#define BC_HSSPIn_MCTRL_CSEN_SET(x) (x << 1)
#define BC_HSSPIn_MCTRL_CSEN_GET(x) ((x >> 1) & 0x00000001)

/*! Clock Division Source Select */
#define BC_HSSPIn_MCTRL_CDSS_POS 3
#define BC_HSSPIn_MCTRL_CDSS_LEN 1
#define BC_HSSPIn_MCTRL_CDSS_MASK 0x00000008
#define BC_HSSPIn_MCTRL_CDSS_SET(x) (x << 3)
#define BC_HSSPIn_MCTRL_CDSS_GET(x) ((x >> 3) & 0x00000001)

/*! Module Enable Status */
#define BC_HSSPIn_MCTRL_MES_POS 4
#define BC_HSSPIn_MCTRL_MES_LEN 1
#define BC_HSSPIn_MCTRL_MES_MASK 0x00000010
#define BC_HSSPIn_MCTRL_MES_SET(x) (x << 4)
#define BC_HSSPIn_MCTRL_MES_GET(x) ((x >> 4) & 0x00000001)

/****************************************************
  ::PCCn:: BitField descriptions
****************************************************/
/*! Active Clock Edges are Same */
#define BC_HSSPIn_PCCn_ACES_POS 2
#define BC_HSSPIn_PCCn_ACES_LEN 1
#define BC_HSSPIn_PCCn_ACES_MASK 0x00000004
#define BC_HSSPIn_PCCn_ACES_SET(x) (x << 2)
#define BC_HSSPIn_PCCn_ACES_GET(x) ((x >> 2) & 0x00000001)

/*! Use retimed clock for capturing the data */
#define BC_HSSPIn_PCCn_RTM_POS 3
#define BC_HSSPIn_PCCn_RTM_LEN 1
#define BC_HSSPIn_PCCn_RTM_MASK 0x00000008
#define BC_HSSPIn_PCCn_RTM_SET(x) (x << 3)
#define BC_HSSPIn_PCCn_RTM_GET(x) ((x >> 3) & 0x00000001)

/*! Slave Select Polarity */
#define BC_HSSPIn_PCCn_SSPOL_POS 4
#define BC_HSSPIn_PCCn_SSPOL_LEN 1
#define BC_HSSPIn_PCCn_SSPOL_MASK 0x00000010
#define BC_HSSPIn_PCCn_SSPOL_SET(x) (x << 4)
#define BC_HSSPIn_PCCn_SSPOL_GET(x) ((x >> 4) & 0x00000001)

/*! Slave-Select to Clock Delay */
#define BC_HSSPIn_PCCn_SS2CD_POS 5
#define BC_HSSPIn_PCCn_SS2CD_LEN 2
#define BC_HSSPIn_PCCn_SS2CD_MASK 0x00000060
#define BC_HSSPIn_PCCn_SS2CD_SET(x) (x << 5)
#define BC_HSSPIn_PCCn_SS2CD_GET(x) ((x >> 5) & 0x00000003)

/*! Shift Direction */
#define BC_HSSPIn_PCCn_SDIR_POS 7
#define BC_HSSPIn_PCCn_SDIR_LEN 1
#define BC_HSSPIn_PCCn_SDIR_MASK 0x00000080
#define BC_HSSPIn_PCCn_SDIR_SET(x) (x << 7)
#define BC_HSSPIn_PCCn_SDIR_GET(x) ((x >> 7) & 0x00000001)

/*! SPI Endian */
#define BC_HSSPIn_PCCn_SENDIAN_POS 8
#define BC_HSSPIn_PCCn_SENDIAN_LEN 1
#define BC_HSSPIn_PCCn_SENDIAN_MASK 0x00000100
#define BC_HSSPIn_PCCn_SENDIAN_SET(x) (x << 8)
#define BC_HSSPIn_PCCn_SENDIAN_GET(x) ((x >> 8) & 0x00000001)

/*! Clock Division Ratio Select */
#define BC_HSSPIn_PCCn_CDRS_POS 9
#define BC_HSSPIn_PCCn_CDRS_LEN 7
#define BC_HSSPIn_PCCn_CDRS_MASK 0x0000fe00
#define BC_HSSPIn_PCCn_CDRS_SET(x) (x << 9)
#define BC_HSSPIn_PCCn_CDRS_GET(x) ((x >> 9) & 0x0000007f)

/*! Write/different command Deselect Time */
#define BC_HSSPIn_PCCn_WRDSEL_POS 17
#define BC_HSSPIn_PCCn_WRDSEL_LEN 4
#define BC_HSSPIn_PCCn_WRDSEL_MASK 0x001e0000
#define BC_HSSPIn_PCCn_WRDSEL_SET(x) (x << 17)
#define BC_HSSPIn_PCCn_WRDSEL_GET(x) ((x >> 17) & 0x0000000f)

/*! Read Deselect Time */
#define BC_HSSPIn_PCCn_RDDSEL_POS 21
#define BC_HSSPIn_PCCn_RDDSEL_LEN 4
#define BC_HSSPIn_PCCn_RDDSEL_MASK 0x01e00000
#define BC_HSSPIn_PCCn_RDDSEL_SET(x) (x << 21)
#define BC_HSSPIn_PCCn_RDDSEL_GET(x) ((x >> 21) & 0x0000000f)

/****************************************************
  ::TXF:: BitField descriptions
****************************************************/
/*! TX-FIFO Full Interrupt */
#define BC_HSSPIn_TXF_TFFS_POS 0
#define BC_HSSPIn_TXF_TFFS_LEN 1
#define BC_HSSPIn_TXF_TFFS_MASK 0x00000001
#define BC_HSSPIn_TXF_TFFS_SET(x) (x << 0)
#define BC_HSSPIn_TXF_TFFS_GET(x) ((x >> 0) & 0x00000001)

/*! TX-FIFO and Shift Register are Empty Interrupt */
#define BC_HSSPIn_TXF_TFES_POS 1
#define BC_HSSPIn_TXF_TFES_LEN 1
#define BC_HSSPIn_TXF_TFES_MASK 0x00000002
#define BC_HSSPIn_TXF_TFES_SET(x) (x << 1)
#define BC_HSSPIn_TXF_TFES_GET(x) ((x >> 1) & 0x00000001)

/*! TX-FIFO Overrun Interrupt */
#define BC_HSSPIn_TXF_TFOS_POS 2
#define BC_HSSPIn_TXF_TFOS_LEN 1
#define BC_HSSPIn_TXF_TFOS_MASK 0x00000004
#define BC_HSSPIn_TXF_TFOS_SET(x) (x << 2)
#define BC_HSSPIn_TXF_TFOS_GET(x) ((x >> 2) & 0x00000001)

/*! TX-FIFO Underrun Interrupt */
#define BC_HSSPIn_TXF_TFUS_POS 3
#define BC_HSSPIn_TXF_TFUS_LEN 1
#define BC_HSSPIn_TXF_TFUS_MASK 0x00000008
#define BC_HSSPIn_TXF_TFUS_SET(x) (x << 3)
#define BC_HSSPIn_TXF_TFUS_GET(x) ((x >> 3) & 0x00000001)

/*! TX-FIFO Fill Level is Less than or Equal to Threshold Interrupt */
#define BC_HSSPIn_TXF_TFLETS_POS 4
#define BC_HSSPIn_TXF_TFLETS_LEN 1
#define BC_HSSPIn_TXF_TFLETS_MASK 0x00000010
#define BC_HSSPIn_TXF_TFLETS_SET(x) (x << 4)
#define BC_HSSPIn_TXF_TFLETS_GET(x) ((x >> 4) & 0x00000001)

/*! TX-FIFO Fill Level is More than Threshold Interrupt */
#define BC_HSSPIn_TXF_TFMTS_POS 5
#define BC_HSSPIn_TXF_TFMTS_LEN 1
#define BC_HSSPIn_TXF_TFMTS_MASK 0x00000020
#define BC_HSSPIn_TXF_TFMTS_SET(x) (x << 5)
#define BC_HSSPIn_TXF_TFMTS_GET(x) ((x >> 5) & 0x00000001)

/*! Slave Select Released Interrupt */
#define BC_HSSPIn_TXF_TSSRS_POS 6
#define BC_HSSPIn_TXF_TSSRS_LEN 1
#define BC_HSSPIn_TXF_TSSRS_MASK 0x00000040
#define BC_HSSPIn_TXF_TSSRS_SET(x) (x << 6)
#define BC_HSSPIn_TXF_TSSRS_GET(x) ((x >> 6) & 0x00000001)

/****************************************************
  ::TXE:: BitField descriptions
****************************************************/
/*! Enable TX-FIFO Full Interrupt */
#define BC_HSSPIn_TXE_TFFE_POS 0
#define BC_HSSPIn_TXE_TFFE_LEN 1
#define BC_HSSPIn_TXE_TFFE_MASK 0x00000001
#define BC_HSSPIn_TXE_TFFE_SET(x) (x << 0)
#define BC_HSSPIn_TXE_TFFE_GET(x) ((x >> 0) & 0x00000001)

/*! Enable TX-FIFO and Shift Register are Empty Interrupt */
#define BC_HSSPIn_TXE_TFEE_POS 1
#define BC_HSSPIn_TXE_TFEE_LEN 1
#define BC_HSSPIn_TXE_TFEE_MASK 0x00000002
#define BC_HSSPIn_TXE_TFEE_SET(x) (x << 1)
#define BC_HSSPIn_TXE_TFEE_GET(x) ((x >> 1) & 0x00000001)

/*! Enable TX-FIFO Overrun Interrupt */
#define BC_HSSPIn_TXE_TFOE_POS 2
#define BC_HSSPIn_TXE_TFOE_LEN 1
#define BC_HSSPIn_TXE_TFOE_MASK 0x00000004
#define BC_HSSPIn_TXE_TFOE_SET(x) (x << 2)
#define BC_HSSPIn_TXE_TFOE_GET(x) ((x >> 2) & 0x00000001)

/*! Enable TX-FIFO Underrun Interrupt */
#define BC_HSSPIn_TXE_TFUE_POS 3
#define BC_HSSPIn_TXE_TFUE_LEN 1
#define BC_HSSPIn_TXE_TFUE_MASK 0x00000008
#define BC_HSSPIn_TXE_TFUE_SET(x) (x << 3)
#define BC_HSSPIn_TXE_TFUE_GET(x) ((x >> 3) & 0x00000001)

/*! Enable TX-FIFO Fill Level is Less than or Equal to Threshold Interrupt */
#define BC_HSSPIn_TXE_TFLETE_POS 4
#define BC_HSSPIn_TXE_TFLETE_LEN 1
#define BC_HSSPIn_TXE_TFLETE_MASK 0x00000010
#define BC_HSSPIn_TXE_TFLETE_SET(x) (x << 4)
#define BC_HSSPIn_TXE_TFLETE_GET(x) ((x >> 4) & 0x00000001)

/*! Enable TX-FIFO Fill Level is More than Threshold Interrupt */
#define BC_HSSPIn_TXE_TFMTE_POS 5
#define BC_HSSPIn_TXE_TFMTE_LEN 1
#define BC_HSSPIn_TXE_TFMTE_MASK 0x00000020
#define BC_HSSPIn_TXE_TFMTE_SET(x) (x << 5)
#define BC_HSSPIn_TXE_TFMTE_GET(x) ((x >> 5) & 0x00000001)

/*! Enable Slave Select Released Interrupt */
#define BC_HSSPIn_TXE_TSSRE_POS 6
#define BC_HSSPIn_TXE_TSSRE_LEN 1
#define BC_HSSPIn_TXE_TSSRE_MASK 0x00000040
#define BC_HSSPIn_TXE_TSSRE_SET(x) (x << 6)
#define BC_HSSPIn_TXE_TSSRE_GET(x) ((x >> 6) & 0x00000001)

/****************************************************
  ::TXC:: BitField descriptions
****************************************************/
/*! Clear ALL TX Interrupts */
#define BC_HSSPIn_TXC_ALL_POS 0
#define BC_HSSPIn_TXC_ALL_LEN 7
#define BC_HSSPIn_TXC_ALL_MASK 0x0000007f
#define BC_HSSPIn_TXC_ALL_SET(x) (x << 0)
#define BC_HSSPIn_TXC_ALL_GET(x) ((x >> 0) & 0x0000007f)

/*! Clear TX-FIFO Full Interrupt */
#define BC_HSSPIn_TXC_TFFC_POS 0
#define BC_HSSPIn_TXC_TFFC_LEN 1
#define BC_HSSPIn_TXC_TFFC_MASK 0x00000001
#define BC_HSSPIn_TXC_TFFC_SET(x) (x << 0)
#define BC_HSSPIn_TXC_TFFC_GET(x) ((x >> 0) & 0x00000001)

/*! Clear TX-FIFO and Shift Register are Empty Interrupt */
#define BC_HSSPIn_TXC_TFEC_POS 1
#define BC_HSSPIn_TXC_TFEC_LEN 1
#define BC_HSSPIn_TXC_TFEC_MASK 0x00000002
#define BC_HSSPIn_TXC_TFEC_SET(x) (x << 1)
#define BC_HSSPIn_TXC_TFEC_GET(x) ((x >> 1) & 0x00000001)

/*! Clear TX-FIFO Overrun Interrupt */
#define BC_HSSPIn_TXC_TFOC_POS 2
#define BC_HSSPIn_TXC_TFOC_LEN 1
#define BC_HSSPIn_TXC_TFOC_MASK 0x00000004
#define BC_HSSPIn_TXC_TFOC_SET(x) (x << 2)
#define BC_HSSPIn_TXC_TFOC_GET(x) ((x >> 2) & 0x00000001)

/*! Clear TX-FIFO Underrun Interrupt */
#define BC_HSSPIn_TXC_TFUC_POS 3
#define BC_HSSPIn_TXC_TFUC_LEN 1
#define BC_HSSPIn_TXC_TFUC_MASK 0x00000008
#define BC_HSSPIn_TXC_TFUC_SET(x) (x << 3)
#define BC_HSSPIn_TXC_TFUC_GET(x) ((x >> 3) & 0x00000001)

/*! Clear TX-FIFO Fill Level is Less than or Equal to Threshold Interrupt */
#define BC_HSSPIn_TXC_TFLETC_POS 4
#define BC_HSSPIn_TXC_TFLETC_LEN 1
#define BC_HSSPIn_TXC_TFLETC_MASK 0x00000010
#define BC_HSSPIn_TXC_TFLETC_SET(x) (x << 4)
#define BC_HSSPIn_TXC_TFLETC_GET(x) ((x >> 4) & 0x00000001)

/*! Clear TX-FIFO Fill Level is More than Threshold Interrupt */
#define BC_HSSPIn_TXC_TFMTC_POS 5
#define BC_HSSPIn_TXC_TFMTC_LEN 1
#define BC_HSSPIn_TXC_TFMTC_MASK 0x00000020
#define BC_HSSPIn_TXC_TFMTC_SET(x) (x << 5)
#define BC_HSSPIn_TXC_TFMTC_GET(x) ((x >> 5) & 0x00000001)

/*! Clear Slave Select Released Interrupt */
#define BC_HSSPIn_TXC_TSSRC_POS 6
#define BC_HSSPIn_TXC_TSSRC_LEN 1
#define BC_HSSPIn_TXC_TSSRC_MASK 0x00000040
#define BC_HSSPIn_TXC_TSSRC_SET(x) (x << 6)
#define BC_HSSPIn_TXC_TSSRC_GET(x) ((x >> 6) & 0x00000001)

/****************************************************
  ::RXF:: BitField descriptions
****************************************************/
/*! RX-FIFO Full Interrupt */
#define BC_HSSPIn_RXF_RFFS_POS 0
#define BC_HSSPIn_RXF_RFFS_LEN 1
#define BC_HSSPIn_RXF_RFFS_MASK 0x00000001
#define BC_HSSPIn_RXF_RFFS_SET(x) (x << 0)
#define BC_HSSPIn_RXF_RFFS_GET(x) ((x >> 0) & 0x00000001)

/*! RX-FIFO and Shift Register are Empty Interrupt */
#define BC_HSSPIn_RXF_RFES_POS 1
#define BC_HSSPIn_RXF_RFES_LEN 1
#define BC_HSSPIn_RXF_RFES_MASK 0x00000002
#define BC_HSSPIn_RXF_RFES_SET(x) (x << 1)
#define BC_HSSPIn_RXF_RFES_GET(x) ((x >> 1) & 0x00000001)

/*! RX-FIFO Overrun Interrupt */
#define BC_HSSPIn_RXF_RFOS_POS 2
#define BC_HSSPIn_RXF_RFOS_LEN 1
#define BC_HSSPIn_RXF_RFOS_MASK 0x00000004
#define BC_HSSPIn_RXF_RFOS_SET(x) (x << 2)
#define BC_HSSPIn_RXF_RFOS_GET(x) ((x >> 2) & 0x00000001)

/*! RX-FIFO Underrun Interrupt */
#define BC_HSSPIn_RXF_RFUS_POS 3
#define BC_HSSPIn_RXF_RFUS_LEN 1
#define BC_HSSPIn_RXF_RFUS_MASK 0x00000008
#define BC_HSSPIn_RXF_RFUS_SET(x) (x << 3)
#define BC_HSSPIn_RXF_RFUS_GET(x) ((x >> 3) & 0x00000001)

/*! RX-FIFO Fill Level is Less than or Equal to Threshold Interrupt */
#define BC_HSSPIn_RXF_RFLETS_POS 4
#define BC_HSSPIn_RXF_RFLETS_LEN 1
#define BC_HSSPIn_RXF_RFLETS_MASK 0x00000010
#define BC_HSSPIn_RXF_RFLETS_SET(x) (x << 4)
#define BC_HSSPIn_RXF_RFLETS_GET(x) ((x >> 4) & 0x00000001)

/*! RX-FIFO Fill Level is More than Threshold Interrupt */
#define BC_HSSPIn_RXF_RFMTS_POS 5
#define BC_HSSPIn_RXF_RFMTS_LEN 1
#define BC_HSSPIn_RXF_RFMTS_MASK 0x00000020
#define BC_HSSPIn_RXF_RFMTS_SET(x) (x << 5)
#define BC_HSSPIn_RXF_RFMTS_GET(x) ((x >> 5) & 0x00000001)

/*! Slave Select Released Interrupt */
#define BC_HSSPIn_RXF_RSSRS_POS 6
#define BC_HSSPIn_RXF_RSSRS_LEN 1
#define BC_HSSPIn_RXF_RSSRS_MASK 0x00000040
#define BC_HSSPIn_RXF_RSSRS_SET(x) (x << 6)
#define BC_HSSPIn_RXF_RSSRS_GET(x) ((x >> 6) & 0x00000001)

/****************************************************
  ::RXE:: BitField descriptions
****************************************************/
/*! Enable RX-FIFO Full Interrupt */
#define BC_HSSPIn_RXE_RFFE_POS 0
#define BC_HSSPIn_RXE_RFFE_LEN 1
#define BC_HSSPIn_RXE_RFFE_MASK 0x00000001
#define BC_HSSPIn_RXE_RFFE_SET(x) (x << 0)
#define BC_HSSPIn_RXE_RFFE_GET(x) ((x >> 0) & 0x00000001)

/*! Enable RX-FIFO and Shift Register are Empty Interrupt */
#define BC_HSSPIn_RXE_RFEE_POS 1
#define BC_HSSPIn_RXE_RFEE_LEN 1
#define BC_HSSPIn_RXE_RFEE_MASK 0x00000002
#define BC_HSSPIn_RXE_RFEE_SET(x) (x << 1)
#define BC_HSSPIn_RXE_RFEE_GET(x) ((x >> 1) & 0x00000001)

/*! Enable RX-FIFO Overrun Interrupt */
#define BC_HSSPIn_RXE_RFOE_POS 2
#define BC_HSSPIn_RXE_RFOE_LEN 1
#define BC_HSSPIn_RXE_RFOE_MASK 0x00000004
#define BC_HSSPIn_RXE_RFOE_SET(x) (x << 2)
#define BC_HSSPIn_RXE_RFOE_GET(x) ((x >> 2) & 0x00000001)

/*! Enable RX-FIFO Underrun Interrupt */
#define BC_HSSPIn_RXE_RFUE_POS 3
#define BC_HSSPIn_RXE_RFUE_LEN 1
#define BC_HSSPIn_RXE_RFUE_MASK 0x00000008
#define BC_HSSPIn_RXE_RFUE_SET(x) (x << 3)
#define BC_HSSPIn_RXE_RFUE_GET(x) ((x >> 3) & 0x00000001)

/*! Enable RX-FIFO Fill Level is Less than or Equal to Threshold Interrupt */
#define BC_HSSPIn_RXE_RFLETE_POS 4
#define BC_HSSPIn_RXE_RFLETE_LEN 1
#define BC_HSSPIn_RXE_RFLETE_MASK 0x00000010
#define BC_HSSPIn_RXE_RFLETE_SET(x) (x << 4)
#define BC_HSSPIn_RXE_RFLETE_GET(x) ((x >> 4) & 0x00000001)

/*! Enable RX-FIFO Fill Level is More than Threshold Interrupt */
#define BC_HSSPIn_RXE_RFMTE_POS 5
#define BC_HSSPIn_RXE_RFMTE_LEN 1
#define BC_HSSPIn_RXE_RFMTE_MASK 0x00000020
#define BC_HSSPIn_RXE_RFMTE_SET(x) (x << 5)
#define BC_HSSPIn_RXE_RFMTE_GET(x) ((x >> 5) & 0x00000001)

/*! Enable Slave Select Released Interrupt */
#define BC_HSSPIn_RXE_RSSRE_POS 6
#define BC_HSSPIn_RXE_RSSRE_LEN 1
#define BC_HSSPIn_RXE_RSSRE_MASK 0x00000040
#define BC_HSSPIn_RXE_RSSRE_SET(x) (x << 6)
#define BC_HSSPIn_RXE_RSSRE_GET(x) ((x >> 6) & 0x00000001)

/****************************************************
  ::RXC:: BitField descriptions
****************************************************/
/*! Clear ALL RX Interrupts */
#define BC_HSSPIn_RXC_ALL_POS 0
#define BC_HSSPIn_RXC_ALL_LEN 7
#define BC_HSSPIn_RXC_ALL_MASK 0x0000007f
#define BC_HSSPIn_RXC_ALL_SET(x) (x << 0)
#define BC_HSSPIn_RXC_ALL_GET(x) ((x >> 0) & 0x0000007f)

/*! Clear RX-FIFO Full Interrupt */
#define BC_HSSPIn_RXC_RFFC_POS 0
#define BC_HSSPIn_RXC_RFFC_LEN 1
#define BC_HSSPIn_RXC_RFFC_MASK 0x00000001
#define BC_HSSPIn_RXC_RFFC_SET(x) (x << 0)
#define BC_HSSPIn_RXC_RFFC_GET(x) ((x >> 0) & 0x00000001)

/*! Clear RX-FIFO and Shift Register are Empty Interrupt */
#define BC_HSSPIn_RXC_RFEC_POS 1
#define BC_HSSPIn_RXC_RFEC_LEN 1
#define BC_HSSPIn_RXC_RFEC_MASK 0x00000002
#define BC_HSSPIn_RXC_RFEC_SET(x) (x << 1)
#define BC_HSSPIn_RXC_RFEC_GET(x) ((x >> 1) & 0x00000001)

/*! Clear RX-FIFO Overrun Interrupt */
#define BC_HSSPIn_RXC_RFOC_POS 2
#define BC_HSSPIn_RXC_RFOC_LEN 1
#define BC_HSSPIn_RXC_RFOC_MASK 0x00000004
#define BC_HSSPIn_RXC_RFOC_SET(x) (x << 2)
#define BC_HSSPIn_RXC_RFOC_GET(x) ((x >> 2) & 0x00000001)

/*! Clear RX-FIFO Underrun Interrupt */
#define BC_HSSPIn_RXC_RFUC_POS 3
#define BC_HSSPIn_RXC_RFUC_LEN 1
#define BC_HSSPIn_RXC_RFUC_MASK 0x00000008
#define BC_HSSPIn_RXC_RFUC_SET(x) (x << 3)
#define BC_HSSPIn_RXC_RFUC_GET(x) ((x >> 3) & 0x00000001)

/*! Clear RX-FIFO Fill Level is Less than or Equal to Threshold Interrupt */
#define BC_HSSPIn_RXC_RFLETC_POS 4
#define BC_HSSPIn_RXC_RFLETC_LEN 1
#define BC_HSSPIn_RXC_RFLETC_MASK 0x00000010
#define BC_HSSPIn_RXC_RFLETC_SET(x) (x << 4)
#define BC_HSSPIn_RXC_RFLETC_GET(x) ((x >> 4) & 0x00000001)

/*! Clear RX-FIFO Fill Level is More than Threshold Interrupt */
#define BC_HSSPIn_RXC_RFMTC_POS 5
#define BC_HSSPIn_RXC_RFMTC_LEN 1
#define BC_HSSPIn_RXC_RFMTC_MASK 0x00000020
#define BC_HSSPIn_RXC_RFMTC_SET(x) (x << 5)
#define BC_HSSPIn_RXC_RFMTC_GET(x) ((x >> 5) & 0x00000001)

/*! Clear Slave Select Released Interrupt */
#define BC_HSSPIn_RXC_RSSRC_POS 6
#define BC_HSSPIn_RXC_RSSRC_LEN 1
#define BC_HSSPIn_RXC_RSSRC_MASK 0x00000040
#define BC_HSSPIn_RXC_RSSRC_SET(x) (x << 6)
#define BC_HSSPIn_RXC_RSSRC_GET(x) ((x >> 6) & 0x00000001)

/****************************************************
  ::FAULTF:: BitField descriptions
****************************************************/
/*! Unmapped Memory Access Fault */
#define BC_HSSPIn_FAULTF_UMAFS_POS 0
#define BC_HSSPIn_FAULTF_UMAFS_LEN 1
#define BC_HSSPIn_FAULTF_UMAFS_MASK 0x00000001
#define BC_HSSPIn_FAULTF_UMAFS_SET(x) (x << 0)
#define BC_HSSPIn_FAULTF_UMAFS_GET(x) ((x >> 0) & 0x00000001)

/*! Write Access Fault */
#define BC_HSSPIn_FAULTF_WAFS_POS 1
#define BC_HSSPIn_FAULTF_WAFS_LEN 1
#define BC_HSSPIn_FAULTF_WAFS_MASK 0x00000002
#define BC_HSSPIn_FAULTF_WAFS_SET(x) (x << 1)
#define BC_HSSPIn_FAULTF_WAFS_GET(x) ((x >> 1) & 0x00000001)

/*! Protection Violation Fault */
#define BC_HSSPIn_FAULTF_PVFS_POS 2
#define BC_HSSPIn_FAULTF_PVFS_LEN 1
#define BC_HSSPIn_FAULTF_PVFS_MASK 0x00000004
#define BC_HSSPIn_FAULTF_PVFS_SET(x) (x << 2)
#define BC_HSSPIn_FAULTF_PVFS_GET(x) ((x >> 2) & 0x00000001)

/*! DMA Write Channel Block Size Fault */
#define BC_HSSPIn_FAULTF_DWCBSFS_POS 3
#define BC_HSSPIn_FAULTF_DWCBSFS_LEN 1
#define BC_HSSPIn_FAULTF_DWCBSFS_MASK 0x00000008
#define BC_HSSPIn_FAULTF_DWCBSFS_SET(x) (x << 3)
#define BC_HSSPIn_FAULTF_DWCBSFS_GET(x) ((x >> 3) & 0x00000001)

/*! DMA Read Channel Block Size Fault */
#define BC_HSSPIn_FAULTF_DRCBSFS_POS 4
#define BC_HSSPIn_FAULTF_DRCBSFS_LEN 1
#define BC_HSSPIn_FAULTF_DRCBSFS_MASK 0x00000010
#define BC_HSSPIn_FAULTF_DRCBSFS_SET(x) (x << 4)
#define BC_HSSPIn_FAULTF_DRCBSFS_GET(x) ((x >> 4) & 0x00000001)

/****************************************************
  ::FAULTC:: BitField descriptions
****************************************************/
/*! Clear Unmapped Memory Access Fault */
#define BC_HSSPIn_FAULTC_UMAFC_POS 0
#define BC_HSSPIn_FAULTC_UMAFC_LEN 1
#define BC_HSSPIn_FAULTC_UMAFC_MASK 0x00000001
#define BC_HSSPIn_FAULTC_UMAFC_SET(x) (x << 0)
#define BC_HSSPIn_FAULTC_UMAFC_GET(x) ((x >> 0) & 0x00000001)

/*! Clear Write Access Fault */
#define BC_HSSPIn_FAULTC_WAFC_POS 1
#define BC_HSSPIn_FAULTC_WAFC_LEN 1
#define BC_HSSPIn_FAULTC_WAFC_MASK 0x00000002
#define BC_HSSPIn_FAULTC_WAFC_SET(x) (x << 1)
#define BC_HSSPIn_FAULTC_WAFC_GET(x) ((x >> 1) & 0x00000001)

/*! Clear Protection Violation Fault */
#define BC_HSSPIn_FAULTC_PVFC_POS 2
#define BC_HSSPIn_FAULTC_PVFC_LEN 1
#define BC_HSSPIn_FAULTC_PVFC_MASK 0x00000004
#define BC_HSSPIn_FAULTC_PVFC_SET(x) (x << 2)
#define BC_HSSPIn_FAULTC_PVFC_GET(x) ((x >> 2) & 0x00000001)

/*! Clear DMA Write Channel Block Size Fault */
#define BC_HSSPIn_FAULTC_DWCBSFC_POS 3
#define BC_HSSPIn_FAULTC_DWCBSFC_LEN 1
#define BC_HSSPIn_FAULTC_DWCBSFC_MASK 0x00000008
#define BC_HSSPIn_FAULTC_DWCBSFC_SET(x) (x << 3)
#define BC_HSSPIn_FAULTC_DWCBSFC_GET(x) ((x >> 3) & 0x00000001)

/*! Clear DMA Read Channel Block Size Fault */
#define BC_HSSPIn_FAULTC_DRCBSFC_POS 4
#define BC_HSSPIn_FAULTC_DRCBSFC_LEN 1
#define BC_HSSPIn_FAULTC_DRCBSFC_MASK 0x00000010
#define BC_HSSPIn_FAULTC_DRCBSFC_SET(x) (x << 4)
#define BC_HSSPIn_FAULTC_DRCBSFC_GET(x) ((x >> 4) & 0x00000001)

/****************************************************
  ::DM:: BitField descriptions
****************************************************/
/*! iMSTART Enable */
#define BC_HSSPIn_DM_DMCFG_SSDC_POS 1
#define BC_HSSPIn_DM_DMCFG_SSDC_LEN 1
#define BC_HSSPIn_DM_DMCFG_SSDC_MASK 0x00000002
#define BC_HSSPIn_DM_DMCFG_SSDC_SET(x) (x << 1)
#define BC_HSSPIn_DM_DMCFG_SSDC_GET(x) ((x >> 1) & 0x00000001)

/*! Slave Select Deassertion Control */
#define BC_HSSPIn_DM_DMCFG_MSTARTEN_POS 2
#define BC_HSSPIn_DM_DMCFG_MSTARTEN_LEN 1
#define BC_HSSPIn_DM_DMCFG_MSTARTEN_MASK 0x00000004
#define BC_HSSPIn_DM_DMCFG_MSTARTEN_SET(x) (x << 2)
#define BC_HSSPIn_DM_DMCFG_MSTARTEN_GET(x) ((x >> 2) & 0x00000001)

/*! RX DMA Enable */
#define BC_HSSPIn_DM_DMDMAEN_RXDMAEN_POS 8
#define BC_HSSPIn_DM_DMDMAEN_RXDMAEN_LEN 1
#define BC_HSSPIn_DM_DMDMAEN_RXDMAEN_MASK 0x00000100
#define BC_HSSPIn_DM_DMDMAEN_RXDMAEN_SET(x) (x << 8)
#define BC_HSSPIn_DM_DMDMAEN_RXDMAEN_GET(x) ((x >> 8) & 0x00000001)

/*! TX DMA Enable */
#define BC_HSSPIn_DM_DMDMAEN_TXDMAEN_POS 9
#define BC_HSSPIn_DM_DMDMAEN_TXDMAEN_LEN 1
#define BC_HSSPIn_DM_DMDMAEN_TXDMAEN_MASK 0x00000200
#define BC_HSSPIn_DM_DMDMAEN_TXDMAEN_SET(x) (x << 9)
#define BC_HSSPIn_DM_DMDMAEN_TXDMAEN_GET(x) ((x >> 9) & 0x00000001)

/****************************************************
  ::DMCTRL:: BitField descriptions
****************************************************/
/*! Transfer start bit */
#define BC_HSSPIn_DMCTRL_DMSTART_START_POS 0
#define BC_HSSPIn_DMCTRL_DMSTART_START_LEN 1
#define BC_HSSPIn_DMCTRL_DMSTART_START_MASK 0x00000001
#define BC_HSSPIn_DMCTRL_DMSTART_START_SET(x) (x << 0)
#define BC_HSSPIn_DMCTRL_DMSTART_START_GET(x) ((x >> 0) & 0x00000001)

/*! Transfer stop bit */
#define BC_HSSPIn_DMCTRL_DMSTOP_STOP_POS 8
#define BC_HSSPIn_DMCTRL_DMSTOP_STOP_LEN 1
#define BC_HSSPIn_DMCTRL_DMSTOP_STOP_MASK 0x00000100
#define BC_HSSPIn_DMCTRL_DMSTOP_STOP_SET(x) (x << 8)
#define BC_HSSPIn_DMCTRL_DMSTOP_STOP_GET(x) ((x >> 8) & 0x00000001)

/*! Peripheral Select */
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_POS 16
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_LEN 2
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_MASK 0x00030000
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_SET(x) (x << 16)
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_GET(x) ((x >> 16) & 0x00000003)

#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_SSEL0 0x00000
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_SSEL1 0x00001
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_SSEL2 0x00002
#define BC_HSSPIn_DMCTRL_DMPSEL_PSEL_SSEL3 0x00003
/*! Transfer Protocol Transfer bit width) */
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_POS 24
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_LEN 2
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_MASK 0x03000000
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_SET(x) (x << 24)
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_GET(x) ((x >> 24) & 0x00000003)

#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_SINGLE_BIT 0x00000
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_DUAL_BIT 0x00001
#define BC_HSSPIn_DMCTRL_DMTRP_WIDTH_QUAD_BIT 0x00002
/*! Transfer Protocol Operation mode */
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_POS 26
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_LEN 2
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_MASK 0x0c000000
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_SET(x) (x << 26)
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_GET(x) ((x >> 26) & 0x00000003)

#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_NONE 0x00000
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_RX_ONLY 0x00001
#define BC_HSSPIn_DMCTRL_DMTRP_OPERATION_TX_ONLY 0x00002
/****************************************************
  ::COUNT:: BitField descriptions
****************************************************/
/*! Byte Count Control */
#define BC_HSSPIn_COUNT_DMBCC_BCC_POS 0
#define BC_HSSPIn_COUNT_DMBCC_BCC_LEN 16
#define BC_HSSPIn_COUNT_DMBCC_BCC_MASK 0x0000ffff
#define BC_HSSPIn_COUNT_DMBCC_BCC_SET(x) (x << 0)
#define BC_HSSPIn_COUNT_DMBCC_BCC_GET(x) ((x >> 0) & 0x0000ffff)

/*! Byte Count Status */
#define BC_HSSPIn_COUNT_DMBCS_BCS_POS 16
#define BC_HSSPIn_COUNT_DMBCS_BCS_LEN 16
#define BC_HSSPIn_COUNT_DMBCS_BCS_MASK 0xffff0000
#define BC_HSSPIn_COUNT_DMBCS_BCS_SET(x) (x << 16)
#define BC_HSSPIn_COUNT_DMBCS_BCS_GET(x) ((x >> 16) & 0x0000ffff)

/****************************************************
  ::DMSTATUS:: BitField descriptions
****************************************************/
/*! Receive status bit */
#define BC_HSSPIn_DMSTATUS_RXACTIVE_POS 0
#define BC_HSSPIn_DMSTATUS_RXACTIVE_LEN 1
#define BC_HSSPIn_DMSTATUS_RXACTIVE_MASK 0x00000001
#define BC_HSSPIn_DMSTATUS_RXACTIVE_SET(x) (x << 0)
#define BC_HSSPIn_DMSTATUS_RXACTIVE_GET(x) ((x >> 0) & 0x00000001)

/*! Transmit status bit */
#define BC_HSSPIn_DMSTATUS_TXACTIVE_POS 1
#define BC_HSSPIn_DMSTATUS_TXACTIVE_LEN 1
#define BC_HSSPIn_DMSTATUS_TXACTIVE_MASK 0x00000002
#define BC_HSSPIn_DMSTATUS_TXACTIVE_SET(x) (x << 1)
#define BC_HSSPIn_DMSTATUS_TXACTIVE_GET(x) ((x >> 1) & 0x00000001)

/*! Current fill level of RX-FIFO */
#define BC_HSSPIn_DMSTATUS_RXFLEVEL_POS 8
#define BC_HSSPIn_DMSTATUS_RXFLEVEL_LEN 5
#define BC_HSSPIn_DMSTATUS_RXFLEVEL_MASK 0x00001f00
#define BC_HSSPIn_DMSTATUS_RXFLEVEL_SET(x) (x << 8)
#define BC_HSSPIn_DMSTATUS_RXFLEVEL_GET(x) ((x >> 8) & 0x0000001f)

/*! Current fill level of TX-FIFO */
#define BC_HSSPIn_DMSTATUS_TXFLEVEL_POS 16
#define BC_HSSPIn_DMSTATUS_TXFLEVEL_LEN 5
#define BC_HSSPIn_DMSTATUS_TXFLEVEL_MASK 0x001f0000
#define BC_HSSPIn_DMSTATUS_TXFLEVEL_SET(x) (x << 16)
#define BC_HSSPIn_DMSTATUS_TXFLEVEL_GET(x) ((x >> 16) & 0x0000001f)

/****************************************************
  ::FIFOCFG:: BitField descriptions
****************************************************/
/*! RX-FIFO Threshold Level */
#define BC_HSSPIn_FIFOCFG_RXFTH_POS 0
#define BC_HSSPIn_FIFOCFG_RXFTH_LEN 4
#define BC_HSSPIn_FIFOCFG_RXFTH_MASK 0x0000000f
#define BC_HSSPIn_FIFOCFG_RXFTH_SET(x) (x << 0)
#define BC_HSSPIn_FIFOCFG_RXFTH_GET(x) ((x >> 0) & 0x0000000f)

/*! TX-FIFO Threshold Level */
#define BC_HSSPIn_FIFOCFG_TXFTH_POS 4
#define BC_HSSPIn_FIFOCFG_TXFTH_LEN 4
#define BC_HSSPIn_FIFOCFG_TXFTH_MASK 0x000000f0
#define BC_HSSPIn_FIFOCFG_TXFTH_SET(x) (x << 4)
#define BC_HSSPIn_FIFOCFG_TXFTH_GET(x) ((x >> 4) & 0x0000000f)

/*! FIFO Width */
#define BC_HSSPIn_FIFOCFG_FWIDTH_POS 8
#define BC_HSSPIn_FIFOCFG_FWIDTH_LEN 2
#define BC_HSSPIn_FIFOCFG_FWIDTH_MASK 0x00000300
#define BC_HSSPIn_FIFOCFG_FWIDTH_SET(x) (x << 8)
#define BC_HSSPIn_FIFOCFG_FWIDTH_GET(x) ((x >> 8) & 0x00000003)

/*! TX-FIFO Control */
#define BC_HSSPIn_FIFOCFG_TXCTRL_POS 10
#define BC_HSSPIn_FIFOCFG_TXCTRL_LEN 1
#define BC_HSSPIn_FIFOCFG_TXCTRL_MASK 0x00000400
#define BC_HSSPIn_FIFOCFG_TXCTRL_SET(x) (x << 10)
#define BC_HSSPIn_FIFOCFG_TXCTRL_GET(x) ((x >> 10) & 0x00000001)

/*! RX-FIFO Flush */
#define BC_HSSPIn_FIFOCFG_RXFLSH_POS 11
#define BC_HSSPIn_FIFOCFG_RXFLSH_LEN 1
#define BC_HSSPIn_FIFOCFG_RXFLSH_MASK 0x00000800
#define BC_HSSPIn_FIFOCFG_RXFLSH_SET(x) (x << 11)
#define BC_HSSPIn_FIFOCFG_RXFLSH_GET(x) ((x >> 11) & 0x00000001)

/*! TX-FIFO Flush */
#define BC_HSSPIn_FIFOCFG_TXFLSH_POS 12
#define BC_HSSPIn_FIFOCFG_TXFLSH_LEN 1
#define BC_HSSPIn_FIFOCFG_TXFLSH_MASK 0x00001000
#define BC_HSSPIn_FIFOCFG_TXFLSH_SET(x) (x << 12)
#define BC_HSSPIn_FIFOCFG_TXFLSH_GET(x) ((x >> 12) & 0x00000001)

/****************************************************
  ::TXFIFOn:: BitField descriptions
****************************************************/
/*! TX-FIFO Register */
#define BC_HSSPIn_TXFIFOn_TXDATA_POS 0
#define BC_HSSPIn_TXFIFOn_TXDATA_LEN 32
#define BC_HSSPIn_TXFIFOn_TXDATA_MASK 0xffffffff
#define BC_HSSPIn_TXFIFOn_TXDATA_SET(x) (x)
#define BC_HSSPIn_TXFIFOn_TXDATA_GET(x) (x)

/****************************************************
  ::RXFIFOn:: BitField descriptions
****************************************************/
/*! RX-FIFO Register */
#define BC_HSSPIn_RXFIFOn_RXDATA_POS 0
#define BC_HSSPIn_RXFIFOn_RXDATA_LEN 32
#define BC_HSSPIn_RXFIFOn_RXDATA_MASK 0xffffffff
#define BC_HSSPIn_RXFIFOn_RXDATA_SET(x) (x)
#define BC_HSSPIn_RXFIFOn_RXDATA_GET(x) (x)

/****************************************************
  ::CSCFG:: BitField descriptions
****************************************************/
/*! Serial SRAM /Serial Flash Memory Type Select */
#define BC_HSSPIn_CSCFG_SRAM_POS 0
#define BC_HSSPIn_CSCFG_SRAM_LEN 1
#define BC_HSSPIn_CSCFG_SRAM_MASK 0x00000001
#define BC_HSSPIn_CSCFG_SRAM_SET(x) (x << 0)
#define BC_HSSPIn_CSCFG_SRAM_GET(x) ((x >> 0) & 0x00000001)

/*! Multi Bit Mode */
#define BC_HSSPIn_CSCFG_MBM_POS 1
#define BC_HSSPIn_CSCFG_MBM_LEN 2
#define BC_HSSPIn_CSCFG_MBM_MASK 0x00000006
#define BC_HSSPIn_CSCFG_MBM_SET(x) (x << 1)
#define BC_HSSPIn_CSCFG_MBM_GET(x) ((x >> 1) & 0x00000003)

/*! SPI Change */
#define BC_HSSPIn_CSCFG_SPICHNG_POS 3
#define BC_HSSPIn_CSCFG_SPICHNG_LEN 1
#define BC_HSSPIn_CSCFG_SPICHNG_MASK 0x00000008
#define BC_HSSPIn_CSCFG_SPICHNG_SET(x) (x << 3)
#define BC_HSSPIn_CSCFG_SPICHNG_GET(x) ((x >> 3) & 0x00000001)

/*! Boot Enable */
#define BC_HSSPIn_CSCFG_BOOTEN_POS 4
#define BC_HSSPIn_CSCFG_BOOTEN_LEN 1
#define BC_HSSPIn_CSCFG_BOOTEN_MASK 0x00000010
#define BC_HSSPIn_CSCFG_BOOTEN_SET(x) (x << 4)
#define BC_HSSPIn_CSCFG_BOOTEN_GET(x) ((x >> 4) & 0x00000001)

/*! Boot Select pin */
#define BC_HSSPIn_CSCFG_BSEL_POS 5
#define BC_HSSPIn_CSCFG_BSEL_LEN 1
#define BC_HSSPIn_CSCFG_BSEL_MASK 0x00000020
#define BC_HSSPIn_CSCFG_BSEL_SET(x) (x << 5)
#define BC_HSSPIn_CSCFG_BSEL_GET(x) ((x >> 5) & 0x00000001)

/*! Slave Select 0 Enable */
#define BC_HSSPIn_CSCFG_SSEL0EN_POS 8
#define BC_HSSPIn_CSCFG_SSEL0EN_LEN 1
#define BC_HSSPIn_CSCFG_SSEL0EN_MASK 0x00000100
#define BC_HSSPIn_CSCFG_SSEL0EN_SET(x) (x << 8)
#define BC_HSSPIn_CSCFG_SSEL0EN_GET(x) ((x >> 8) & 0x00000001)

/*! Slave Select 1 Enable */
#define BC_HSSPIn_CSCFG_SSEL1EN_POS 9
#define BC_HSSPIn_CSCFG_SSEL1EN_LEN 1
#define BC_HSSPIn_CSCFG_SSEL1EN_MASK 0x00000200
#define BC_HSSPIn_CSCFG_SSEL1EN_SET(x) (x << 9)
#define BC_HSSPIn_CSCFG_SSEL1EN_GET(x) ((x >> 9) & 0x00000001)

/*! Slave Select 2 Enable */
#define BC_HSSPIn_CSCFG_SSEL2EN_POS 10
#define BC_HSSPIn_CSCFG_SSEL2EN_LEN 1
#define BC_HSSPIn_CSCFG_SSEL2EN_MASK 0x00000400
#define BC_HSSPIn_CSCFG_SSEL2EN_SET(x) (x << 10)
#define BC_HSSPIn_CSCFG_SSEL2EN_GET(x) ((x >> 10) & 0x00000001)

/*! Slave Select 3 Enable */
#define BC_HSSPIn_CSCFG_SSEL3EN_POS 11
#define BC_HSSPIn_CSCFG_SSEL3EN_LEN 1
#define BC_HSSPIn_CSCFG_SSEL3EN_MASK 0x00000800
#define BC_HSSPIn_CSCFG_SSEL3EN_SET(x) (x << 11)
#define BC_HSSPIn_CSCFG_SSEL3EN_GET(x) ((x >> 11) & 0x00000001)

/*! Memory Device Selection bits */
#define BC_HSSPIn_CSCFG_MSEL_POS 16
#define BC_HSSPIn_CSCFG_MSEL_LEN 4
#define BC_HSSPIn_CSCFG_MSEL_MASK 0x000f0000
#define BC_HSSPIn_CSCFG_MSEL_SET(x) (x << 16)
#define BC_HSSPIn_CSCFG_MSEL_GET(x) ((x >> 16) & 0x0000000f)

/****************************************************
  ::CSITIME:: BitField descriptions
****************************************************/
/*! Idle Timer */
#define BC_HSSPIn_CSITIME_ITIME_POS 0
#define BC_HSSPIn_CSITIME_ITIME_LEN 16
#define BC_HSSPIn_CSITIME_ITIME_MASK 0x0000ffff
#define BC_HSSPIn_CSITIME_ITIME_SET(x) (x << 0)
#define BC_HSSPIn_CSITIME_ITIME_GET(x) ((x >> 0) & 0x0000ffff)

/****************************************************
  ::CSAEXT:: BitField descriptions
****************************************************/
/*! Address Extension Bits */
#define BC_HSSPIn_CSAEXT_AEXT_POS 13
#define BC_HSSPIn_CSAEXT_AEXT_LEN 19
#define BC_HSSPIn_CSAEXT_AEXT_MASK 0xffffe000
#define BC_HSSPIn_CSAEXT_AEXT_SET(x) (x << 13)
#define BC_HSSPIn_CSAEXT_AEXT_GET(x) ((x >> 13) & 0x0007ffff)

/****************************************************
  ::HSSPIn_RDCSDCn:: BitField descriptions
****************************************************/
/*! Decode */
#define BC_HSSPIn_HSSPIn_RDCSDCn_DEC_POS 0
#define BC_HSSPIn_HSSPIn_RDCSDCn_DEC_LEN 1
#define BC_HSSPIn_HSSPIn_RDCSDCn_DEC_MASK 0x00000001
#define BC_HSSPIn_HSSPIn_RDCSDCn_DEC_SET(x) (x << 0)
#define BC_HSSPIn_HSSPIn_RDCSDCn_DEC_GET(x) ((x >> 0) & 0x00000001)

/*! Transfer Protocol */
#define BC_HSSPIn_HSSPIn_RDCSDCn_TRP_POS 1
#define BC_HSSPIn_HSSPIn_RDCSDCn_TRP_LEN 2
#define BC_HSSPIn_HSSPIn_RDCSDCn_TRP_MASK 0x00000006
#define BC_HSSPIn_HSSPIn_RDCSDCn_TRP_SET(x) (x << 1)
#define BC_HSSPIn_HSSPIn_RDCSDCn_TRP_GET(x) ((x >> 1) & 0x00000003)

/*! Continuous */
#define BC_HSSPIn_HSSPIn_RDCSDCn_CONT_POS 3
#define BC_HSSPIn_HSSPIn_RDCSDCn_CONT_LEN 1
#define BC_HSSPIn_HSSPIn_RDCSDCn_CONT_MASK 0x00000008
#define BC_HSSPIn_HSSPIn_RDCSDCn_CONT_SET(x) (x << 3)
#define BC_HSSPIn_HSSPIn_RDCSDCn_CONT_GET(x) ((x >> 3) & 0x00000001)

/*! Command Sequencer Data /Control Byte for Memory-Read transactions */
#define BC_HSSPIn_HSSPIn_RDCSDCn_RDCSDATA_POS 8
#define BC_HSSPIn_HSSPIn_RDCSDCn_RDCSDATA_LEN 8
#define BC_HSSPIn_HSSPIn_RDCSDCn_RDCSDATA_MASK 0x0000ff00
#define BC_HSSPIn_HSSPIn_RDCSDCn_RDCSDATA_SET(x) (x << 8)
#define BC_HSSPIn_HSSPIn_RDCSDCn_RDCSDATA_GET(x) ((x >> 8) & 0x000000ff)

/****************************************************
  ::HSSPIn_RDCSDCnp1:: BitField descriptions
****************************************************/
/*! Decode */
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_DEC_POS 16
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_DEC_LEN 1
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_DEC_MASK 0x00010000
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_DEC_SET(x) (x << 16)
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_DEC_GET(x) ((x >> 16) & 0x00000001)

/*! Transfer Protocol */
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_TRP_POS 17
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_TRP_LEN 2
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_TRP_MASK 0x00060000
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_TRP_SET(x) (x << 17)
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_TRP_GET(x) ((x >> 17) & 0x00000003)

/*! Continuous */
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_CONT_POS 19
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_CONT_LEN 1
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_CONT_MASK 0x00080000
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_CONT_SET(x) (x << 19)
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_CONT_GET(x) ((x >> 19) & 0x00000001)

/*! Command Sequencer Data /Control Byte for Memory-Read transactions */
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_RDCSDATA_POS 24
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_RDCSDATA_LEN 8
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_RDCSDATA_MASK 0xff000000
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_RDCSDATA_SET(x) (x << 24)
#define BC_HSSPIn_HSSPIn_RDCSDCnp1_RDCSDATA_GET(x) ((x >> 24) & 0x000000ff)

/****************************************************
  ::HSSPIn_WRCSDCn:: BitField descriptions
****************************************************/
/*! Decode */
#define BC_HSSPIn_HSSPIn_WRCSDCn_DEC_POS 0
#define BC_HSSPIn_HSSPIn_WRCSDCn_DEC_LEN 1
#define BC_HSSPIn_HSSPIn_WRCSDCn_DEC_MASK 0x00000001
#define BC_HSSPIn_HSSPIn_WRCSDCn_DEC_SET(x) (x << 0)
#define BC_HSSPIn_HSSPIn_WRCSDCn_DEC_GET(x) ((x >> 0) & 0x00000001)

/*! Transfer Protocol */
#define BC_HSSPIn_HSSPIn_WRCSDCn_TRP_POS 1
#define BC_HSSPIn_HSSPIn_WRCSDCn_TRP_LEN 2
#define BC_HSSPIn_HSSPIn_WRCSDCn_TRP_MASK 0x00000006
#define BC_HSSPIn_HSSPIn_WRCSDCn_TRP_SET(x) (x << 1)
#define BC_HSSPIn_HSSPIn_WRCSDCn_TRP_GET(x) ((x >> 1) & 0x00000003)

/*! Continuous */
#define BC_HSSPIn_HSSPIn_WRCSDCn_CONT_POS 3
#define BC_HSSPIn_HSSPIn_WRCSDCn_CONT_LEN 1
#define BC_HSSPIn_HSSPIn_WRCSDCn_CONT_MASK 0x00000008
#define BC_HSSPIn_HSSPIn_WRCSDCn_CONT_SET(x) (x << 3)
#define BC_HSSPIn_HSSPIn_WRCSDCn_CONT_GET(x) ((x >> 3) & 0x00000001)

/*! Command Sequencer Data /Control Byte for Memory-write transactions */
#define BC_HSSPIn_HSSPIn_WRCSDCn_WRCSDATA_POS 8
#define BC_HSSPIn_HSSPIn_WRCSDCn_WRCSDATA_LEN 8
#define BC_HSSPIn_HSSPIn_WRCSDCn_WRCSDATA_MASK 0x0000ff00
#define BC_HSSPIn_HSSPIn_WRCSDCn_WRCSDATA_SET(x) (x << 8)
#define BC_HSSPIn_HSSPIn_WRCSDCn_WRCSDATA_GET(x) ((x >> 8) & 0x000000ff)

/****************************************************
  ::HSSPIn_WRCSDCnp1:: BitField descriptions
****************************************************/
/*! Decode */
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_DEC_POS 16
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_DEC_LEN 1
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_DEC_MASK 0x00010000
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_DEC_SET(x) (x << 16)
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_DEC_GET(x) ((x >> 16) & 0x00000001)

/*! Transfer Protocol */
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_TRP_POS 17
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_TRP_LEN 2
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_TRP_MASK 0x00060000
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_TRP_SET(x) (x << 17)
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_TRP_GET(x) ((x >> 17) & 0x00000003)

/*! Continuous */
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_CONT_POS 19
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_CONT_LEN 1
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_CONT_MASK 0x00080000
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_CONT_SET(x) (x << 19)
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_CONT_GET(x) ((x >> 19) & 0x00000001)

/*! Command Sequencer Data /Control Byte for Memory-write transactions */
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_WRCSDATA_POS 24
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_WRCSDATA_LEN 8
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_WRCSDATA_MASK 0xff000000
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_WRCSDATA_SET(x) (x << 24)
#define BC_HSSPIn_HSSPIn_WRCSDCnp1_WRCSDATA_GET(x) ((x >> 24) & 0x000000ff)

/****************************************************
  ::MID:: BitField descriptions
****************************************************/
/*! Module ID */
#define BC_HSSPIn_MID_MID_POS 0
#define BC_HSSPIn_MID_MID_LEN 32
#define BC_HSSPIn_MID_MID_MASK 0xffffffff
#define BC_HSSPIn_MID_MID_SET(x) (x)
#define BC_HSSPIn_MID_MID_GET(x) (x)
