#ifndef __UART_REG_H_
#define __UART_REG_H_

#include "common.h"

/*
 * UART Registers
 */

/**
 * UART register structure.
 */
typedef volatile struct {
    uint32_t DR;            /**<  Data Register */
    uint32_t RSRECR;        /**<  Receive Status Register / Error Clear Register */
    uint32_t Reserved01[4]; /**<  Reserved */
    uint32_t FR;            /**<  Flag Register */
    uint32_t Reserved02;    /**<  Reserved */
    uint32_t ILPR;          /**<  IrDA Low-Power Counter Register */
    uint32_t IBRD;          /**<  Integer Baud Rate Register */
    uint32_t FBRD;          /**<  Fractional Baud Rate Register */
    uint32_t LCR_H;         /**<  Line Control Register */
    uint32_t CR;            /**<  Control Register */
    uint32_t IFLS;          /**<  Interrupt FIFO Level Select Register */
    uint32_t IMSC;          /**<  Interrupt Mask Set / Clear Register */
    uint32_t RIS;           /**<  Raw Interrupt Status Register */
    uint32_t MIS;           /**<  Masked Interrupt Status Register */
    uint32_t ICR;           /**<  Interrupt Clear Register */
    uint32_t DMACR;         /**<  uart DMA Control Register */
    uint32_t Reserved03[(0xFE0 - 0x4C) / 4];
    uint32_t PeriphID[4];
    uint32_t CellID[4];
} uart_reg_t;

/***************  Bit definition of UARTTDR register  ***************/
#define UART_DR_OE_Pos 11
#define UART_DR_OE_Msk ((uint32_t)0x1 << UART_DR_OE_Pos)
#define UART_DR_OE UART_DR_OE_Msk /* Overrun error */
#define UART_DR_FE_Pos 10
#define UART_DR_FE_Msk ((uint32_t)0x1 << UART_DR_FE_Pos)
#define UART_DR_FE UART_DR_FE_Msk /* Break error */
#define UART_DR_PE_Pos 9
#define UART_DR_PE_Msk ((uint32_t)0x1 << UART_DR_PE_Msk)
#define UART_DR_PE UART_DR_PE_Msk /* Parity error */
#define UART_DR_BE_Pos 8
#define UART_DR_BE_Msk ((uint32_t)0x1 << UART_DR_BE_Pos)
#define UART_DR_BE UART_DR_BE_Msk /* Framing error */
#define UART_DR_DATA_Pos 0
#define UART_DR_DATA_Msk ((uint32_t)0xFF << UART_DR_DATA_Pos)
#define UART_DR_DATA UART_DR_DATA_Msk /* Recieve data charactor  */
                                      /* Transmit data charactor */

/***************  Bit definition of UARTRSR register  ***************/
#define UART_RSR_OE_Pos 3
#define UART_RSR_OE_Msk ((uint32_t)0x1 << UART_RSR_OE_Pos)
#define UART_RSR_OE UART_RSR_OE_Msk /* Overrun error */
#define UART_RSR_BE_Pos 2
#define UART_RSR_BE_Msk ((uint32_t)0x1 << UART_RSR_BE_Pos)
#define UART_RSR_BE UART_RSR_BE_Msk /* Break error */
#define UART_RSR_PE_Pos 1
#define UART_RSR_PE_Msk ((uint32_t)0x1 << UART_RSR_PE_Pos)
#define UART_RSR_PE UART_RSR_PE_Msk /* Parity error */
#define UART_RSR_FE_Pos 0
#define UART_RSR_FE_Msk ((uint32_t)0x1 << UART_RSR_FE_Pos)
#define UART_RSR_FE UART_RSR_FE_Msk /* Framing error */

/***************  Bit definition of UARTTFR register  ***************/
#define UART_FR_RI_Pos 8
#define UART_FR_RI_Msk ((uint32_t)0x01 << UART_FR_RI_Pos)
#define UART_FR_RI UART_FR_RI_Msk /* Ring indicator */
#define UART_FR_TXFE_Pos 7
#define UART_FR_TXFE_Msk ((uint32_t)0x01 << UART_FR_TXFE_Pos)
#define UART_FR_TXFE UART_FR_TXFE_Msk /* Transmit FIFO empty */
#define UART_FR_RXFF_Pos 6
#define UART_FR_RXFF_Msk ((uint32_t)0x1 << UART_FR_RXFF_Pos)
#define UART_FR_RXFF UART_FR_RXFF_Msk /* Receive FIFO full */
#define UART_FR_TXFF_Pos 5
#define UART_FR_TXFF_Msk ((uint32_t)0x1 << UART_FR_TXFF_Pos)
#define UART_FR_TXFF UART_FR_TXFF_Msk /* Transmit FIFO full */
#define UART_FR_RXFE_Pos 4
#define UART_FR_RXFE_Msk ((uint32_t)0x1 << UART_FR_RXFE_Pos)
#define UART_FR_RXFE UART_FR_RXFE_Msk /* Receive FIFO empty */
#define UART_FR_BUSY_Pos 3
#define UART_FR_BUSY_Msk ((uint32_t)0x1 << UART_FR_BUSY_Pos)
#define UART_FR_BUSY UART_FR_BUSY_Msk /* UART busy */
#define UART_FR_DCD_Pos 2
#define UART_FR_DCD_Msk ((uint32_t)0x1 << UART_FR_DCD_Pos)
#define UART_FR_DCD UART_FR_DCD_Msk /* Data carrier detect */
#define UART_FR_DSR_Pos 1
#define UART_FR_DSR_Msk ((uint32_t)0x1 << UART_FR_DSR_Pos)
#define UART_FR_DSR UART_FR_DSR_Msk /* Data set ready */
#define UART_FR_CTS_Pos 0
#define UART_FR_CTS_Msk ((uint32_t)0x1 << UART_FR_CTS_Pos)
#define UART_FR_CTS UART_FR_CTS_Msk /* Clear to send */

/***************  Bit definition of UARTILPR register  ***************/
#define UART_ILPR_ILPDVSR_Pos 0
#define UART_ILPR_ILPDVSR_Msk ((uint32_t)0xFF << UART_ILPR_ILPDVSR_Pos)
#define UART_ILPR_ILPDVSR UART_ILPR_ILPDVSR_Msk /* 8bit low-power divisor value */

/***************  Bit definition of UARTIBRD register  ***************/
#define UART_IBRD_BD_Pos 0
#define UART_IBRD_BD_Msk ((uint32_t)0xFFFF << UART_IBRD_BD_Pos)
#define UART_IBRD_BD UART_IBRD_BD_Msk /* The integer baud rate divisor */

/***************  Bit definition of UARTFBRD register  ***************/
#define UART_FBRF_BD_Pos 0
#define UART_FBRF_BD_Msk ((uint32_t)0x3F << UART_FBRF_BD_Pos)
#define UART_FBRF_BD UART_FBRF_BD_Msk /* The fractional baud rate divisor */

/***************  Bit definition of UARTLCR_H register  ***************/
#define UART_LCRH_SPS_Pos 7
#define UART_LCRH_SPS_Msk ((uint32_t)0x1 << UART_LCRH_SPS_Pos)
#define UART_LCRH_SPS UART_LCRH_SPS_Msk /* Stick parity select */

#define UART_LCRH_WLEN_Pos 5
#define UART_LCRH_WLEN_Msk ((uint32_t)0x3 << UART_LCRH_WLEN_Pos)
#define UART_LCRH_WLEN UART_LCRH_WLEN_Msk /* Word length MASK*/

/* configuration for WLEN */
#define UART_LCRH_WLEN_8 UART_LCRH_WLEN_Msk /* Word length 8bits*/
#define UART_LCRH_WLEN_7 UART_LCRH_WLEN_Msk /* Word length 7bits*/
#define UART_LCRH_WLEN_6 UART_LCRH_WLEN_Msk /* Word length 6bits*/
#define UART_LCRH_WLEN_5 UART_LCRH_WLEN_Msk /* Word length 5bits*/

#define UART_LCRH_FEN_Pos 4
#define UART_LCRH_FEN_Msk ((uint32_t)0x1 << UART_LCRH_FEN_Pos)
#define UART_LCRH_FEN UART_LCRH_FEN_Msk /* Enable FIFOs */
#define UART_LCRH_STP2_Pos 3
#define UART_LCRH_STP2_Msk ((uint32_t)0x1 << UART_LCRH_STP2_Pos)
#define UART_LCRH_STP2 UART_LCRH_STP2_Msk /* Two stop bits select */
#define UART_LCRH_EPS_Pos 2
#define UART_LCRH_EPS_Msk ((uint32_t)0x1 << UART_LCRH_EPS_Pos)
#define UART_LCRH_EPS UART_LCRH_EPS_Msk /* Even parity select */
#define UART_LCRH_PEN_Pos 1
#define UART_LCRH_PEN_Msk ((uint32_t)0x1 << UART_LCRH_PEN_Pos)
#define UART_LCRH_PEN UART_LCRH_PEN_Msk /* Parity enable */
#define UART_LCRH_BRK_Pos 0
#define UART_LCRH_BRK_Msk ((uint32_t)0x1 << UART_LCRH_BRK_Pos)
#define UART_LCRH_BRK UART_LCRH_BRK_Msk /* Send break */

/***************  Bit definition of UARTCR register  ***************/
#define UART_CR_CTSEN_Pos 15
#define UART_CR_CTSEN_Msk ((uint32_t)0x1 << UART_CR_CTSEN_Pos)
#define UART_CR_CTSEN UART_CR_CTSEN_Msk /* CTS hardware flow control enable */
#define UART_CR_RTSEN_Pos 14
#define UART_CR_RTSEN_Msk ((uint32_t)0x1 << UART_CR_RTSEN_Pos)
#define UART_CR_RTSEN UART_CR_RTSEN_Msk /* RTS hardware flow control enable */
#define UART_CR_OUT2_Pos 13
#define UART_CR_OUT2_Msk ((uint32_t)0x1 << UART_CR_OUT2_Pos)
#define UART_CR_OUT2 UART_CR_OUT2_Msk /* Complement of the UART Out2 modem status output */
#define UART_CR_OUT1_Pos 12
#define UART_CR_OUT1_Msk ((uint32_t)0x1 << UART_CR_OUT1_Pos)
#define UART_CR_OUT1 UART_CR_OUT1_Msk /* Complement of the UART Out2 modem status output */
#define UART_CR_RTS_Pos 11
#define UART_CR_RTS_Msk ((uint32_t)0x1 << UART_CR_RTS_Pos)
#define UART_CR_RTS UART_CR_RTS_Msk /* Request to send */
#define UART_CR_DTR_Pos 10
#define UART_CR_DTR_Msk ((uint32_t)0x1 << UART_CR_DTR_Pos)
#define UART_CR_DTR UART_CR_DTR_Msk /* Data transmit ready */
#define UART_CR_RXE_Pos 9
#define UART_CR_RXE_Msk ((uint32_t)0x1 << UART_CR_RXE_Pos)
#define UART_CR_RXE UART_CR_RXE_Msk /* Receive enable */
#define UART_CR_TXE_Pos 8
#define UART_CR_TXE_Msk ((uint32_t)0x1 << UART_CR_TXE_Pos)
#define UART_CR_TXE UART_CR_TXE_Msk /* Transmit enable */
#define UART_CR_LBE_Pos 7
#define UART_CR_LBE_Msk ((uint32_t)0x1 << UART_CR_LBE_Pos)
#define UART_CR_LBE UART_CR_LBE_Msk /* Loopback enable */
#define UART_CR_SIRLP_Pos 2
#define UART_CR_SIRLP_Msk ((uint32_t)0x1 << UART_CR_SIRLP_Pos)
#define UART_CR_SIRLP UART_CR_SIRLP_Msk /* SIR low-power IrDA mode */
#define UART_CR_SIREN_Pos 1
#define UART_CR_SIREN_Msk ((uint32_t)0x1 << UART_CR_SIREN_Pos)
#define UART_CR_SIREN UART_CR_SIREN_Msk /* SIR enable */
#define UART_CR_UARTEN_Pos 0
#define UART_CR_UARTEN_Msk ((uint32_t)0x1 << UART_CR_UARTEN_Pos)
#define UART_CR_UARTEN UART_CR_UARTEN_Msk /* UART enable */

/***************  Bit definition of UARTIFLS register  ***************/
#define UART_IFLS_RXIFLSEL_Pos 3
#define UART_IFLS_RXIFLSEL_Msk ((uint32_t)0x7 << UART_IFLS_RXIFLSEL_Pos)
#define UART_IFLS_RXIFLSEL UART_IFLS_RXIFLSEL_Msk /* Receive interrupt FIFO level select */

/* configuration for RXIFLSEL */
#define UART_IFLS_RXIFLSEL_1_8_Msk \
    ((uint32_t)((uint32_t)0x0 << UART_IFLS_RXIFLSEL_Pos)) /* Receive FIFO becomes >= 1/8 full */
#define UART_IFLS_RXIFLSEL_1_4_Msk \
    ((uint32_t)((uint32_t)0x1 << UART_IFLS_RXIFLSEL_Pos)) /* Receive FIFO becomes >= 1/4 full */
#define UART_IFLS_RXIFLSEL_1_2_Msk \
    ((uint32_t)((uint32_t)0x2 << UART_IFLS_RXIFLSEL_Pos)) /* Receive FIFO becomes >= 1/2 full */
#define UART_IFLS_RXIFLSEL_3_4_Msk \
    ((uint32_t)((uint32_t)0x3 << UART_IFLS_RXIFLSEL_Pos)) /* Receive FIFO becomes >= 3/4 full */
#define UART_IFLS_RXIFLSEL_7_8_Msk \
    ((uint32_t)((uint32_t)0x4 << UART_IFLS_RXIFLSEL_Pos)) /* Receive FIFO becomes >= 7/8 full */

#define UART_IFLS_RXIFLSEL_1_8 UART_IFLS_RXIFLSEL_1_8_Msk /* Receive FIFO becomes >= 1/8 full */
#define UART_IFLS_RXIFLSEL_1_4 UART_IFLS_RXIFLSEL_1_4_Msk /* Receive FIFO becomes >= 1/4 full */
#define UART_IFLS_RXIFLSEL_1_2 UART_IFLS_RXIFLSEL_1_2_Msk /* Receive FIFO becomes >= 1/2 full */
#define UART_IFLS_RXIFLSEL_3_4 UART_IFLS_RXIFLSEL_3_4_Msk /* Receive FIFO becomes >= 3/4 full */
#define UART_IFLS_RXIFLSEL_7_8 UART_IFLS_RXIFLSEL_7_8_Msk /* Receive FIFO becomes >= 7/8 full */

#define UART_IFLS_TXIFLSEL_Pos 0
#define UART_IFLS_TXIFLSEL_Msk ((uint32_t)0x7 << UART_IFLS_TXIFLSEL_Pos)
#define UART_IFLS_TXIFLSEL UART_IFLS_TXIFLSEL_Msk /* Transmit interrupt FIFO level select */

/***************  Bit definition of UARTIMSC register  ***************/
#define UART_IMSC_OEIM_Pos 10
#define UART_IMSC_OEIM_Msk ((uint32_t)0x1 << UART_IMSC_OEIM_Pos)
#define UART_IMSC_OEIM UART_IMSC_OEIM_Msk /* Overrun error interrupt mask */
#define UART_IMSC_BEIM_Pos 9
#define UART_IMSC_BEIM_Msk ((uint32_t)0x1 << UART_IMSC_BEIM_Pos)
#define UART_IMSC_BEIM UART_IMSC_BEIM_Msk /* Break error intererupt mask */
#define UART_IMSC_PEIM_Pos 8
#define UART_IMSC_PEIM_Msk ((uint32_t)0x1 << UART_IMSC_PEIM_Pos)
#define UART_IMSC_PEIM UART_IMSC_PEIM_Msk /* Parity error interrupt mask */
#define UART_IMSC_FEIM_Pos 7
#define UART_IMSC_FEIM_Msk ((uint32_t)0x1 << UART_IMSC_FEIM_Pos)
#define UART_IMSC_FEIM UART_IMSC_FEIM_Msk /* Framing error interrupt mask */
#define UART_IMSC_RTIM_Pos 6
#define UART_IMSC_RTIM_Msk ((uint32_t)0x1 << UART_IMSC_RTIM_Pos)
#define UART_IMSC_RTIM UART_IMSC_RTIM_Msk /* Receive timeout interrupt mask */
#define UART_IMSC_TXIM_Pos 5
#define UART_IMSC_TXIM_Msk ((uint32_t)0x1 << UART_IMSC_TXIM_Pos)
#define UART_IMSC_TXIM UART_IMSC_TXIM_Msk /* Transmit interrupt mask */
#define UART_IMSC_RXIM_Pos 4
#define UART_IMSC_RXIM_Msk ((uint32_t)0x1 << UART_IMSC_RXIM_Pos)
#define UART_IMSC_RXIM UART_IMSC_RXIM_Msk /* Receive interrupt mask */
#define UART_IMSC_DSRMIM_Pos 3
#define UART_IMSC_DSRMIM_Msk ((uint32_t)0x1 << UART_IMSC_DSRMIM_Pos)
#define UART_IMSC_DSRMIM UART_IMSC_DSRMIM_Msk /* uUARTDSR modem interrupt mask */
#define UART_IMSC_DCDMIM_Pos 2
#define UART_IMSC_DCDMIM_Msk ((uint32_t)0x1 << UART_IMSC_DCDMIM_Pos)
#define UART_IMSC_DCDMIM UART_IMSC_DCDMIM_Msk /* uUARTDCD modem interrupt mask */
#define UART_IMSC_CTSMIM_Pos 1
#define UART_IMSC_CTSMIM_Msk ((uint32_t)0x1 << UART_IMSC_CTSMIM_Pos)
#define UART_IMSC_CTSMIM UART_IMSC_CTSMIM_Msk /* uUARTCTS modem interrupt mask */
#define UART_IMSC_RIMIM_Pos 0
#define UART_IMSC_RIMIM_Msk ((uint32_t)0x1 << UART_IMSC_RIMIM_Pos)
#define UART_IMSC_RIMIM UART_IMSC_RIMIM_Msk /* uUARTRI modem interrupt mask */

/***************  Bit definition of UARTRIS register  ***************/
#define UART_RIS_OERIS_Pos 10
#define UART_RIS_OERIS_Msk ((uint32_t)0x1 << UART_RIS_OERIS_Pos)
#define UART_RIS_OERIS UART_RIS_OERIS_Msk /* Overrun error interrupt status */
#define UART_RIS_BERIS_Pos 9
#define UART_RIS_BERIS_Msk ((uint32_t)0x1 << UART_RIS_BERIS_Pos)
#define UART_RIS_BERIS UART_RIS_BERIS_Msk /* Break error interrupt status */
#define UART_RIS_PERIS_Pos 8
#define UART_RIS_PERIS_Msk ((uint32_t)0x1 << UART_RIS_PERIS_Pos)
#define UART_RIS_PERIS UART_RIS_PERIS_Msk /* Parity error interrupt status */
#define UART_RIS_FERIS_Pos 7
#define UART_RIS_FERIS_Msk ((uint32_t)0x1 << UART_RIS_FERIS_Pos)
#define UART_RIS_FERIS UART_RIS_FERIS_Msk /* Framing error interrupt status */
#define UART_RIS_RTRIS_Pos 6
#define UART_RIS_RTRIS_Msk ((uint32_t)0x1 << UART_RIS_RTRIS_Pos)
#define UART_RIS_RTRIS UART_RIS_RTRIS_Msk /* Recieve timeout interrupt status */
#define UART_RIS_TXRIS_Pos 5
#define UART_RIS_TXRIS_Msk ((uint32_t)0x1 << UART_RIS_TXRIS_Pos)
#define UART_RIS_TXRIS UART_RIS_TXRIS_Msk /* Transmit interrupt status */
#define UART_RIS_RXRIS_Pos 4
#define UART_RIS_RXRIS_Msk ((uint32_t)0x1 << UART_RIS_RXRIS_Pos)
#define UART_RIS_RXRIS UART_RIS_RXRIS_Msk /* Receive interrupt status */
#define UART_RIS_DSRRMIS_Pos 3
#define UART_RIS_DSRRMIS_Msk ((uint32_t)0x1 << UART_RIS_DSRRMIS_Pos)
#define UART_RIS_DSRRMIS UART_RIS_DSRRMIS_Msk /* uUARTDSR modem interrupt status */
#define UART_RIS_DCDRMIS_Pos 2
#define UART_RIS_DCDRMIS_Msk ((uint32_t)0x1 << UART_RIS_DCDRMIS_Pos)
#define UART_RIS_DCDRMIS UART_RIS_DCDRMIS_Msk /* uUARTDCD modem interrupt status */
#define UART_RIS_CTSRMIS_Pos 1
#define UART_RIS_CTSRMIS_Msk ((uint32_t)0x1 << UART_RIS_CTSRMIS_Pos)
#define UART_RIS_CTSRMIS UART_RIS_CTSRMIS_Msk /* uUARTCTS modem interrupt status */
#define UART_RIS_RIRMIS_Pos 0
#define UART_RIS_RIRMIS_Msk ((uint32_t)0x1 << UART_RIS_RIRMIS_Pos)
#define UART_RIS_RIRMIS UART_RIS_RIRMIS_Msk /* uUARTRI modem interrupt status */

/***************  Bit definition of UARTMIS register  ***************/
#define UART_MIS_OEMIS_Pos 10
#define UART_MIS_OEMIS_Msk ((uint32_t)0x1 << UART_MIS_OEMIS_Pos)
#define UART_MIS_OEMIS UART_MIS_OEMIS_Msk /* Overrun error masked interrupt status */
#define UART_MIS_BEMIS_Pos 9
#define UART_MIS_BEMIS_Msk ((uint32_t)0x1 << UART_MIS_BEMIS_Pos)
#define UART_MIS_BEMIS UART_MIS_BEMIS_Msk /* Break error masked interrupt status */
#define UART_MIS_PEMIS_Pos 8
#define UART_MIS_PEMIS_Msk ((uint32_t)0x1 << UART_MIS_PEMIS_Pos)
#define UART_MIS_PEMIS UART_MIS_PEMIS_Msk /* Parity error masked interrupt status */
#define UART_MIS_FEMIS_Pos 7
#define UART_MIS_FEMIS_Msk ((uint32_t)0x1 << UART_MIS_FEMIS_Pos)
#define UART_MIS_FEMIS UART_MIS_FEMIS_Msk /* Framing error masked interrupt status */
#define UART_MIS_RTMIS_Pos 6
#define UART_MIS_RTMIS_Msk ((uint32_t)0x1 << UART_MIS_RTMIS_Pos)
#define UART_MIS_RTMIS UART_MIS_RTMIS_Msk /* Receive timeout masked interrupt status */
#define UART_MIS_TXMIS_Pos 5
#define UART_MIS_TXMIS_Msk ((uint32_t)0x1 << UART_MIS_TXMIS_Pos)
#define UART_MIS_TXMIS UART_MIS_TXMIS_Msk /* Transmit masked interrupt status */
#define UART_MIS_RXMIS_Pos 4
#define UART_MIS_RXMIS_Msk ((uint32_t)0x1 << UART_MIS_RXMIS_Pos)
#define UART_MIS_RXMIS UART_MIS_RXMIS_Msk /* Receive masked interrupt status */
#define UART_MIS_DSRMMIS_Pos 3
#define UART_MIS_DSRMMIS_Msk ((uint32_t)0x1 << UART_MIS_DSRMMIS_Pos)
#define UART_MIS_DSRMMIS UART_MIS_DSRMMIS_Msk /* uUARTDSR modem masked interrupt status */
#define UART_MIS_DCDMMIS_Pos 2
#define UART_MIS_DCDMMIS_Msk ((uint32_t)0x1 << UART_MIS_DCDMMIS_Pos)
#define UART_MIS_DCDMMIS UART_MIS_DCDMMIS_Msk /* uUARTDCD modem masked interrupt status */
#define UART_MIS_CTSMMIS_Pos 1
#define UART_MIS_CTSMMIS_Msk ((uint32_t)0x1 << UART_MIS_CTSMMIS_Pos)
#define UART_MIS_CTSMMIS UART_MIS_CTSMMIS_Msk /* uUARTCTS modem masked interrupt status */
#define UART_MIS_RIMMIS_Pos 0
#define UART_MIS_RIMMIS_Msk ((uint32_t)0x1 << UART_MIS_RIMMIS_Pos)
#define UART_MIS_RIMMIS UART_MIS_RIMMIS_Msk /* uUARTRI modem masked interrupt status */

/***************  Bit definition of UARTICR register  ***************/
#define UART_ICR_OEIC_Pos 10
#define UART_ICR_OEIC_Msk ((uint32_t)0x1 << UART_ICR_OEIC_Pos)
#define UART_ICR_OEIC UART_ICR_OEIC_Msk /* Overrun error interrupt clear */
#define UART_ICR_BEIC_Pos 9
#define UART_ICR_BEIC_Msk ((uint32_t)0x1 << UART_ICR_BEIC_Pos)
#define UART_ICR_BEIC UART_ICR_BEIC_Msk /* Break error interrupt clear */
#define UART_ICR_PEIC_Pos 8
#define UART_ICR_PEIC_Msk ((uint32_t)0x1 << UART_ICR_PEIC_Pos)
#define UART_ICR_PEIC UART_ICR_PEIC_Msk /* Parity error interrupt clear */
#define UART_ICR_FEIC_Pos 7
#define UART_ICR_FEIC_Msk ((uint32_t)0x1 << UART_ICR_FEIC_Pos)
#define UART_ICR_FEIC UART_ICR_FEIC_Msk /* Framing error interrupt clear */
#define UART_ICR_RTIC_Pos 6
#define UART_ICR_RTIC_Msk ((uint32_t)0x1 << UART_ICR_RTIC_Pos)
#define UART_ICR_RTIC UART_ICR_RTIC_Msk /* Receive timeout interrupt clear */
#define UART_ICR_TXIC_Pos 5
#define UART_ICR_TXIC_Msk ((uint32_t)0x1 << UART_ICR_TXIC_Pos)
#define UART_ICR_TXIC UART_ICR_TXIC_Msk /* Transmit interrupt clear */
#define UART_ICR_RXIC_Pos 4
#define UART_ICR_RXIC_Msk ((uint32_t)0x1 << UART_ICR_RXIC_Pos)
#define UART_ICR_RXIC UART_ICR_RXIC_Msk /* Receive interrupt clear */
#define UART_ICR_DSRMIC_Pos 3
#define UART_ICR_DSRMIC_Msk ((uint32_t)0x1 << UART_ICR_DSRMIC_Pos)
#define UART_ICR_DSRMIC UART_ICR_DSRMIC_Msk /* uUARTDSR modem interrupt clear */
#define UART_ICR_DCDMIC_Pos 2
#define UART_ICR_DCDMIC_Msk ((uint32_t)0x1 << UART_ICR_DCDMIC_Pos)
#define UART_ICR_DCDMIC UART_ICR_DCDMIC_Msk /* uUARTDCD modem interrupt clear */
#define UART_ICR_CTSMIC_Pos 1
#define UART_ICR_CTSMIC_Msk ((uint32_t)0x1 << UART_ICR_CTSMIC_Pos)
#define UART_ICR_CTSMIC UART_ICR_CTSMIC_Msk /* uUARTCTS modem interrupt clear */
#define UART_ICR_RIMIC_Pos 0
#define UART_ICR_RIMIC_Msk ((uint32_t)0x1 << UART_ICR_RIMIC_Pos)
#define UART_ICR_RIMIC UART_ICR_RIMIC_Msk /* uUARTRI modem interrupt clear */

/***************  Bit definition of UARTDMACR register  ***************/
#define UART_DMACR_DMAONERR_Pos 2
#define UART_DMACR_DMAONERR_Msk ((uint32_t)0x1 << UART_DMACR_DMAONERR_Pos)
#define UART_DMACR_DMAONERR UART_DMACR_DMAONERR_Msk /* DMA on error */
#define UART_DMACR_TXDMAE_Pos 1
#define UART_DMACR_TXDMAE_Msk ((uint32_t)0x1 << UART_DMACR_TXDMAE_Pos)
#define UART_DMACR_TXDMAE UART_DMACR_TXDMAE_Msk /* Tramsmit DMA enable */
#define UART_DMACR_RXDMAE_Pos 0
#define UART_DMACR_RXDMAE_Msk ((uint32_t)0x1 << UART_DMACR_RXDMAE_Pos)
#define UART_DMACR_RXDMAE UART_DMACR_RXDMAE_Msk /* Receive DMA enable */

#endif /*__UART_REG_H_*/
