
#ifndef __WATCHDOG_REG_H_
#define __WATCHDOG_REG_H_
#include "common.h"

typedef struct {
    __IO uint32_t WdogLoad;    /*Load Register*/
    __I uint32_t WdogValue;    /*Value Register*/
    __IO uint32_t WdogControl; /*Control Register*/
    __O uint32_t WdogIntClr;   /*Interrupt Clear Register*/
    __IO uint32_t WdogRIS;     /*Raw Interrupt Status Register*/
    __IO uint32_t WdogMIS;     /*Masked Interrupt Status Register*/

    uint32_t Reserved00[(0xC00 - 0x18) / 4]; /*Reserve bytes*/

    __IO uint32_t WdogLock; /*Lock Register*/
} wdog_reg_t;

typedef struct {
    __IO uint32_t WdogITCR; /*Integration Test Control Register*/
    __O uint32_t WdogITOP;  /*Integration Test Output Set Register*/
} wdog_test_t;

typedef struct {
    __I uint32_t WdogPeriphID[4]; /*Peripheral Identification Register*/
    __I uint32_t WdogPCellID[4];  /*PrimeCell Identification Register*/
} wdog_id_t;

/*Watchdog access definition*/
#define WDOGTEST_OFFSET 0x0F00
#define WDOGID_OFFSET 0x0FE0

#define WDOGTEST_BASE (WDOG_BASE + WTEST_OFFSET)
#define WDOGID_BASE (WDOG_BASE + WDOGID_OFFSET)

#define WDOGTEST ((wdog_test_t*)WDOGTEST_BASE)
#define WATCHDOGID ((wdog_id_t*)WDOGID_BASE)

/*Bit definition of WdogControl register*/
#define WDOG_CNTL_RESEN_Pos 1
#define WDOG_CNTL_RESEN_Msk \
    ((uint32_t)0x1 << WDOG_CNTL_RESEN_Pos) /* Enable Watchdog module reset output */
#define WDOG_CNTL_RESEN WDOG_CNTL_RESEN_Msk

#define WDOG_CNTL_INTEN_Pos 0
#define WDOG_CNTL_INTEN_Msk                                              \
    ((uint32_t)0x1 << WDOG_CNTL_INTEN_Pos) /* Enable the interrupt event \
                                            */
#define WDOG_CNTL_INTEN WDOG_CNTL_INTEN_Msk

/*Bit definition of WdogRIS*/
#define WDOG_RIS_WDOGRIS_Pos 0
#define WDOG_RIS_WDOGRIS_Msk ((uint32_t)0x1 << WDOG_RIS_WDOGRIS_Pos) /* Raw interrupt status */
#define WDOG_RIS_WDOGRIS WDOG_RIS_WDOGRIS_Msk

/*Bit definition of WdogMIS*/
#define WDOG_MIS_WDOGMIS_Pos 0
#define WDOG_MIS_WDOGMIS_Msk                                            \
    ((uint32_t)0x1 << WDOG_MIS_WDOGMIS_Pos) /* Enabled interrupt status \
                                             */
#define WDOG_MIS_WDOGMIS WDOG_MIS_WDOGMIS_Msk

/*Bit definition of WdogLock (Read value)*/
#define WDOG_LOCK_WDOGLOCK_Pos 0
#define WDOG_LOCK_WDOGLOCK_Msk \
    ((uint32_t)0x1 << WDOG_LOCK_WDOGLOCK_Pos) /* write access to all register is disable */
#define WDOG_LOCK_WDOGLOCK WDOG_LOCK_WDOGLOCK_Msk

/* When write this value to WdogLock register, all other register is accessible*/
#define WDOG_ENABLE_WRITE 0x1ACCE551
#define WDOG_DISABLE_WRITE 0XFFFFFFFF

/*Bit definition of WdogITCR register*/
#define WDOG_ITCR_ITEN_Pos 0
#define WDOG_ITCR_ITEN_Msk ((uint32_t)0x1 << WDOG_ITCR_ITEN_Pos) /*Integration test enable*/
#define WDOG_ITCR_ITEN WDOG_ITCR_ITEN_Msk

#define WDOG_ITOP_WDOGINT_Pos 1
#define WDOG_ITOP_WDOGINT_Msk \
    ((uint32_t)0x1            \
     << WDOG_ITOP_WDOGINT_Pos) /*Value output on WDOGINT when in integration test mode*/
#define WDOG_ITOP_WDOGINT WDOG_ITOP_WDOGINT_Msk

#define WDOG_ITOP_WDOGRES_Pos 0
#define WDOG_ITOP_WDOGRES_Msk \
    ((uint32_t)0x1            \
     << WDOG_ITOP_WDOGRES_Pos) /*Value output on WDOGRES when in integration test mode*/
#define WDOG_ITOP_WDOGRES WDOG_ITOP_WDOGRES_Msk

#endif  //__WATCHDOG_REG_H_
