#include "spi_bus.h"
#include <stddef.h>
#include "bsp_error.h"

int spi_slave_config_set(struct spi_bus_driver* drv, const uint8_t slv_id,
                         const spi_slave_conf_t* conf) {
    if (drv->ops->slave_config_set) {
        return drv->ops->slave_config_set(drv, slv_id, conf);
    }
    return ENOT_IMPLEMENTED;
}

int spi_bus_read(struct spi_bus_driver* drv, const uint8_t slv_id,
                 const spi_xfer_mode_t transfer_mode, void* buf, uint32_t size,
                 spi_bus_callback_t cb, void* cb_param) {
    if (drv->ops->read) {
        return drv->ops->read(drv, slv_id, transfer_mode, buf, size, cb, cb_param);
    }
    return ENOT_IMPLEMENTED;
}

int spi_bus_write(struct spi_bus_driver* drv, const uint8_t slv_id,
                  const spi_xfer_mode_t transfer_mode, void* buf, uint32_t size,
                  spi_bus_callback_t cb, void* cb_param) {
    if (drv->ops->write) {
        return drv->ops->write(drv, slv_id, transfer_mode, buf, size, cb, cb_param);
    }
    return ENOT_IMPLEMENTED;
}

int spi_bus_transceive(struct spi_bus_driver* drv, const uint8_t slv_id,
                       const spi_xfer_mode_t transfer_mode, void* txb, void* rxb, uint32_t tx_size,
                       uint32_t rx_size, spi_bus_callback_t cb, void* cb_param) {
    if (drv->ops->transceive) {
        return drv->ops->transceive(drv, slv_id, transfer_mode, txb, rxb, tx_size, rx_size, cb,
                                    cb_param);
    }
    return ENOT_IMPLEMENTED;
}

int spi_bus_transact(struct spi_bus_driver* drv, spi_transaction_t* transact, spi_bus_callback_t cb,
                     void* cb_param) {
    if (drv->ops->transact) {
        return drv->ops->transact(drv, transact, cb, cb_param);
    }
    return ENOT_IMPLEMENTED;
}

void spi_bus_transaction_init_read(spi_transfer_t* t_list, uint8_t* buff, uint32_t size) {
    t_list->mode = SPI_XFER_EXTENDED_SPI_MODE;
    t_list->size = size;
    t_list->rxd = buff;
    t_list->txd = NULL;
}

void spi_bus_transaction_init_write(spi_transfer_t* t_list, const uint8_t* buff, uint32_t size) {
    t_list->mode = SPI_XFER_EXTENDED_SPI_MODE;
    t_list->size = size;
    t_list->rxd = NULL;
    t_list->txd = (uint8_t*)buff;
}
