#include "common.h"
#include "spi_flash.h"
/** @addtogroup spi_flash spi_flash
 *  Documentation details of SPI_FLASH FW.
 *  @{
 */

/**
 * Useful flash command Ids
 **/
typedef struct {
    uint8_t read;       /**< Read command */
    uint8_t write;      /**< Write command */
    uint8_t quad_read;  /**< Quad read command */
    uint8_t quad_write; /**< Quad write command */
    uint8_t erase_4k;   /**< 4KB erase command */
    uint8_t erase_32k;  /**< 32KB erase command */
    uint8_t erase_64k;  /**< 64KB erase command */
#ifdef CONFIG_ENABLE_BULK_ERASE
    uint8_t chip_erase; /**< Full chip erase command */
#endif
    uint8_t read_id;               /**< Read flash id command */
    uint8_t read_sfdp;             /**< Read sfdp command */
    uint8_t wr_enable;             /**< Write enable command */
    uint8_t wr_disable;            /**< Write disable command */
    uint8_t read_status_reg;       /**< Read status register command */
    uint8_t read_flag_status_reg;  /**< Read flag status register command */
    uint8_t clear_flag_status_reg; /**< Clear flag status register command */
} flash_cmds;

/**
 * Useful flash information read from SFDP
 **/
typedef struct {
    flash_cmds cmds;                    /**< Flash command ids */
    spi_flash_information_t flash_info; /**< Flash information */
    uint32_t erase_4k_timeout;          /**< Maximum time taken to 4KB erase */
    uint32_t erase_32k_timeout;         /**< Maximum time taken to 32KB erase */
    uint32_t erase_64k_timeout;         /**< Maximum time taken to 64KB erase */
    uint32_t chip_erase_timeout;        /**< Maximum time taken to whole chip erase */
    uint32_t page_write_timeout;        /**< Maximum time taken to write page */
    uint8_t read_dummy_cycles;          /**< Number of dummy cycles needed for read */
} sfdp_data_t;

/**
 * Function to collect SFDP information from flash.
 *
 * @param bus the spi bus driver in use
 * @param slave_id Slave ID of the SPI device.
 * @param data contains SFDP information collected.
 *
 * @return 0 in case of success else return non-negative value in case of error.
 */
int sfdp_read_data(struct spi_bus_driver* bus, uint8_t slave_id, sfdp_data_t* data);
/** @} spi_flash
 */
