#include "uart.h"
#include <stdint.h>
#include "bsp_error.h"

#ifdef CONFIG_LOG_DEFAULT_LEVEL
#ifndef CONFIG_LOG_UART_LEVEL
#define CONFIG_LOG_UART_LEVEL CONFIG_LOG_DEFAULT_LEVEL
#endif
DECLARE_LOG_MODULE(UART, CONFIG_LOG_UART_LEVEL);
#endif

int uart_open(struct uart_driver* drv, const uart_config_t* uart_cfg) {
    if (drv->ops->open) {
        return drv->ops->open(drv, uart_cfg);
    }
    return ENOT_IMPLEMENTED;
}

int uart_read(struct uart_driver* drv, uint8_t* buf, const uint32_t len, const uint32_t timeout,
              uart_xfer_complete_callback cb, void* cb_param) {
    if (drv->ops->read) {
        return drv->ops->read(drv, buf, len, timeout, cb, cb_param);
    }
    return ENOT_IMPLEMENTED;
}

int uart_write(struct uart_driver* drv, const uint8_t* buf, const uint32_t len,
               const uint32_t timeout, uart_xfer_complete_callback cb, void* cb_param) {
    if (drv->ops->write) {
        return drv->ops->write(drv, buf, len, timeout, cb, cb_param);
    }
    return ENOT_IMPLEMENTED;
}

int uart_close(struct uart_driver* drv) {
    if (drv->ops->close) {
        return drv->ops->close(drv);
    }
    return ENOT_IMPLEMENTED;
}

int uart_get_char(struct uart_driver* drv) {
    if (drv->char_ops->get_char) {
        return drv->char_ops->get_char(drv);
    }
    return ENOT_IMPLEMENTED;
}

int uart_put_char(struct uart_driver* drv, const uint8_t ch) {
    if (drv->char_ops->get_char) {
        return drv->char_ops->put_char(drv, ch);
    }
    return ENOT_IMPLEMENTED;
}

int uart_set_config(struct uart_driver* drv, const uart_config_t* uart_cfg) {
    if (drv->char_ops->set_config) {
        return drv->char_ops->set_config(drv, uart_cfg);
    }
    return ENOT_IMPLEMENTED;
}
