
#include <errno.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>

#undef errno
extern int errno;

// functions to stub/or allow stdlib support
// Many implementations taken from:
// https://sites.google.com/site/stm32discovery/open-source-development-with-the-stm32-discovery/getting-newlib-to-work-with-stm32-and-code-sourcery-lite-eabi

// This will not be a problem since there are no shared libs, see
// https://lists.debian.org/debian-gcc/2003/07/msg00057.html
void* __dso_handle = (void*)&__dso_handle;

int _fstat(int file, struct stat* st) {
    st->st_mode = S_IFCHR;
    return 0;
}

int _close(int fd) {
    return -1;
}

// TODO: this might be implemented later in a different way
// int _write(int fd, char* buf, int count) { return count; }

// TODO: this might be implemented later in a different way
int _read(int fd, char* buf, int count) {
    return 0;
}

int _write(int fd, char* buf, int count) {
    return 0;
}

int _isatty(int file) {
    return 1;
}

int _lseek(int file, int ptr, int dir) {
    return 0;
}

void _kill(int pid, int sig) {
    return;
}

int _getpid(void) {
    return -1;
}

/*
 sbrk
 Implementation from
 https://interrupt.memfault.com/blog/boostrapping-libc-with-newlib
 */
caddr_t _sbrk(int incr) {
    extern char __end__;  // Defined by the linker
    static char* heap = NULL;
    caddr_t prev_heap;

    if (heap == NULL) {
        heap = (caddr_t)&__end__;
    }
    prev_heap = heap;

    heap += incr;

    return prev_heap;
}

void _exit(int code) {
    while (1)
        ;
}
