#include <stdint.h>
#include "AKD1000.h"
#include "bsp_error.h"
#include "cli_cmd.h"
#include "driver.h"
#include "elog.h"
#include "log_backend.h"
#include "power_monitor.h"
#include "systick.h"
#include "systimer.h"
/**
 * @page Commands CLI
 * @section power_monitor POWER MONITOR
 * @ref POWER_MONITOR-CLI-1 \n
 */

typedef struct {
    char cmp_str[6];
    int (*read_measurement)(struct power_monitor_driver* drv, int* value);
    char print_str[8];
    char print_unit[3];
} power_measurement_t;

power_measurement_t power_measure[] = {{"volt", get_voltage, "Voltage", "uV"},
                                       {"curr", get_current, "Current", "uA"},
                                       {"power", get_power, "Power", "uW"}};

int power_monitor_cli_handler(int argc, char** argv, struct cli_cmd_ctx* ctx) {
    int ret = SUCCESS;
    int value;
    uint32_t indx = 0;
    struct power_monitor_driver* drv = NULL;

    bool param_check = true;

    if ((argc == 4) && (!strncmp(argv[1], "read", 4))) {
        drv = (struct power_monitor_driver*)driver_lookup(argv[2]);

        if (drv) {
            for (indx = 0; indx < 3; indx++) {
                if (!strncmp(argv[3], power_measure[indx].cmp_str,
                             strlen(power_measure[indx].cmp_str))) {
                    if (0 >= power_measure[indx].read_measurement(drv, &value)) {
                        ret = EFAILURE;
                    }
                    break;
                }
            }

            if (indx == 3) {
                param_check = false;
            }
        } else {
            if ((!strcmp(argv[2], "ina1")) || (!strcmp(argv[2], "ina2"))) {
                cli_printf(ctx, "device is not available \n", __FUNCTION__);
            } else {
                param_check = false;
            }
            ret = EFAILURE;
        }
    } else {
        param_check = false;
    }

    if (false == param_check) {
        cli_printf(ctx, "Syntax: %s read {dev_name} {measurement}\n", argv[0]);
        cli_printf(ctx, "\tdev_name:   device name {ina1 | ina2}\n");
        cli_printf(ctx, "\tmeasurement:   Type of measurement {volt|curr|power}\n");

        ret = EFAILURE;
    } else {
        if (ret) {
            cli_printf(ctx, "Error: check if device is available\n");
        } else {
            cli_printf(ctx, "%s : %d %s\n", power_measure[indx].print_str, value,
                       power_measure[indx].print_unit);
        }
    }

    return ret;
}

DECLARE_CMD(pmon, power_monitor_cli_handler);

int main(void) {
    bsp_init();
    while (1) {
        cli_poll();
    }
}
