/*
 * Copyright (c) 2020, <TBD>.
 */

#ifndef _INTERFACE_H
#define _INTERFACE_H

#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>

/**
 * @addtogroup elog
 * @{
 * @defgroup log_backend log_backend
 * Log backend allows to implement the way logs are pushed to the user.
 * @{
 */

/**
 * Generic function type of log backend initialization
 */
typedef int (*if_init_t)();

/**
 * Generic function type to define blocking write call to
 * a communication interface, that takes charecter buffer
 */
typedef uint32_t (*if_write_t)(const char*, const uint32_t);

/**
 * Host Communication interface configuration
 */
struct log_common {
    /** Function to initialize log backend*/
    if_init_t init;
    /** Function to write to interface, expects string, synchronous call*/
    if_write_t write;
};

/**< Structure holding a log backend instance*/
struct log_item {
    /** Log backend instance name */
    char* name;
    /** Actual log backend instance pointer */
    struct log_common* logger;
};

/**
 * Inialize log backends supported
 * @return status of the inialization SUCESS or EFAILURE.
 */
int log_backend_init();

/**
 * Declare a logbackend.
 */
#if defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
#define DECLARE_LOGBACKEND(_name_, _loginst_)                                      \
    struct log_item __attribute__((section("LOG_BACKENDS"))) __attribute__((used)) \
        __loginst_##_name_ = {.name = #_name_, .logger = _loginst_};
#elif defined(__GNUC__)
#define DECLARE_LOGBACKEND(_name_, _loginst_)                 \
    struct log_item __attribute__((section(".log_backends"))) \
        __loginst_##_name_ = {.name = #_name_, .logger = _loginst_};
#endif

/**
 * Search for a log backends section given its name
 * @param name the name of the log backend instance to look for
 * @return struct log_common* the pointer to the log backend instance handler
 * NULL if log backend instance not found
 */
struct log_common* log_backend_lookup(char* name);

/** @} log_backend
 * @} elog
 */
#endif /* #ifndef _INTERFACE_H */
