#ifndef __SYSTICK_H__
#define __SYSTICK_H__
#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif
/** @addtogroup infra
 * @{
 */

/**
 * @addtogroup systick systick
 * Documentation details of systick feaure
 *
 * Systick feature is an interface allowing to access the
 * ARM systick component. It configures the timer and allow
 * registring a callback.
 *  @{
 */

/**
 * Callback function type systick_callback_t
 * Callback invokes on every microseconds interrupt
 *
 * @param ticks system up time in milliseconds
 *
 */

typedef void (*systick_callback_t)(uint64_t ticks);

/**
 * @brief  : function returns system up time in terms of milliseconds
 * @param  : void
 * @retval : timer period in milliseconds
 */
uint64_t get_time_ms(void);

/**
 * @brief  : function returns system up time in terms of microseconds
 * @param  : void
 * @retval : timer period in microseconds
 */
uint64_t get_time_us(void);

/**
 * @brief  : function returns system up time in terms of nanoseconds
 * @param  : void
 * @retval : timer period in nanoseconds
 */
uint64_t get_time_ns(void);

/**
 * @brief  : function generates a delay in microseconds
 * @param  period  timer period in microseconds
 */
void delay_us(uint32_t period);

/**
 * @brief  : systick_init API is used to configure and initialize systick timer to generate at
 * interrupt at every 1 millisecond.
 * @param  : void
 */
void systick_init(void);

/**
 * @brief  : systick_register_cb API is used to register a callback function.
 * @param cb the callback function to call on every systick interrupt
 * @return : error code incase of failure or 0 if success
 */
int systick_register_cb(systick_callback_t cb);

/**
 * @brief  : systick_deregister_cb API is used to de-register the callback function.
 * @param cb the callback function to be de-register
 * @return : error code incase of failure or 0 if success
 */
int systick_deregister_cb(systick_callback_t cb);

#ifdef __cplusplus
}
#endif
/** @} systick
 * @} infra
 */
#endif /*__SYSTICK_H__*/
