#ifndef __SYSTIMER_H__
#define __SYSTIMER_H__

#include <stdint.h>

struct systimer;

/**
 * @addtogroup infra
 * @{
 */

/**
 * @addtogroup systimer systimer
 * Documentation details of systimer
 *
 * It is deprecated by @ref workqueues
 *  @{
 */

/**
 * timer function
 *
 * @param timer the timer that is executed
 */
typedef void (*systimer_callback_t)(struct systimer* timer);

/**
 * system timer element structure
 */
struct systimer {
    /** queuing pointer, should not be touched or used. */
    struct systimer* next;
    /** callback function, should be initialized with the wanted timer function */
    systimer_callback_t cb;
    /** scheduled time, should not be touched, it is used internally */
    uint64_t sheduled_time;
    /** Callback parameter cb_param to be passed as part of callback fn*/
    void* cb_param;
};

/**
 * Insert a timer item in the timer list.
 * This an asynchronous function and timer pointer should be valid until the timer function is
 * executed
 *
 * @param timer the timer to queue
 * @param delay the delay in milliseconds after which the timer has to be executed.
 *
 * @return error code incase of failure or 0 if success
 */
int systimer_register(struct systimer* timer, uint32_t delay);

/**
 * Remove a timer item from the timer list
 *
 * @param timer the timer to dequeue
 *
 * @return error code incase of failure or 0 if success
 */
int systimer_deregister(struct systimer* timer);

/**
 * Indicates if there is timer pending (this allows a timer registration to be removed)
 *
 * @return 0 if no timer pending, or != 0 otherwise
 */
int systimer_pending(void);

/**
 * Initialize the system timer
 * @note This function should be called from SysTick_Handler
 * @param : void
 */
void systimer_init(void);

/**
 * @} systimer
 * @} infra
 */
#endif /* __SYSTIMER_H__ */
