#include <stdarg.h>
#include <stdbool.h>
#include "bsp_error.h"
#include "log_backend.h"
#include "uart.h"

static struct uart_driver* uart_drv = NULL;
static uart_config_t uart_config = {
    .baud_rate = 115200,
    .word_len = UART_WORDLEN_8,
    .stop_bits = UART_STOP_BIT_ONE,
    .parity = UART_PARITY_NO,
    .sticky_parity = false,
};

/**
 * Function to initialize and confiugre an UART interface
 * @return    SUCCESS, EFAILURE in case of success, failure.
 */
static int log_uart_init();

/**
 * Function to write on UART interface
 * @param[in] data Data to be presented to User.
 * @param[in] len   Length of @p wrbuff in bytes.
 * @return           Number of bytes written.
 */
static uint32_t log_uart_wr(const char* data, const uint32_t len);

static uint32_t log_uart_wr(const char* data, const uint32_t len) {
    return uart_write(uart_drv, (uint8_t*)data, len, 100, NULL, NULL);
}

static int log_uart_init() {
    int rc = 0;

    uart_drv = (struct uart_driver*)driver_lookup(CONFIG_LOG_BACKEND_UART_INST);

    if (NULL != uart_drv) {
        struct driver_item* drv = uart_drv->driver.reg;
        if (drv->driver->init(drv->driver, drv->priv)) {
            return -1;
        }
        if ((rc = uart_open(uart_drv, &uart_config))) {
            return EFAILURE;
        }
    } else {
        return EFAILURE;
    }
    return rc;
}

struct log_common uart_logger = {
    .init = log_uart_init,
    .write = log_uart_wr,
};
DECLARE_LOGBACKEND(uart, &uart_logger);
