#include <stdarg.h>
#include <stdbool.h>
#include <stdio.h>
#include "bsp_error.h"
#include "cli_cmd.h"
#include "device.h"
#include "driver.h"
#include "stdlib.h"
#include "uart.h"
static int uart_ctx_vprintf(struct cli_ctx* ctx, const char* fmt, va_list args);
static int uart_ctx_getchar(struct cli_ctx* ctx);
static void uart_ctx_puts(struct cli_ctx* ctx, char* str);
static void uart_ctx_putchar(struct cli_ctx* ctx, int c);

static uart_config_t uart_config = {
    .baud_rate = 115200,
    .word_len = UART_WORDLEN_8,
    .stop_bits = UART_STOP_BIT_ONE,
    .parity = UART_PARITY_NO,
    .sticky_parity = false,
};

struct uart_cli {
    struct cli_ctx ctx;
    struct uart_driver* drv;
};

static struct uart_cli uart_cli_ctx = {.ctx = {.vprintf = &uart_ctx_vprintf,
                                               .get_char = &uart_ctx_getchar,
                                               .puts = &uart_ctx_puts,
                                               .put = &uart_ctx_putchar,
                                               .buffer = {0},
                                               .cmd_idx = 0,
                                               .state = TTY_STATE_NORMAL}};

static struct cli_cmd_ctx uart_cli_cmd_ctx;

int uart_ctx_vprintf(struct cli_ctx* ctx, const char* fmt, va_list args) {
    char text[128];
    int len;
    len = vsprintf(text, fmt, args);
    uart_write(((struct uart_cli*)ctx)->drv, (uint8_t*)text, len, 100, NULL, NULL);
    return len;
}

int uart_ctx_getchar(struct cli_ctx* ctx) {
    return uart_get_char(((struct uart_cli*)ctx)->drv);
}
void uart_ctx_puts(struct cli_ctx* ctx, char* str) {
    uart_write(((struct uart_cli*)ctx)->drv, (uint8_t*)str, strlen(str), 100, NULL, NULL);
}

void uart_ctx_putchar(struct cli_ctx* ctx, int c) {
    while (uart_put_char(((struct uart_cli*)ctx)->drv, c))
        ;
}

static int uart_channel_init(struct cli_channel_handler* chan) {
    uart_cli_ctx.drv = (struct uart_driver*)driver_lookup(chan->priv);

    uart_cli_ctx.ctx.ctx = &uart_cli_cmd_ctx;
    uart_cli_cmd_ctx.cli = &uart_cli_ctx.ctx;

    if (NULL != uart_cli_ctx.drv) {
        struct driver_item* drv = uart_cli_ctx.drv->driver.reg;
        if (drv->driver->init(drv->driver, drv->priv)) {
            return -1;
        }
        if (uart_open(uart_cli_ctx.drv, &uart_config)) {
            return -1;
        }
    } else {
        return -1;
    }
    return 0;
}

DECLARE_CLI_CHANNEL(uart, &uart_cli_ctx.ctx, uart_channel_init, CONFIG_CLI_BACKEND_UART_INST);
